/* dark color scheme */
@define-color dark_bg_color #0f0f0f;
@define-color dark_fg_color #a5a5a5;
/* colormap actually used by the theme, to be overridden in other css files */
@define-color theme_bg_color #a5a5a5;
@define-color theme_fg_color #000000;
@define-color theme_base_color #d0d0d0;
@define-color theme_text_color #000000;
@define-color theme_selected_bg_color #B36A87;
@define-color theme_selected_fg_color #000000;
@define-color theme_tooltip_bg_color #a5a5a5;
@define-color theme_tooltip_fg_color #000000;
/* shadow effects */
@define-color light_shadow #fff;
@define-color dark_shadow #000;
/* misc colors used by gtk+ */
@define-color info_fg_color #fff;
@define-color info_bg_color #03a9f4;
@define-color warning_fg_color #fff;
@define-color warning_bg_color #ef6c00;
@define-color question_fg_color #fff;
@define-color question_bg_color #673ab7;
@define-color error_fg_color #fff;
@define-color error_bg_color #f44336;
@define-color link_color #B36A87;
@define-color success_color #4caf50;
@define-color warning_color #ef6c00;
@define-color error_color #f44336;
/* widget colors */
@define-color titlebar_bg_color @dark_bg_color;
@define-color titlebar_fg_color @dark_fg_color;
@define-color menubar_bg_color @dark_bg_color;
@define-color menubar_fg_color @dark_fg_color;
@define-color toolbar_bg_color @theme_bg_color;
@define-color toolbar_fg_color @theme_fg_color;
@define-color menu_bg_color @dark_bg_color;
@define-color menu_fg_color @dark_fg_color;
@define-color panel_bg_color @dark_bg_color;
@define-color panel_fg_color @dark_fg_color;
/* osd */
@define-color osd_base #0f0f0f;
@define-color osd_bg rgba(15, 15, 15, 0.8);
@define-color osd_fg #a5a5a5;
/* lightdm greeter colors */
@define-color lightdm_bg_color #0f0f0f;
@define-color lightdm_fg_color #a5a5a5;
/* window manager colors */
@define-color wm_bg #0f0f0f;
@define-color wm_border_focused #B36A87;
@define-color wm_border_unfocused #0f0f0f;
@define-color wm_title_focused mix(#a5a5a5,#0f0f0f,0.1);
@define-color wm_title_unfocused mix(#a5a5a5,#0f0f0f,0.4);
@define-color wm_icons_focused mix(#a5a5a5,#0f0f0f,0.1);
@define-color wm_icons_focused_prelight #B36A87;
@define-color wm_icons_focused_pressed #974d6a;
@define-color wm_icons_unfocused mix(#a5a5a5,#0f0f0f,0.4);
@define-color wm_icons_unfocused_prelight #B36A87;
@define-color wm_icons_unfocused_pressed #974d6a;
/**************
 ! GTK settings
***************/
* {
  -GtkArrow-arrow-scaling: .5;
  -GtkExpander-expander-size: 8;
  -GtkStatusbar-shadow-type: none;
  -GtkToolItemGroup-expander-size: 8;
  -GtkWindow-resize-grip-height: 0;
  -GtkWindow-resize-grip-width: 0;
  -WnckTasklist-fade-overlay-rect: 0;
  -GtkWidget-cursor-color: #000000;
  -GtkWidget-secondary-cursor-color: #000000;
  -GtkWidget-cursor-aspect-ratio: 0.04;
  outline-color: rgba(179, 106, 135, 0.5);
  outline-style: dashed;
  outline-width: 1px;
  outline-offset: -1px;
  outline-radius: 3px; }

/*************
 ! Base states
 *************/
*:selected, .gtkstyle-fallback:selected, GtkLabel:selected, .grid-child:selected, GtkFlowBox .grid-child:selected, GucharmapChartable:focus, GucharmapChartable:hover, GucharmapChartable:active, GucharmapChartable:selected, .view:selected, GtkHTML:selected, .view:selected:focus, GtkHTML:selected:focus, .gedit-document-panel-document-row:selected, .gedit-document-panel-document-row:selected:hover, GeditViewFrame .gedit-search-slider .not-found:selected, :focus:selected, GtkFlowBox .grid-child:focus:selected, GucharmapChartable:focus, .gedit-document-panel-document-row:focus:selected:hover, GeditViewFrame .gedit-search-slider .not-found:focus:selected {
  background-color: #B36A87;
  color: #000000; }

* {
  /* hyperlinks */
  -GtkHTML-link-color: #B36A87;
  -GtkIMHtml-hyperlink-color: #B36A87;
  -GtkWidget-link-color: #B36A87;
  -GtkWidget-visited-link-color: #B36A87; }
  *:insensitive, *:insensitive:insensitive {
    color: mix(#000000,#a5a5a5,0.5); }
  *:insensitive {
    -gtk-image-effect: dim; }
  *:hover {
    -gtk-image-effect: highlight; }
  *:link, *:visited {
    color: #B36A87; }

.background {
  background-color: #a5a5a5;
  color: #000000; }
  .background:backdrop {
    text-shadow: none;
    icon-shadow: none; }
  .background.csd {
    background-color: #a5a5a5; }

.gtkstyle-fallback {
  background-color: rgba(165, 165, 165, 0.5);
  color: #000000; }
  .gtkstyle-fallback:hover {
    background-color: #b6b6b6;
    color: #000000; }
  .gtkstyle-fallback:active {
    background-color: #959595;
    color: #000000; }
  .gtkstyle-fallback:insensitive {
    background-color: #a5a5a5;
    color: mix(#000000,#a5a5a5,0.5); }

GtkImage, GtkImage:insensitive, GtkLabel, GtkLabel:insensitive, GtkBox, GtkBox:insensitive, GtkGrid, GtkGrid:insensitive {
  background-color: transparent; }

GtkLabel.separator {
  color: #000000; }

GtkLabel:insensitive {
  color: mix(#000000,#a5a5a5,0.5); }

/*********
 ! Buttons
**********/
.button, .button.default, .toolbar .button, .header-bar .button, .suggested-action.button, .selection-mode.header-bar .button.suggested-action, .selection-mode.toolbar .button.suggested-action, .destructive-action.button, .selection-mode.header-bar .button, .selection-mode.toolbar .button, .info .button, .warning .button, .question .button, .error .button, GtkPopover .button, GtkModelButton.button, GtkModelButton.button:backdrop, .app-notification .button, .app-notification.frame .button, .osd.button, .osd .button,
#XfceNotifyWindow.button,
#XfceNotifyWindow .button, NemoPathbarButton {
  padding: 3px 5px;
  border-width: 1px;
  border-style: solid;
  border-radius: 3px;
  transition: 150ms ease;
  outline-color: transparent;
  -GtkWidget-focus-padding: 1;
  -GtkWidget-focus-line-width: 0; }
  .button:focus, .selection-mode.header-bar .button:focus, .selection-mode.toolbar .button:focus, GtkModelButton.button:focus:backdrop, .app-notification.frame .button:focus,
  #XfceNotifyWindow.button:focus,
  #XfceNotifyWindow .button:focus, NemoPathbarButton:focus, .button:hover, .selection-mode.header-bar .button:hover, .selection-mode.toolbar .button:hover, GtkModelButton.button:hover:backdrop, .app-notification.frame .button:hover,
  #XfceNotifyWindow.button:hover,
  #XfceNotifyWindow .button:hover, NemoPathbarButton:hover, .button:active, .selection-mode.header-bar .button:active, .selection-mode.toolbar .button:active, GtkModelButton.button:active:backdrop, .app-notification.frame .button:active,
  #XfceNotifyWindow.button:active,
  #XfceNotifyWindow .button:active, NemoPathbarButton:active {
    transition: none; }

.linked > GtkComboBox > .button:dir(ltr) {
  border-radius: 0;
  border-left-style: none;
  border-right-style: solid; }
  .linked > GtkComboBox > .button:dir(rtl) {
    border-radius: 0;
    border-right-style: none;
    border-left-style: solid; }

.button.linked, .linked .button, GtkComboBox.combobox-entry .entry, GtkComboBox.combobox-entry .button, .toolbar .button.linked, .toolbar .linked .button, .header-bar .button.linked, .header-bar .linked .button, .selection-mode.header-bar .button.linked, .selection-mode.header-bar .linked .button, .selection-mode.toolbar .button.linked, .selection-mode.toolbar .linked .button {
  border-width: 1px;
  border-style: solid;
  border-radius: 0;
  border-right-style: none;
  border-left-style: none; }
  .button.linked:first-child, .linked .button:first-child, GtkComboBox.combobox-entry .entry:first-child, GtkComboBox.combobox-entry .button:first-child, .linked > GtkComboBox:first-child > .button, .selection-mode.header-bar .button.linked:first-child, .selection-mode.header-bar .linked .button:first-child, .selection-mode.toolbar .button.linked:first-child, .selection-mode.toolbar .linked .button:first-child {
    border-width: 1px;
    border-radius: 3px;
    border-left-style: solid;
    border-right-style: none;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
    .button.linked:first-child:dir(rtl), .linked .button:first-child:dir(rtl), GtkComboBox.combobox-entry .entry:first-child:dir(rtl), GtkComboBox.combobox-entry .button:first-child:dir(rtl), .linked > GtkComboBox:first-child > .button:dir(rtl), .selection-mode.header-bar .button.linked:first-child:dir(rtl), .selection-mode.header-bar .linked .button:first-child:dir(rtl), .selection-mode.toolbar .button.linked:first-child:dir(rtl), .selection-mode.toolbar .linked .button:first-child:dir(rtl) {
      border-left-style: none;
      border-right-style: solid; }
  .button.linked:last-child, .linked .button:last-child, GtkComboBox.combobox-entry .entry:last-child, GtkComboBox.combobox-entry .button:last-child, .linked > GtkComboBox:last-child > .button, .selection-mode.header-bar .button.linked:last-child, .selection-mode.header-bar .linked .button:last-child, .selection-mode.toolbar .button.linked:last-child, .selection-mode.toolbar .linked .button:last-child {
    border-width: 1px;
    border-radius: 3px;
    border-left-style: none;
    border-right-style: solid;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }
    .button.linked:last-child:dir(rtl), .linked .button:last-child:dir(rtl), GtkComboBox.combobox-entry .entry:last-child:dir(rtl), GtkComboBox.combobox-entry .button:last-child:dir(rtl), .linked > GtkComboBox:last-child > .button:dir(rtl), .selection-mode.header-bar .button.linked:last-child:dir(rtl), .selection-mode.header-bar .linked .button:last-child:dir(rtl), .selection-mode.toolbar .button.linked:last-child:dir(rtl), .selection-mode.toolbar .linked .button:last-child:dir(rtl) {
      border-left-style: solid;
      border-right-style: none; }
  .button.linked:only-child, .linked .button:only-child, GtkComboBox.combobox-entry .entry:only-child, GtkComboBox.combobox-entry .button:only-child, .linked > GtkComboBox:only-child > .button, .selection-mode.header-bar .button.linked:only-child, .selection-mode.header-bar .linked .button:only-child, .selection-mode.toolbar .button.linked:only-child, .selection-mode.toolbar .linked .button:only-child, .button.linked:first-child:only-child, .linked .button:first-child:only-child, GtkComboBox.combobox-entry .entry:first-child:only-child, GtkComboBox.combobox-entry .button:first-child:only-child, .linked > GtkComboBox:first-child > .button:only-child, .linked > GtkComboBox:only-child > .button:first-child {
    border-width: 1px;
    border-style: solid;
    border-radius: 3px; }

* {
  -GtkButton-child-displacement-x: 0;
  -GtkButton-child-displacement-y: 0;
  -GtkButton-default-border: 0;
  -GtkButton-image-spacing: 0;
  -GtkButton-inner-border: 1;
  -GtkButton-interior-focus: true;
  -GtkButtonBox-child-min-height: 24;
  -GtkButtonBox-child-internal-pad-y: 1;
  -GtkToolButton-icon-spacing: 6; }

.info .button.close, .warning .button.close, .question .button.close, .error .button.close, .notebook tab .button {
  border: 1px solid transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none; }
  .info .button.close:focus, .warning .button.close:focus, .question .button.close:focus, .error .button.close:focus, .notebook tab .button:focus, .info .button.close:hover, .warning .button.close:hover, .question .button.close:hover, .error .button.close:hover, .notebook tab .button:hover {
    border: 1px solid rgba(0, 0, 0, 0.3);
    background-color: rgba(255, 255, 255, 0.2);
    background-image: none;
    box-shadow: none; }
  .info .button.close:active, .warning .button.close:active, .question .button.close:active, .error .button.close:active, .notebook tab .button:active, .info .button.close:checked, .warning .button.close:checked, .question .button.close:checked, .error .button.close:checked, .notebook tab .button:checked, .info .button.close:active:hover, .warning .button.close:active:hover, .question .button.close:active:hover, .error .button.close:active:hover, .notebook tab .button:active:hover, .info .button.close:checked:hover, .warning .button.close:checked:hover, .question .button.close:checked:hover, .error .button.close:checked:hover, .notebook tab .button:checked:hover {
    border: 1px solid rgba(0, 0, 0, 0.3);
    background-color: rgba(0, 0, 0, 0.1);
    background-image: none;
    box-shadow: none; }

.button {
  /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
  background-color: #8b639b;
  background-image: none;
  border-color: rgba(0, 0, 0, 0.22);
  color: #000000;
  box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
  .button:focus, .button:hover {
    border-color: rgba(0, 0, 0, 0.22); }
  .button:active, .button:active:hover, .button:active:focus, .button:active:hover:focus, .button:checked, .button:checked:hover, .button:checked:focus, .button:checked:hover:focus {
    border-color: rgba(0, 0, 0, 0.22); }
  .button:insensitive {
    border-color: rgba(0, 0, 0, 0.22); }
  .button:active:insensitive, .button:checked:insensitive {
    border-color: rgba(0, 0, 0, 0.22); }
  .button.flat {
    border-color: rgba(139, 99, 155, 0);
    background-color: rgba(139, 99, 155, 0);
    background-image: none;
    box-shadow: none; }
  .button:focus, .button:hover, .button.flat:focus, .button.flat:hover {
    background-color: #a282af;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.3);
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .button:focus:focus, .button:focus:hover, .button:hover:focus, .button:hover:hover, .button.flat:focus:focus, .button.flat:focus:hover, .button.flat:hover:focus, .button.flat:hover:hover {
      border-color: rgba(0, 0, 0, 0.3); }
    .button:focus:active, .button:focus:active:hover, .button:focus:active:focus, .button:focus:active:hover:focus, .button:focus:checked, .button:focus:checked:hover, .button:focus:checked:focus, .button:focus:checked:hover:focus, .button:hover:active, .button:hover:active:hover, .button:hover:active:focus, .button:hover:active:hover:focus, .button:hover:checked, .button:hover:checked:hover, .button:hover:checked:focus, .button:hover:checked:hover:focus, .button.flat:focus:active, .button.flat:focus:active:hover, .button.flat:focus:active:focus, .button.flat:focus:active:hover:focus, .button.flat:focus:checked, .button.flat:focus:checked:hover, .button.flat:focus:checked:focus, .button.flat:focus:checked:hover:focus, .button.flat:hover:active, .button.flat:hover:active:hover, .button.flat:hover:active:focus, .button.flat:hover:active:hover:focus, .button.flat:hover:checked, .button.flat:hover:checked:hover, .button.flat:hover:checked:focus, .button.flat:hover:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.3); }
    .button:focus:insensitive, .button:hover:insensitive, .button.flat:focus:insensitive, .button.flat:hover:insensitive {
      border-color: rgba(0, 0, 0, 0.3); }
    .button:focus:active:insensitive, .button:focus:checked:insensitive, .button:hover:active:insensitive, .button:hover:checked:insensitive, .button.flat:focus:active:insensitive, .button.flat:focus:checked:insensitive, .button.flat:hover:active:insensitive, .button.flat:hover:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.3); }
  .button:active, .button:checked, .button.flat:active, .button.flat:checked {
    background-color: #61456d;
    background-image: none;
    color: #000000;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .button:active:focus, .button:active:hover, .button:checked:focus, .button:checked:hover, .button.flat:active:focus, .button.flat:active:hover, .button.flat:checked:focus, .button.flat:checked:hover {
      background-color: #5a4065;
      background-image: none;
      color: #000000; }
  .button:focus, .button:hover, .button.flat:focus, .button.flat:hover {
    color: #000000; }
  .button:active:insensitive, .button:checked:insensitive, .button.flat:active:insensitive, .button.flat:checked:insensitive {
    background-color: #7d598c;
    background-image: none;
    color: #000000;
    box-shadow: none; }
  .button:insensitive:insensitive, .button.flat:insensitive:insensitive {
    background-color: rgba(139, 99, 155, 0.3);
    background-image: none;
    color: mix(#8b639b,#000000,0.5);
    box-shadow: none; }
  .button:active {
    color: #000000; }
  .button.flat:insensitive:insensitive {
    background-color: transparent;
    background-image: none;
    color: mix(#8b639b,#000000,0.5);
    box-shadow: none; }
  .button.separator, .button .separator {
    border: 1px solid currentColor;
    color: #7d598c; }
    .button.separator:insensitive, .button .separator:insensitive {
      color: #765484; }
  .button.default {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #B36A87;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.12);
    color: #000000;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.12); }
    .button.default:focus, .button.default:hover {
      border-color: rgba(0, 0, 0, 0.12); }
    .button.default:active, .button.default:active:hover, .button.default:active:focus, .button.default:active:hover:focus, .button.default:checked, .button.default:checked:hover, .button.default:checked:focus, .button.default:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.12); }
    .button.default:insensitive {
      border-color: rgba(0, 0, 0, 0.12); }
    .button.default:active:insensitive, .button.default:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.12); }
    .button.default.flat {
      border-color: rgba(179, 106, 135, 0);
      background-color: rgba(179, 106, 135, 0);
      background-image: none;
      box-shadow: none; }
    .button.default:focus, .button.default:hover, .button.default.flat:focus, .button.default.flat:hover {
      background-color: #c690a5;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.2);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.32); }
      .button.default:focus:focus, .button.default:focus:hover, .button.default:hover:focus, .button.default:hover:hover, .button.default.flat:focus:focus, .button.default.flat:focus:hover, .button.default.flat:hover:focus, .button.default.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.2); }
      .button.default:focus:active, .button.default:focus:active:hover, .button.default:focus:active:focus, .button.default:focus:active:hover:focus, .button.default:focus:checked, .button.default:focus:checked:hover, .button.default:focus:checked:focus, .button.default:focus:checked:hover:focus, .button.default:hover:active, .button.default:hover:active:hover, .button.default:hover:active:focus, .button.default:hover:active:hover:focus, .button.default:hover:checked, .button.default:hover:checked:hover, .button.default:hover:checked:focus, .button.default:hover:checked:hover:focus, .button.default.flat:focus:active, .button.default.flat:focus:active:hover, .button.default.flat:focus:active:focus, .button.default.flat:focus:active:hover:focus, .button.default.flat:focus:checked, .button.default.flat:focus:checked:hover, .button.default.flat:focus:checked:focus, .button.default.flat:focus:checked:hover:focus, .button.default.flat:hover:active, .button.default.flat:hover:active:hover, .button.default.flat:hover:active:focus, .button.default.flat:hover:active:hover:focus, .button.default.flat:hover:checked, .button.default.flat:hover:checked:hover, .button.default.flat:hover:checked:focus, .button.default.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.2); }
      .button.default:focus:insensitive, .button.default:hover:insensitive, .button.default.flat:focus:insensitive, .button.default.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.2); }
      .button.default:focus:active:insensitive, .button.default:focus:checked:insensitive, .button.default:hover:active:insensitive, .button.default:hover:checked:insensitive, .button.default.flat:focus:active:insensitive, .button.default.flat:focus:checked:insensitive, .button.default.flat:hover:active:insensitive, .button.default.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.2); }
    .button.default:active, .button.default:checked, .button.default.flat:active, .button.default.flat:checked {
      background-color: #84435d;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .button.default:active:focus, .button.default:active:hover, .button.default:checked:focus, .button.default:checked:hover, .button.default.flat:active:focus, .button.default.flat:active:hover, .button.default.flat:checked:focus, .button.default.flat:checked:hover {
        background-color: #7b3f56;
        background-image: none;
        color: #000000; }
    .button.default:focus, .button.default:hover, .button.default.flat:focus, .button.default.flat:hover {
      color: #000000; }
    .button.default:active:insensitive, .button.default:checked:insensitive, .button.default.flat:active:insensitive, .button.default.flat:checked:insensitive {
      background-color: #a95778;
      background-image: none;
      color: #000000;
      box-shadow: none; }
    .button.default:insensitive:insensitive, .button.default.flat:insensitive:insensitive {
      background-color: #ae617f;
      background-image: none;
      color: mix(#B36A87,#000000,0.5);
      box-shadow: none; }
    .button.default:active {
      color: #000000; }
    .button.default.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#B36A87,#000000,0.5);
      box-shadow: none; }
    .button.default.separator, .button.default .separator {
      border: 1px solid currentColor;
      color: #a95778; }
      .button.default.separator:insensitive, .button.default .separator:insensitive {
        color: #a05271; }
  .button.linked, .linked .button {
    box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .button.linked:focus, .button.linked:hover, .linked .button:focus, .linked .button:hover {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .button.linked:active, .button.linked:active:hover, .button.linked:active:focus, .button.linked:active:hover:focus, .button.linked:checked, .button.linked:checked:hover, .button.linked:checked:focus, .button.linked:checked:hover:focus, .linked .button:active, .linked .button:active:hover, .linked .button:active:focus, .linked .button:active:hover:focus, .linked .button:checked, .linked .button:checked:hover, .linked .button:checked:focus, .linked .button:checked:hover:focus {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), inset 0 1px rgba(0, 0, 0, 0.07), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .button.linked:insensitive, .linked .button:insensitive {
      box-shadow: inset -1px 0 #6f4f7c; }
    .button.linked:last-child, .button.linked:only-child, .linked .button:last-child, .linked .button:only-child {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .button.linked:last-child:hover, .button.linked:only-child:hover, .linked .button:last-child:hover, .linked .button:only-child:hover {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .button.linked:insensitive:last-child, .button.linked:insensitive:only-child, .button.linked:active:insensitive:last-child, .button.linked:active:insensitive:only-child, .button.linked:checked:insensitive:last-child, .button.linked:checked:insensitive:only-child, .linked .button:insensitive:last-child, .linked .button:insensitive:only-child, .linked .button:active:insensitive:last-child, .linked .button:active:insensitive:only-child, .linked .button:checked:insensitive:last-child, .linked .button:checked:insensitive:only-child {
      box-shadow: none; }
    .button.linked:active:last-child, .button.linked:active:last-child:focus, .button.linked:active:last-child:hover, .button.linked:active:last-child:hover:focus, .button.linked:checked:last-child, .button.linked:checked:last-child:focus, .button.linked:checked:last-child:hover, .button.linked:checked:last-child:hover:focus, .linked .button:active:last-child, .linked .button:active:last-child:focus, .linked .button:active:last-child:hover, .linked .button:active:last-child:hover:focus, .linked .button:checked:last-child, .linked .button:checked:last-child:focus, .linked .button:checked:last-child:hover, .linked .button:checked:last-child:hover:focus {
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
    .button.linked:active:only-child, .button.linked:active:only-child:focus, .button.linked:active:only-child:hover, .button.linked:active:only-child:hover:focus, .button.linked:checked:only-child, .button.linked:checked:only-child:focus, .button.linked:checked:only-child:hover, .button.linked:checked:only-child:hover:focus, .linked .button:active:only-child, .linked .button:active:only-child:focus, .linked .button:active:only-child:hover, .linked .button:active:only-child:hover:focus, .linked .button:checked:only-child, .linked .button:checked:only-child:focus, .linked .button:checked:only-child:hover, .linked .button:checked:only-child:hover:focus {
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
  .spinbutton .button {
    color: mix(#000000,#d0d0d0,0.4);
    padding: 3px 6px;
    border: 0;
    border-radius: 0;
    border-style: none;
    background-color: transparent;
    background-image: none;
    box-shadow: inset 1px 0 #bbbbbb; }
    .spinbutton .button:insensitive {
      color: mix(#000000,#d0d0d0,0.7);
      box-shadow: inset 1px 0 #b1b1b1; }
    .spinbutton .button:active, .spinbutton .button:checked, .spinbutton .button:hover {
      color: #000000; }
    .spinbutton .button:first-child {
      border-radius: 3px 0 0 3px;
      box-shadow: none; }
    .spinbutton .button:last-child {
      border-radius: 0 3px 3px 0; }
    .spinbutton .button:dir(rtl) {
      box-shadow: inset -1px 0 #bbbbbb; }
  .spinbutton.vertical .button {
    border: 1px solid #848484;
    border-radius: 3px;
    background-color: #b2b2b2;
    background-image: none;
    color: #000000;
    box-shadow: none; }
    .spinbutton.vertical .button:hover {
      border-color: #747474;
      background-color: #b6b6b6;
      background-image: none; }
    .spinbutton.vertical .button:active, .spinbutton.vertical .button:checked {
      border-color: #848484;
      background-color: #9d9d9d;
      background-image: none; }
    .spinbutton.vertical .button:active:hover, .spinbutton.vertical .button:checked:hover {
      border-color: #747474; }
    .spinbutton.vertical .button:focus, .spinbutton.vertical .button:hover:focus, .spinbutton.vertical .button:active:focus, .spinbutton.vertical .button:active:hover:focus {
      border-color: #747474; }
    .spinbutton.vertical .button:insensitive {
      border-color: #8c8c8c;
      background-color: #959595;
      background-image: none; }
    .spinbutton.vertical .button:first-child {
      border-width: 1px;
      border-bottom-width: 0;
      border-bottom-right-radius: 0;
      border-bottom-left-radius: 0; }
    .spinbutton.vertical .button:last-child {
      border-width: 1px;
      border-top-width: 0;
      border-top-left-radius: 0;
      border-top-right-radius: 0; }
  .button .spinbutton.vertical.entry {
    border-width: 1px;
    border-style: solid;
    border-radius: 0; }

/******************
! ComboBoxes *
*******************/
GtkComboBox > .button {
  padding: 1px 4px;
  -GtkComboBox-arrow-scaling: .5;
  -GtkComboBox-shadow-type: none; }

GtkComboBox .separator {
  /* always disable separators */
  -GtkWidget-wide-separators: true;
  -GtkWidget-horizontal-separator: 0;
  -GtkWidget-vertical-separator: 0;
  border-style: none; }

/*********
 ! Entry *
**********/
.entry.linked, .linked .entry {
  border-width: 1px;
  border-radius: 0;
  border-right-width: 0;
  border-left-width: 0; }
  .entry.linked:first-child, .linked .entry:first-child {
    border-width: 1px;
    border-radius: 3px;
    border-right-width: 0;
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }
  .entry.linked:last-child, .linked .entry:last-child {
    border-width: 1px;
    border-radius: 3px;
    border-left-width: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  .entry.linked:only-child, .linked .entry:only-child {
    border-width: 1px;
    border-radius: 3px; }

.entry, .menuitem .entry, GtkPopover .entry {
  padding: 2px 3px;
  border-width: 1px;
  border-style: solid;
  border-radius: 3px;
  transition: border 150ms ease;
  box-shadow: inset 1px 1px rgba(0, 0, 0, 0.06), inset -1px 0 rgba(0, 0, 0, 0.06); }
  .entry:focus, .entry:hover, .entry:active {
    transition: none; }
  .entry:selected, .entry:selected:focus {
    background-color: #B36A87;
    color: #000000; }
  .entry:insensitive {
    box-shadow: none; }
  .progressbar.entry {
    background-color: #B36A87;
    background-image: none;
    border-width: 0;
    border-radius: 3px;
    color: #000000; }
  .image.left.entry {
    padding-right: 3px; }

.entry {
  background-color: #d0d0d0;
  background-image: none;
  border-color: #a6a6a6;
  color: #000000; }
  .entry:focus, .entry:hover {
    border-color: #9c9c9c; }
  .entry:active, .entry:active:hover, .entry:active:focus, .entry:active:hover:focus, .entry:checked, .entry:checked:hover, .entry:checked:focus, .entry:checked:hover:focus {
    border-color: #929292; }
  .entry:insensitive {
    border-color: #b1b1b1; }
  .entry:active:insensitive, .entry:checked:insensitive {
    border-color: #a6a6a6; }
  .entry:focus, .entry:active {
    border-color: #B36A87; }
  .entry:insensitive {
    background-color: #bbbbbb;
    background-image: none;
    color: mix(#d0d0d0,#000000,0.5); }

/*********
 ! Buttons
**********/
/******************
! ComboBoxes *
*******************/
/*********
 ! Buttons
**********/
/******************
! ComboBoxes *
*******************/
/*********
 ! Toolbar
**********/
.toolbar {
  background-color: #a5a5a5;
  background-image: none;
  border-color: #848484;
  padding: 6px;
  color: #000000;
  padding: 2px;
  border-style: none; }
  .toolbar:focus, .toolbar:hover {
    border-color: #7c7c7c; }
  .toolbar:active, .toolbar:active:hover, .toolbar:active:focus, .toolbar:active:hover:focus, .toolbar:checked, .toolbar:checked:hover, .toolbar:checked:focus, .toolbar:checked:hover:focus {
    border-color: #747474; }
  .toolbar:insensitive {
    border-color: #8c8c8c; }
  .toolbar:active:insensitive, .toolbar:checked:insensitive {
    border-color: #848484; }
  .toolbar:insensitive {
    background-color: #959595;
    background-image: none;
    color: mix(#000000,#a5a5a5,0.5); }
  .toolbar .title {
    font: bold;
    padding: 0 6px; }
  .toolbar .subtitle {
    font: smaller;
    padding: 0 6px; }
  .toolbar .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #8b639b;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #000000;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .toolbar .button:focus, .toolbar .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .toolbar .button:active, .toolbar .button:active:hover, .toolbar .button:active:focus, .toolbar .button:active:hover:focus, .toolbar .button:checked, .toolbar .button:checked:hover, .toolbar .button:checked:focus, .toolbar .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .toolbar .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .toolbar .button:active:insensitive, .toolbar .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .toolbar .button.flat {
      border-color: rgba(139, 99, 155, 0);
      background-color: rgba(139, 99, 155, 0);
      background-image: none;
      box-shadow: none; }
    .toolbar .button:focus, .toolbar .button:hover, .toolbar .button.flat:focus, .toolbar .button.flat:hover {
      background-color: #a282af;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .toolbar .button:focus:focus, .toolbar .button:focus:hover, .toolbar .button:hover:focus, .toolbar .button:hover:hover, .toolbar .button.flat:focus:focus, .toolbar .button.flat:focus:hover, .toolbar .button.flat:hover:focus, .toolbar .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .toolbar .button:focus:active, .toolbar .button:focus:active:hover, .toolbar .button:focus:active:focus, .toolbar .button:focus:active:hover:focus, .toolbar .button:focus:checked, .toolbar .button:focus:checked:hover, .toolbar .button:focus:checked:focus, .toolbar .button:focus:checked:hover:focus, .toolbar .button:hover:active, .toolbar .button:hover:active:hover, .toolbar .button:hover:active:focus, .toolbar .button:hover:active:hover:focus, .toolbar .button:hover:checked, .toolbar .button:hover:checked:hover, .toolbar .button:hover:checked:focus, .toolbar .button:hover:checked:hover:focus, .toolbar .button.flat:focus:active, .toolbar .button.flat:focus:active:hover, .toolbar .button.flat:focus:active:focus, .toolbar .button.flat:focus:active:hover:focus, .toolbar .button.flat:focus:checked, .toolbar .button.flat:focus:checked:hover, .toolbar .button.flat:focus:checked:focus, .toolbar .button.flat:focus:checked:hover:focus, .toolbar .button.flat:hover:active, .toolbar .button.flat:hover:active:hover, .toolbar .button.flat:hover:active:focus, .toolbar .button.flat:hover:active:hover:focus, .toolbar .button.flat:hover:checked, .toolbar .button.flat:hover:checked:hover, .toolbar .button.flat:hover:checked:focus, .toolbar .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .toolbar .button:focus:insensitive, .toolbar .button:hover:insensitive, .toolbar .button.flat:focus:insensitive, .toolbar .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .toolbar .button:focus:active:insensitive, .toolbar .button:focus:checked:insensitive, .toolbar .button:hover:active:insensitive, .toolbar .button:hover:checked:insensitive, .toolbar .button.flat:focus:active:insensitive, .toolbar .button.flat:focus:checked:insensitive, .toolbar .button.flat:hover:active:insensitive, .toolbar .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .toolbar .button:active, .toolbar .button:checked, .toolbar .button.flat:active, .toolbar .button.flat:checked {
      background-color: #61456d;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .toolbar .button:active:focus, .toolbar .button:active:hover, .toolbar .button:checked:focus, .toolbar .button:checked:hover, .toolbar .button.flat:active:focus, .toolbar .button.flat:active:hover, .toolbar .button.flat:checked:focus, .toolbar .button.flat:checked:hover {
        background-color: #5a4065;
        background-image: none;
        color: #000000; }
    .toolbar .button:focus, .toolbar .button:hover, .toolbar .button.flat:focus, .toolbar .button.flat:hover {
      color: #000000; }
    .toolbar .button:active:insensitive, .toolbar .button:checked:insensitive, .toolbar .button.flat:active:insensitive, .toolbar .button.flat:checked:insensitive {
      background-color: #7d598c;
      background-image: none;
      color: #000000;
      box-shadow: none; }
    .toolbar .button:insensitive:insensitive, .toolbar .button.flat:insensitive:insensitive {
      background-color: rgba(139, 99, 155, 0.3);
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    .toolbar .button:active {
      color: #000000; }
    .toolbar .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    .toolbar .button.separator, .toolbar .button .separator {
      border: 1px solid currentColor;
      color: #7d598c; }
      .toolbar .button.separator:insensitive, .toolbar .button .separator:insensitive {
        color: #765484; }
  .toolbar .button.linked, .toolbar .linked .button {
    box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .toolbar .button.linked:focus, .toolbar .button.linked:hover, .toolbar .linked .button:focus, .toolbar .linked .button:hover {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .toolbar .button.linked:active, .toolbar .button.linked:active:hover, .toolbar .button.linked:active:focus, .toolbar .button.linked:active:hover:focus, .toolbar .button.linked:checked, .toolbar .button.linked:checked:hover, .toolbar .button.linked:checked:focus, .toolbar .button.linked:checked:hover:focus, .toolbar .linked .button:active, .toolbar .linked .button:active:hover, .toolbar .linked .button:active:focus, .toolbar .linked .button:active:hover:focus, .toolbar .linked .button:checked, .toolbar .linked .button:checked:hover, .toolbar .linked .button:checked:focus, .toolbar .linked .button:checked:hover:focus {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), inset 0 1px rgba(0, 0, 0, 0.07), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .toolbar .button.linked:insensitive, .toolbar .linked .button:insensitive {
      box-shadow: inset -1px 0 #6f4f7c; }
    .toolbar .button.linked:last-child, .toolbar .button.linked:only-child, .toolbar .linked .button:last-child, .toolbar .linked .button:only-child {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .toolbar .button.linked:last-child:hover, .toolbar .button.linked:only-child:hover, .toolbar .linked .button:last-child:hover, .toolbar .linked .button:only-child:hover {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .toolbar .button.linked:insensitive:last-child, .toolbar .button.linked:insensitive:only-child, .toolbar .button.linked:active:insensitive:last-child, .toolbar .button.linked:active:insensitive:only-child, .toolbar .button.linked:checked:insensitive:last-child, .toolbar .button.linked:checked:insensitive:only-child, .toolbar .linked .button:insensitive:last-child, .toolbar .linked .button:insensitive:only-child, .toolbar .linked .button:active:insensitive:last-child, .toolbar .linked .button:active:insensitive:only-child, .toolbar .linked .button:checked:insensitive:last-child, .toolbar .linked .button:checked:insensitive:only-child {
      box-shadow: none; }
    .toolbar .button.linked:active:last-child, .toolbar .button.linked:active:last-child:focus, .toolbar .button.linked:active:last-child:hover, .toolbar .button.linked:active:last-child:hover:focus, .toolbar .button.linked:checked:last-child, .toolbar .button.linked:checked:last-child:focus, .toolbar .button.linked:checked:last-child:hover, .toolbar .button.linked:checked:last-child:hover:focus, .toolbar .linked .button:active:last-child, .toolbar .linked .button:active:last-child:focus, .toolbar .linked .button:active:last-child:hover, .toolbar .linked .button:active:last-child:hover:focus, .toolbar .linked .button:checked:last-child, .toolbar .linked .button:checked:last-child:focus, .toolbar .linked .button:checked:last-child:hover, .toolbar .linked .button:checked:last-child:hover:focus {
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
    .toolbar .button.linked:active:only-child, .toolbar .button.linked:active:only-child:focus, .toolbar .button.linked:active:only-child:hover, .toolbar .button.linked:active:only-child:hover:focus, .toolbar .button.linked:checked:only-child, .toolbar .button.linked:checked:only-child:focus, .toolbar .button.linked:checked:only-child:hover, .toolbar .button.linked:checked:only-child:hover:focus, .toolbar .linked .button:active:only-child, .toolbar .linked .button:active:only-child:focus, .toolbar .linked .button:active:only-child:hover, .toolbar .linked .button:active:only-child:hover:focus, .toolbar .linked .button:checked:only-child, .toolbar .linked .button:checked:only-child:focus, .toolbar .linked .button:checked:only-child:hover, .toolbar .linked .button:checked:only-child:hover:focus {
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
  .toolbar GtkComboBox, .toolbar .button {
    padding: 2px; }
    .toolbar GtkComboBox.text-button, .toolbar .button.text-button {
      padding: 3px; }
    .toolbar GtkComboBox.image-button, .toolbar .button.image-button {
      padding: 4px 2px 4px 3px; }
  .toolbar GtkSeparatorToolItem, .toolbar .separator, .toolbar .separator:insensitive {
    color: #959595;
    border-color: currentColor;
    -GtkWidget-window-dragging: true; }
  .toolbar .menubar {
    -GtkToolbar-button-relief: normal; }
  .toolbar.inline-toolbar {
    background-image: none;
    background-color: transparent; }
  .toolbar GtkToolButton:insensitive GtkButton:insensitive,
  .toolbar GtkToolButton:insensitive GtkButton:insensitive.button,
  .toolbar GtkToolButton:insensitive GtkButton:insensitive.flat.button {
    background-color: #a5a5a5; }

.header-bar {
  background-color: #0f0f0f;
  background-image: none;
  border-color: #0c0c0c;
  padding: 6px;
  color: #a5a5a5;
  border-width: 0 0 1px;
  border-style: solid; }
  .header-bar:focus, .header-bar:hover {
    border-color: #0b0b0b; }
  .header-bar:active, .header-bar:active:hover, .header-bar:active:focus, .header-bar:active:hover:focus, .header-bar:checked, .header-bar:checked:hover, .header-bar:checked:focus, .header-bar:checked:hover:focus {
    border-color: #0b0b0b; }
  .header-bar:insensitive {
    border-color: #0d0d0d; }
  .header-bar:active:insensitive, .header-bar:checked:insensitive {
    border-color: #0c0c0c; }
  .header-bar:insensitive {
    background-color: #0e0e0e;
    background-image: none;
    color: mix(#a5a5a5,#0f0f0f,0.5); }
  .header-bar .title {
    font: bold;
    padding: 0 6px; }
  .header-bar .subtitle {
    font: smaller;
    padding: 0 6px; }
  .header-bar .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #8b639b;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #000000;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .header-bar .button:focus, .header-bar .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .header-bar .button:active, .header-bar .button:active:hover, .header-bar .button:active:focus, .header-bar .button:active:hover:focus, .header-bar .button:checked, .header-bar .button:checked:hover, .header-bar .button:checked:focus, .header-bar .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .header-bar .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .header-bar .button:active:insensitive, .header-bar .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .header-bar .button.flat {
      border-color: rgba(139, 99, 155, 0);
      background-color: rgba(139, 99, 155, 0);
      background-image: none;
      box-shadow: none; }
    .header-bar .button:focus, .header-bar .button:hover, .header-bar .button.flat:focus, .header-bar .button.flat:hover {
      background-color: #a282af;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .header-bar .button:focus:focus, .header-bar .button:focus:hover, .header-bar .button:hover:focus, .header-bar .button:hover:hover, .header-bar .button.flat:focus:focus, .header-bar .button.flat:focus:hover, .header-bar .button.flat:hover:focus, .header-bar .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .header-bar .button:focus:active, .header-bar .button:focus:active:hover, .header-bar .button:focus:active:focus, .header-bar .button:focus:active:hover:focus, .header-bar .button:focus:checked, .header-bar .button:focus:checked:hover, .header-bar .button:focus:checked:focus, .header-bar .button:focus:checked:hover:focus, .header-bar .button:hover:active, .header-bar .button:hover:active:hover, .header-bar .button:hover:active:focus, .header-bar .button:hover:active:hover:focus, .header-bar .button:hover:checked, .header-bar .button:hover:checked:hover, .header-bar .button:hover:checked:focus, .header-bar .button:hover:checked:hover:focus, .header-bar .button.flat:focus:active, .header-bar .button.flat:focus:active:hover, .header-bar .button.flat:focus:active:focus, .header-bar .button.flat:focus:active:hover:focus, .header-bar .button.flat:focus:checked, .header-bar .button.flat:focus:checked:hover, .header-bar .button.flat:focus:checked:focus, .header-bar .button.flat:focus:checked:hover:focus, .header-bar .button.flat:hover:active, .header-bar .button.flat:hover:active:hover, .header-bar .button.flat:hover:active:focus, .header-bar .button.flat:hover:active:hover:focus, .header-bar .button.flat:hover:checked, .header-bar .button.flat:hover:checked:hover, .header-bar .button.flat:hover:checked:focus, .header-bar .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .header-bar .button:focus:insensitive, .header-bar .button:hover:insensitive, .header-bar .button.flat:focus:insensitive, .header-bar .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .header-bar .button:focus:active:insensitive, .header-bar .button:focus:checked:insensitive, .header-bar .button:hover:active:insensitive, .header-bar .button:hover:checked:insensitive, .header-bar .button.flat:focus:active:insensitive, .header-bar .button.flat:focus:checked:insensitive, .header-bar .button.flat:hover:active:insensitive, .header-bar .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .header-bar .button:active, .header-bar .button:checked, .header-bar .button.flat:active, .header-bar .button.flat:checked {
      background-color: #61456d;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .header-bar .button:active:focus, .header-bar .button:active:hover, .header-bar .button:checked:focus, .header-bar .button:checked:hover, .header-bar .button.flat:active:focus, .header-bar .button.flat:active:hover, .header-bar .button.flat:checked:focus, .header-bar .button.flat:checked:hover {
        background-color: #5a4065;
        background-image: none;
        color: #000000; }
    .header-bar .button:focus, .header-bar .button:hover, .header-bar .button.flat:focus, .header-bar .button.flat:hover {
      color: #000000; }
    .header-bar .button:active:insensitive, .header-bar .button:checked:insensitive, .header-bar .button.flat:active:insensitive, .header-bar .button.flat:checked:insensitive {
      background-color: #7d598c;
      background-image: none;
      color: #000000;
      box-shadow: none; }
    .header-bar .button:insensitive:insensitive, .header-bar .button.flat:insensitive:insensitive {
      background-color: rgba(139, 99, 155, 0.3);
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    .header-bar .button:active {
      color: #000000; }
    .header-bar .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    .header-bar .button.separator, .header-bar .button .separator {
      border: 1px solid currentColor;
      color: #7d598c; }
      .header-bar .button.separator:insensitive, .header-bar .button .separator:insensitive {
        color: #765484; }
  .header-bar .button.linked, .header-bar .linked .button {
    box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .header-bar .button.linked:focus, .header-bar .button.linked:hover, .header-bar .linked .button:focus, .header-bar .linked .button:hover {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .header-bar .button.linked:active, .header-bar .button.linked:active:hover, .header-bar .button.linked:active:focus, .header-bar .button.linked:active:hover:focus, .header-bar .button.linked:checked, .header-bar .button.linked:checked:hover, .header-bar .button.linked:checked:focus, .header-bar .button.linked:checked:hover:focus, .header-bar .linked .button:active, .header-bar .linked .button:active:hover, .header-bar .linked .button:active:focus, .header-bar .linked .button:active:hover:focus, .header-bar .linked .button:checked, .header-bar .linked .button:checked:hover, .header-bar .linked .button:checked:focus, .header-bar .linked .button:checked:hover:focus {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), inset 0 1px rgba(0, 0, 0, 0.07), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .header-bar .button.linked:insensitive, .header-bar .linked .button:insensitive {
      box-shadow: inset -1px 0 #6f4f7c; }
    .header-bar .button.linked:last-child, .header-bar .button.linked:only-child, .header-bar .linked .button:last-child, .header-bar .linked .button:only-child {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .header-bar .button.linked:last-child:hover, .header-bar .button.linked:only-child:hover, .header-bar .linked .button:last-child:hover, .header-bar .linked .button:only-child:hover {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .header-bar .button.linked:insensitive:last-child, .header-bar .button.linked:insensitive:only-child, .header-bar .button.linked:active:insensitive:last-child, .header-bar .button.linked:active:insensitive:only-child, .header-bar .button.linked:checked:insensitive:last-child, .header-bar .button.linked:checked:insensitive:only-child, .header-bar .linked .button:insensitive:last-child, .header-bar .linked .button:insensitive:only-child, .header-bar .linked .button:active:insensitive:last-child, .header-bar .linked .button:active:insensitive:only-child, .header-bar .linked .button:checked:insensitive:last-child, .header-bar .linked .button:checked:insensitive:only-child {
      box-shadow: none; }
    .header-bar .button.linked:active:last-child, .header-bar .button.linked:active:last-child:focus, .header-bar .button.linked:active:last-child:hover, .header-bar .button.linked:active:last-child:hover:focus, .header-bar .button.linked:checked:last-child, .header-bar .button.linked:checked:last-child:focus, .header-bar .button.linked:checked:last-child:hover, .header-bar .button.linked:checked:last-child:hover:focus, .header-bar .linked .button:active:last-child, .header-bar .linked .button:active:last-child:focus, .header-bar .linked .button:active:last-child:hover, .header-bar .linked .button:active:last-child:hover:focus, .header-bar .linked .button:checked:last-child, .header-bar .linked .button:checked:last-child:focus, .header-bar .linked .button:checked:last-child:hover, .header-bar .linked .button:checked:last-child:hover:focus {
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
    .header-bar .button.linked:active:only-child, .header-bar .button.linked:active:only-child:focus, .header-bar .button.linked:active:only-child:hover, .header-bar .button.linked:active:only-child:hover:focus, .header-bar .button.linked:checked:only-child, .header-bar .button.linked:checked:only-child:focus, .header-bar .button.linked:checked:only-child:hover, .header-bar .button.linked:checked:only-child:hover:focus, .header-bar .linked .button:active:only-child, .header-bar .linked .button:active:only-child:focus, .header-bar .linked .button:active:only-child:hover, .header-bar .linked .button:active:only-child:hover:focus, .header-bar .linked .button:checked:only-child, .header-bar .linked .button:checked:only-child:focus, .header-bar .linked .button:checked:only-child:hover, .header-bar .linked .button:checked:only-child:hover:focus {
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
  .header-bar GtkComboBox, .header-bar .button {
    padding: 2px; }
    .header-bar GtkComboBox.text-button, .header-bar .button.text-button {
      padding: 3px; }
    .header-bar GtkComboBox.image-button, .header-bar .button.image-button {
      padding: 4px 2px 4px 3px; }
  .header-bar GtkSeparatorToolItem, .header-bar .separator, .header-bar .separator:insensitive {
    color: #0e0e0e;
    border-color: currentColor;
    -GtkWidget-window-dragging: true; }
  .header-bar .menubar {
    -GtkToolbar-button-relief: normal; }
  .header-bar .button {
    color: #000000; }

.titlebar {
  background-color: #0f0f0f;
  background-image: none;
  border-radius: 3px 3px 0 0;
  color: mix(#a5a5a5,#0f0f0f,0.1); }
  .titlebar:backdrop {
    background-color: #0f0f0f;
    background-image: none;
    color: mix(#a5a5a5,#0f0f0f,0.6);
    text-shadow: none; }
  .titlebar.default-decoration {
    border: 0;
    box-shadow: none; }
  .tiled .titlebar, .maximized .titlebar {
    border-radius: 0; }
  .titlebar .title {
    font: bold; }
  .titlebar .titlebutton {
    padding: 3px;
    border: 0;
    background-image: none;
    background-color: transparent;
    color: mix(#a5a5a5,#0f0f0f,0.1);
    box-shadow: none; }
    .titlebar .titlebutton:hover, .titlebar .titlebutton:hover:focus {
      background-image: none;
      background-color: transparent;
      color: #B36A87;
      box-shadow: none; }
    .titlebar .titlebutton:active, .titlebar .titlebutton:active:hover {
      background-image: none;
      background-color: transparent;
      color: #a95778;
      box-shadow: none; }
    .titlebar .titlebutton:backdrop {
      background: none;
      color: mix(#a5a5a5,#0f0f0f,0.6);
      icon-shadow: none; }

/**************
 ! Action-bar *
***************/
.action-bar {
  background-color: #a5a5a5;
  background-image: none;
  padding: 3px;
  border-width: 1px 0 0;
  border-style: solid;
  border-color: #848484;
  color: #000000; }
  .action-bar .button.text-button {
    padding: 2px; }
  .action-bar .button.image-button {
    padding: 4px; }
  .action-bar .title {
    font: bold;
    padding: 0 6px; }
  .action-bar .subtitle {
    font: smaller;
    padding: 0 6px; }

/***************
 ! Search bars *
****************/
.search-bar {
  background-color: #a2a2a2;
  background-image: none;
  border-width: 0 0 1px;
  border-style: solid;
  border-color: #848484;
  color: #000000; }
  .search-bar .button.close-button {
    padding: 3px; }

/******************
 ! Action buttons *
*******************/
.suggested-action.button, .selection-mode.header-bar .button.suggested-action, .selection-mode.toolbar .button.suggested-action {
  /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
  background-color: #4caf50;
  background-image: none;
  border-color: rgba(0, 0, 0, 0.22);
  color: #000000;
  box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
  .suggested-action.button:focus, .selection-mode.header-bar .button.suggested-action:focus, .selection-mode.toolbar .button.suggested-action:focus, .suggested-action.button:hover, .selection-mode.header-bar .button.suggested-action:hover, .selection-mode.toolbar .button.suggested-action:hover {
    border-color: rgba(0, 0, 0, 0.22); }
  .suggested-action.button:active, .selection-mode.header-bar .button.suggested-action:active, .selection-mode.toolbar .button.suggested-action:active, .suggested-action.button:active:hover, .suggested-action.button:active:focus, .suggested-action.button:active:hover:focus, .suggested-action.button:checked, .selection-mode.header-bar .button.suggested-action:checked, .selection-mode.toolbar .button.suggested-action:checked, .suggested-action.button:checked:hover, .suggested-action.button:checked:focus, .suggested-action.button:checked:hover:focus {
    border-color: rgba(0, 0, 0, 0.22); }
  .suggested-action.button:insensitive, .selection-mode.header-bar .button.suggested-action:insensitive, .selection-mode.toolbar .button.suggested-action:insensitive {
    border-color: rgba(0, 0, 0, 0.22); }
  .suggested-action.button:active:insensitive, .suggested-action.button:checked:insensitive {
    border-color: rgba(0, 0, 0, 0.22); }
  .suggested-action.button.flat, .selection-mode.header-bar .flat.button.suggested-action, .selection-mode.toolbar .flat.button.suggested-action {
    border-color: rgba(76, 175, 80, 0);
    background-color: rgba(76, 175, 80, 0);
    background-image: none;
    box-shadow: none; }
  .suggested-action.button:focus, .selection-mode.header-bar .button.suggested-action:focus, .selection-mode.toolbar .button.suggested-action:focus, .suggested-action.button:hover, .selection-mode.header-bar .button.suggested-action:hover, .selection-mode.toolbar .button.suggested-action:hover, .suggested-action.button.flat:focus, .suggested-action.button.flat:hover {
    background-color: #6dc071;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.3);
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .suggested-action.button:focus:focus, .suggested-action.button:focus:hover, .suggested-action.button:hover:focus, .suggested-action.button:hover:hover, .suggested-action.button.flat:focus:focus, .suggested-action.button.flat:focus:hover, .suggested-action.button.flat:hover:focus, .suggested-action.button.flat:hover:hover {
      border-color: rgba(0, 0, 0, 0.3); }
    .suggested-action.button:focus:active, .suggested-action.button:focus:active:hover, .suggested-action.button:focus:active:focus, .suggested-action.button:focus:active:hover:focus, .suggested-action.button:focus:checked, .suggested-action.button:focus:checked:hover, .suggested-action.button:focus:checked:focus, .suggested-action.button:focus:checked:hover:focus, .suggested-action.button:hover:active, .suggested-action.button:hover:active:hover, .suggested-action.button:hover:active:focus, .suggested-action.button:hover:active:hover:focus, .suggested-action.button:hover:checked, .suggested-action.button:hover:checked:hover, .suggested-action.button:hover:checked:focus, .suggested-action.button:hover:checked:hover:focus, .suggested-action.button.flat:focus:active, .suggested-action.button.flat:focus:active:hover, .suggested-action.button.flat:focus:active:focus, .suggested-action.button.flat:focus:active:hover:focus, .suggested-action.button.flat:focus:checked, .suggested-action.button.flat:focus:checked:hover, .suggested-action.button.flat:focus:checked:focus, .suggested-action.button.flat:focus:checked:hover:focus, .suggested-action.button.flat:hover:active, .suggested-action.button.flat:hover:active:hover, .suggested-action.button.flat:hover:active:focus, .suggested-action.button.flat:hover:active:hover:focus, .suggested-action.button.flat:hover:checked, .suggested-action.button.flat:hover:checked:hover, .suggested-action.button.flat:hover:checked:focus, .suggested-action.button.flat:hover:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.3); }
    .suggested-action.button:focus:insensitive, .suggested-action.button:hover:insensitive, .suggested-action.button.flat:focus:insensitive, .suggested-action.button.flat:hover:insensitive {
      border-color: rgba(0, 0, 0, 0.3); }
    .suggested-action.button:focus:active:insensitive, .suggested-action.button:focus:checked:insensitive, .suggested-action.button:hover:active:insensitive, .suggested-action.button:hover:checked:insensitive, .suggested-action.button.flat:focus:active:insensitive, .suggested-action.button.flat:focus:checked:insensitive, .suggested-action.button.flat:hover:active:insensitive, .suggested-action.button.flat:hover:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.3); }
  .suggested-action.button:active, .selection-mode.header-bar .button.suggested-action:active, .selection-mode.toolbar .button.suggested-action:active, .suggested-action.button:checked, .selection-mode.header-bar .button.suggested-action:checked, .selection-mode.toolbar .button.suggested-action:checked, .suggested-action.button.flat:active, .suggested-action.button.flat:checked {
    background-color: #357b38;
    background-image: none;
    color: #000000;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .suggested-action.button:active:focus, .suggested-action.button:active:hover, .suggested-action.button:checked:focus, .suggested-action.button:checked:hover, .suggested-action.button.flat:active:focus, .suggested-action.button.flat:active:hover, .suggested-action.button.flat:checked:focus, .suggested-action.button.flat:checked:hover {
      background-color: #317234;
      background-image: none;
      color: #000000; }
  .suggested-action.button:focus, .selection-mode.header-bar .button.suggested-action:focus, .selection-mode.toolbar .button.suggested-action:focus, .suggested-action.button:hover, .selection-mode.header-bar .button.suggested-action:hover, .selection-mode.toolbar .button.suggested-action:hover, .suggested-action.button.flat:focus, .suggested-action.button.flat:hover {
    color: #000000; }
  .suggested-action.button:active:insensitive, .suggested-action.button:checked:insensitive, .suggested-action.button.flat:active:insensitive, .suggested-action.button.flat:checked:insensitive {
    background-color: #449e48;
    background-image: none;
    color: #000000;
    box-shadow: none; }
  .suggested-action.button:insensitive:insensitive, .suggested-action.button.flat:insensitive:insensitive {
    background-color: rgba(76, 175, 80, 0.3);
    background-image: none;
    color: mix(#4caf50,#000000,0.5);
    box-shadow: none; }
  .suggested-action.button:active, .selection-mode.header-bar .button.suggested-action:active, .selection-mode.toolbar .button.suggested-action:active {
    color: #000000; }
  .suggested-action.button.flat:insensitive:insensitive {
    background-color: transparent;
    background-image: none;
    color: mix(#4caf50,#000000,0.5);
    box-shadow: none; }
  .suggested-action.button.separator, .selection-mode.header-bar .separator.button.suggested-action, .selection-mode.toolbar .separator.button.suggested-action, .suggested-action.button .separator, .selection-mode.header-bar .button.suggested-action .separator, .selection-mode.toolbar .button.suggested-action .separator {
    border: 1px solid currentColor;
    color: #449e48; }
    .suggested-action.button.separator:insensitive, .suggested-action.button .separator:insensitive {
      color: #419544; }

.destructive-action.button {
  /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
  background-color: #f44336;
  background-image: none;
  border-color: rgba(0, 0, 0, 0.12);
  color: #000000;
  box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.12); }
  .destructive-action.button:focus, .destructive-action.button:hover {
    border-color: rgba(0, 0, 0, 0.12); }
  .destructive-action.button:active, .destructive-action.button:active:hover, .destructive-action.button:active:focus, .destructive-action.button:active:hover:focus, .destructive-action.button:checked, .destructive-action.button:checked:hover, .destructive-action.button:checked:focus, .destructive-action.button:checked:hover:focus {
    border-color: rgba(0, 0, 0, 0.12); }
  .destructive-action.button:insensitive {
    border-color: rgba(0, 0, 0, 0.12); }
  .destructive-action.button:active:insensitive, .destructive-action.button:checked:insensitive {
    border-color: rgba(0, 0, 0, 0.12); }
  .destructive-action.button.flat {
    border-color: rgba(244, 67, 54, 0);
    background-color: rgba(244, 67, 54, 0);
    background-image: none;
    box-shadow: none; }
  .destructive-action.button:focus, .destructive-action.button:hover, .destructive-action.button.flat:focus, .destructive-action.button.flat:hover {
    background-color: #f7786f;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.2);
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.32); }
    .destructive-action.button:focus:focus, .destructive-action.button:focus:hover, .destructive-action.button:hover:focus, .destructive-action.button:hover:hover, .destructive-action.button.flat:focus:focus, .destructive-action.button.flat:focus:hover, .destructive-action.button.flat:hover:focus, .destructive-action.button.flat:hover:hover {
      border-color: rgba(0, 0, 0, 0.2); }
    .destructive-action.button:focus:active, .destructive-action.button:focus:active:hover, .destructive-action.button:focus:active:focus, .destructive-action.button:focus:active:hover:focus, .destructive-action.button:focus:checked, .destructive-action.button:focus:checked:hover, .destructive-action.button:focus:checked:focus, .destructive-action.button:focus:checked:hover:focus, .destructive-action.button:hover:active, .destructive-action.button:hover:active:hover, .destructive-action.button:hover:active:focus, .destructive-action.button:hover:active:hover:focus, .destructive-action.button:hover:checked, .destructive-action.button:hover:checked:hover, .destructive-action.button:hover:checked:focus, .destructive-action.button:hover:checked:hover:focus, .destructive-action.button.flat:focus:active, .destructive-action.button.flat:focus:active:hover, .destructive-action.button.flat:focus:active:focus, .destructive-action.button.flat:focus:active:hover:focus, .destructive-action.button.flat:focus:checked, .destructive-action.button.flat:focus:checked:hover, .destructive-action.button.flat:focus:checked:focus, .destructive-action.button.flat:focus:checked:hover:focus, .destructive-action.button.flat:hover:active, .destructive-action.button.flat:hover:active:hover, .destructive-action.button.flat:hover:active:focus, .destructive-action.button.flat:hover:active:hover:focus, .destructive-action.button.flat:hover:checked, .destructive-action.button.flat:hover:checked:hover, .destructive-action.button.flat:hover:checked:focus, .destructive-action.button.flat:hover:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.2); }
    .destructive-action.button:focus:insensitive, .destructive-action.button:hover:insensitive, .destructive-action.button.flat:focus:insensitive, .destructive-action.button.flat:hover:insensitive {
      border-color: rgba(0, 0, 0, 0.2); }
    .destructive-action.button:focus:active:insensitive, .destructive-action.button:focus:checked:insensitive, .destructive-action.button:hover:active:insensitive, .destructive-action.button:hover:checked:insensitive, .destructive-action.button.flat:focus:active:insensitive, .destructive-action.button.flat:focus:checked:insensitive, .destructive-action.button.flat:hover:active:insensitive, .destructive-action.button.flat:hover:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.2); }
  .destructive-action.button:active, .destructive-action.button:checked, .destructive-action.button.flat:active, .destructive-action.button.flat:checked {
    background-color: #c6180b;
    background-image: none;
    color: #000000;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .destructive-action.button:active:focus, .destructive-action.button:active:hover, .destructive-action.button:checked:focus, .destructive-action.button:checked:hover, .destructive-action.button.flat:active:focus, .destructive-action.button.flat:active:hover, .destructive-action.button.flat:checked:focus, .destructive-action.button.flat:checked:hover {
      background-color: #b8160a;
      background-image: none;
      color: #000000; }
  .destructive-action.button:focus, .destructive-action.button:hover, .destructive-action.button.flat:focus, .destructive-action.button.flat:hover {
    color: #000000; }
  .destructive-action.button:active:insensitive, .destructive-action.button:checked:insensitive, .destructive-action.button.flat:active:insensitive, .destructive-action.button.flat:checked:insensitive {
    background-color: #f2291a;
    background-image: none;
    color: #000000;
    box-shadow: none; }
  .destructive-action.button:insensitive:insensitive, .destructive-action.button.flat:insensitive:insensitive {
    background-color: #f33628;
    background-image: none;
    color: mix(#f44336,#000000,0.5);
    box-shadow: none; }
  .destructive-action.button:active {
    color: #000000; }
  .destructive-action.button.flat:insensitive:insensitive {
    background-color: transparent;
    background-image: none;
    color: mix(#f44336,#000000,0.5);
    box-shadow: none; }
  .destructive-action.button.separator, .destructive-action.button .separator {
    border: 1px solid currentColor;
    color: #f2291a; }
    .destructive-action.button.separator:insensitive, .destructive-action.button .separator:insensitive {
      color: #f01d0d; }

/******************
* selection mode *
******************/
.selection-mode.header-bar, .selection-mode.toolbar {
  background-color: #B36A87;
  background-image: none;
  border-color: #974d6a;
  padding: 6px;
  color: #000000; }
  .selection-mode.header-bar:focus, .selection-mode.header-bar:hover, .selection-mode.toolbar:focus, .selection-mode.toolbar:hover {
    border-color: #8e4864; }
  .selection-mode.header-bar:active, .selection-mode.header-bar:active:hover, .selection-mode.header-bar:active:focus, .selection-mode.header-bar:active:hover:focus, .selection-mode.header-bar:checked, .selection-mode.header-bar:checked:hover, .selection-mode.header-bar:checked:focus, .selection-mode.header-bar:checked:hover:focus, .selection-mode.toolbar:active, .selection-mode.toolbar:active:hover, .selection-mode.toolbar:active:focus, .selection-mode.toolbar:active:hover:focus, .selection-mode.toolbar:checked, .selection-mode.toolbar:checked:hover, .selection-mode.toolbar:checked:focus, .selection-mode.toolbar:checked:hover:focus {
    border-color: #84435d; }
  .selection-mode.header-bar:insensitive, .selection-mode.toolbar:insensitive {
    border-color: #a05271; }
  .selection-mode.header-bar:active:insensitive, .selection-mode.header-bar:checked:insensitive, .selection-mode.toolbar:active:insensitive, .selection-mode.toolbar:checked:insensitive {
    border-color: #974d6a; }
  .selection-mode.header-bar:insensitive, .selection-mode.toolbar:insensitive {
    background-color: #a95778;
    background-image: none;
    color: mix(#000000,#B36A87,0.5); }
  .selection-mode.header-bar .title, .selection-mode.toolbar .title {
    font: bold;
    padding: 0 6px; }
  .selection-mode.header-bar .subtitle, .selection-mode.toolbar .subtitle {
    font: smaller;
    padding: 0 6px; }
  .selection-mode.header-bar .button, .selection-mode.toolbar .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #8b639b;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #000000;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button:focus, .selection-mode.header-bar .button:hover, .selection-mode.toolbar .button:focus, .selection-mode.toolbar .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button:active, .selection-mode.header-bar .button:active:hover, .selection-mode.header-bar .button:active:focus, .selection-mode.header-bar .button:active:hover:focus, .selection-mode.header-bar .button:checked, .selection-mode.header-bar .button:checked:hover, .selection-mode.header-bar .button:checked:focus, .selection-mode.header-bar .button:checked:hover:focus, .selection-mode.toolbar .button:active, .selection-mode.toolbar .button:active:hover, .selection-mode.toolbar .button:active:focus, .selection-mode.toolbar .button:active:hover:focus, .selection-mode.toolbar .button:checked, .selection-mode.toolbar .button:checked:hover, .selection-mode.toolbar .button:checked:focus, .selection-mode.toolbar .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button:insensitive, .selection-mode.toolbar .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button:active:insensitive, .selection-mode.header-bar .button:checked:insensitive, .selection-mode.toolbar .button:active:insensitive, .selection-mode.toolbar .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button.flat, .selection-mode.toolbar .button.flat {
      border-color: rgba(139, 99, 155, 0);
      background-color: rgba(139, 99, 155, 0);
      background-image: none;
      box-shadow: none; }
    .selection-mode.header-bar .button:focus, .selection-mode.header-bar .button:hover, .selection-mode.header-bar .button.flat:focus, .selection-mode.header-bar .button.flat:hover, .selection-mode.toolbar .button:focus, .selection-mode.toolbar .button:hover, .selection-mode.toolbar .button.flat:focus, .selection-mode.toolbar .button.flat:hover {
      background-color: #a282af;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .selection-mode.header-bar .button:focus:focus, .selection-mode.header-bar .button:focus:hover, .selection-mode.header-bar .button:hover:focus, .selection-mode.header-bar .button:hover:hover, .selection-mode.header-bar .button.flat:focus:focus, .selection-mode.header-bar .button.flat:focus:hover, .selection-mode.header-bar .button.flat:hover:focus, .selection-mode.header-bar .button.flat:hover:hover, .selection-mode.toolbar .button:focus:focus, .selection-mode.toolbar .button:focus:hover, .selection-mode.toolbar .button:hover:focus, .selection-mode.toolbar .button:hover:hover, .selection-mode.toolbar .button.flat:focus:focus, .selection-mode.toolbar .button.flat:focus:hover, .selection-mode.toolbar .button.flat:hover:focus, .selection-mode.toolbar .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .selection-mode.header-bar .button:focus:active, .selection-mode.header-bar .button:focus:active:hover, .selection-mode.header-bar .button:focus:active:focus, .selection-mode.header-bar .button:focus:active:hover:focus, .selection-mode.header-bar .button:focus:checked, .selection-mode.header-bar .button:focus:checked:hover, .selection-mode.header-bar .button:focus:checked:focus, .selection-mode.header-bar .button:focus:checked:hover:focus, .selection-mode.header-bar .button:hover:active, .selection-mode.header-bar .button:hover:active:hover, .selection-mode.header-bar .button:hover:active:focus, .selection-mode.header-bar .button:hover:active:hover:focus, .selection-mode.header-bar .button:hover:checked, .selection-mode.header-bar .button:hover:checked:hover, .selection-mode.header-bar .button:hover:checked:focus, .selection-mode.header-bar .button:hover:checked:hover:focus, .selection-mode.header-bar .button.flat:focus:active, .selection-mode.header-bar .button.flat:focus:active:hover, .selection-mode.header-bar .button.flat:focus:active:focus, .selection-mode.header-bar .button.flat:focus:active:hover:focus, .selection-mode.header-bar .button.flat:focus:checked, .selection-mode.header-bar .button.flat:focus:checked:hover, .selection-mode.header-bar .button.flat:focus:checked:focus, .selection-mode.header-bar .button.flat:focus:checked:hover:focus, .selection-mode.header-bar .button.flat:hover:active, .selection-mode.header-bar .button.flat:hover:active:hover, .selection-mode.header-bar .button.flat:hover:active:focus, .selection-mode.header-bar .button.flat:hover:active:hover:focus, .selection-mode.header-bar .button.flat:hover:checked, .selection-mode.header-bar .button.flat:hover:checked:hover, .selection-mode.header-bar .button.flat:hover:checked:focus, .selection-mode.header-bar .button.flat:hover:checked:hover:focus, .selection-mode.toolbar .button:focus:active, .selection-mode.toolbar .button:focus:active:hover, .selection-mode.toolbar .button:focus:active:focus, .selection-mode.toolbar .button:focus:active:hover:focus, .selection-mode.toolbar .button:focus:checked, .selection-mode.toolbar .button:focus:checked:hover, .selection-mode.toolbar .button:focus:checked:focus, .selection-mode.toolbar .button:focus:checked:hover:focus, .selection-mode.toolbar .button:hover:active, .selection-mode.toolbar .button:hover:active:hover, .selection-mode.toolbar .button:hover:active:focus, .selection-mode.toolbar .button:hover:active:hover:focus, .selection-mode.toolbar .button:hover:checked, .selection-mode.toolbar .button:hover:checked:hover, .selection-mode.toolbar .button:hover:checked:focus, .selection-mode.toolbar .button:hover:checked:hover:focus, .selection-mode.toolbar .button.flat:focus:active, .selection-mode.toolbar .button.flat:focus:active:hover, .selection-mode.toolbar .button.flat:focus:active:focus, .selection-mode.toolbar .button.flat:focus:active:hover:focus, .selection-mode.toolbar .button.flat:focus:checked, .selection-mode.toolbar .button.flat:focus:checked:hover, .selection-mode.toolbar .button.flat:focus:checked:focus, .selection-mode.toolbar .button.flat:focus:checked:hover:focus, .selection-mode.toolbar .button.flat:hover:active, .selection-mode.toolbar .button.flat:hover:active:hover, .selection-mode.toolbar .button.flat:hover:active:focus, .selection-mode.toolbar .button.flat:hover:active:hover:focus, .selection-mode.toolbar .button.flat:hover:checked, .selection-mode.toolbar .button.flat:hover:checked:hover, .selection-mode.toolbar .button.flat:hover:checked:focus, .selection-mode.toolbar .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .selection-mode.header-bar .button:focus:insensitive, .selection-mode.header-bar .button:hover:insensitive, .selection-mode.header-bar .button.flat:focus:insensitive, .selection-mode.header-bar .button.flat:hover:insensitive, .selection-mode.toolbar .button:focus:insensitive, .selection-mode.toolbar .button:hover:insensitive, .selection-mode.toolbar .button.flat:focus:insensitive, .selection-mode.toolbar .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .selection-mode.header-bar .button:focus:active:insensitive, .selection-mode.header-bar .button:focus:checked:insensitive, .selection-mode.header-bar .button:hover:active:insensitive, .selection-mode.header-bar .button:hover:checked:insensitive, .selection-mode.header-bar .button.flat:focus:active:insensitive, .selection-mode.header-bar .button.flat:focus:checked:insensitive, .selection-mode.header-bar .button.flat:hover:active:insensitive, .selection-mode.header-bar .button.flat:hover:checked:insensitive, .selection-mode.toolbar .button:focus:active:insensitive, .selection-mode.toolbar .button:focus:checked:insensitive, .selection-mode.toolbar .button:hover:active:insensitive, .selection-mode.toolbar .button:hover:checked:insensitive, .selection-mode.toolbar .button.flat:focus:active:insensitive, .selection-mode.toolbar .button.flat:focus:checked:insensitive, .selection-mode.toolbar .button.flat:hover:active:insensitive, .selection-mode.toolbar .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .selection-mode.header-bar .button:active, .selection-mode.header-bar .button:checked, .selection-mode.header-bar .button.flat:active, .selection-mode.header-bar .button.flat:checked, .selection-mode.toolbar .button:active, .selection-mode.toolbar .button:checked, .selection-mode.toolbar .button.flat:active, .selection-mode.toolbar .button.flat:checked {
      background-color: #61456d;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .selection-mode.header-bar .button:active:focus, .selection-mode.header-bar .button:active:hover, .selection-mode.header-bar .button:checked:focus, .selection-mode.header-bar .button:checked:hover, .selection-mode.header-bar .button.flat:active:focus, .selection-mode.header-bar .button.flat:active:hover, .selection-mode.header-bar .button.flat:checked:focus, .selection-mode.header-bar .button.flat:checked:hover, .selection-mode.toolbar .button:active:focus, .selection-mode.toolbar .button:active:hover, .selection-mode.toolbar .button:checked:focus, .selection-mode.toolbar .button:checked:hover, .selection-mode.toolbar .button.flat:active:focus, .selection-mode.toolbar .button.flat:active:hover, .selection-mode.toolbar .button.flat:checked:focus, .selection-mode.toolbar .button.flat:checked:hover {
        background-color: #5a4065;
        background-image: none;
        color: #000000; }
    .selection-mode.header-bar .button:focus, .selection-mode.header-bar .button:hover, .selection-mode.header-bar .button.flat:focus, .selection-mode.header-bar .button.flat:hover, .selection-mode.toolbar .button:focus, .selection-mode.toolbar .button:hover, .selection-mode.toolbar .button.flat:focus, .selection-mode.toolbar .button.flat:hover {
      color: #000000; }
    .selection-mode.header-bar .button:active:insensitive, .selection-mode.header-bar .button:checked:insensitive, .selection-mode.header-bar .button.flat:active:insensitive, .selection-mode.header-bar .button.flat:checked:insensitive, .selection-mode.toolbar .button:active:insensitive, .selection-mode.toolbar .button:checked:insensitive, .selection-mode.toolbar .button.flat:active:insensitive, .selection-mode.toolbar .button.flat:checked:insensitive {
      background-color: #7d598c;
      background-image: none;
      color: #000000;
      box-shadow: none; }
    .selection-mode.header-bar .button:insensitive:insensitive, .selection-mode.header-bar .button.flat:insensitive:insensitive, .selection-mode.toolbar .button:insensitive:insensitive, .selection-mode.toolbar .button.flat:insensitive:insensitive {
      background-color: rgba(139, 99, 155, 0.3);
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    .selection-mode.header-bar .button:active, .selection-mode.toolbar .button:active {
      color: #000000; }
    .selection-mode.header-bar .button.flat:insensitive:insensitive, .selection-mode.toolbar .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    .selection-mode.header-bar .button.separator, .selection-mode.header-bar .button .separator, .selection-mode.toolbar .button.separator, .selection-mode.toolbar .button .separator {
      border: 1px solid currentColor;
      color: #7d598c; }
      .selection-mode.header-bar .button.separator:insensitive, .selection-mode.header-bar .button .separator:insensitive, .selection-mode.toolbar .button.separator:insensitive, .selection-mode.toolbar .button .separator:insensitive {
        color: #765484; }
  .selection-mode.header-bar .button.linked, .selection-mode.header-bar .linked .button, .selection-mode.toolbar .button.linked, .selection-mode.toolbar .linked .button {
    box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button.linked:focus, .selection-mode.header-bar .button.linked:hover, .selection-mode.header-bar .linked .button:focus, .selection-mode.header-bar .linked .button:hover, .selection-mode.toolbar .button.linked:focus, .selection-mode.toolbar .button.linked:hover, .selection-mode.toolbar .linked .button:focus, .selection-mode.toolbar .linked .button:hover {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .selection-mode.header-bar .button.linked:active, .selection-mode.header-bar .button.linked:active:hover, .selection-mode.header-bar .button.linked:active:focus, .selection-mode.header-bar .button.linked:active:hover:focus, .selection-mode.header-bar .button.linked:checked, .selection-mode.header-bar .button.linked:checked:hover, .selection-mode.header-bar .button.linked:checked:focus, .selection-mode.header-bar .button.linked:checked:hover:focus, .selection-mode.header-bar .linked .button:active, .selection-mode.header-bar .linked .button:active:hover, .selection-mode.header-bar .linked .button:active:focus, .selection-mode.header-bar .linked .button:active:hover:focus, .selection-mode.header-bar .linked .button:checked, .selection-mode.header-bar .linked .button:checked:hover, .selection-mode.header-bar .linked .button:checked:focus, .selection-mode.header-bar .linked .button:checked:hover:focus, .selection-mode.toolbar .button.linked:active, .selection-mode.toolbar .button.linked:active:hover, .selection-mode.toolbar .button.linked:active:focus, .selection-mode.toolbar .button.linked:active:hover:focus, .selection-mode.toolbar .button.linked:checked, .selection-mode.toolbar .button.linked:checked:hover, .selection-mode.toolbar .button.linked:checked:focus, .selection-mode.toolbar .button.linked:checked:hover:focus, .selection-mode.toolbar .linked .button:active, .selection-mode.toolbar .linked .button:active:hover, .selection-mode.toolbar .linked .button:active:focus, .selection-mode.toolbar .linked .button:active:hover:focus, .selection-mode.toolbar .linked .button:checked, .selection-mode.toolbar .linked .button:checked:hover, .selection-mode.toolbar .linked .button:checked:focus, .selection-mode.toolbar .linked .button:checked:hover:focus {
      box-shadow: inset -1px 0 rgba(0, 0, 0, 0.22), inset 0 1px rgba(0, 0, 0, 0.07), inset 0 -1px rgba(0, 0, 0, 0.05); }
    .selection-mode.header-bar .button.linked:insensitive, .selection-mode.header-bar .linked .button:insensitive, .selection-mode.toolbar .button.linked:insensitive, .selection-mode.toolbar .linked .button:insensitive {
      box-shadow: inset -1px 0 #6f4f7c; }
    .selection-mode.header-bar .button.linked:last-child, .selection-mode.header-bar .button.linked:only-child, .selection-mode.header-bar .linked .button:last-child, .selection-mode.header-bar .linked .button:only-child, .selection-mode.toolbar .button.linked:last-child, .selection-mode.toolbar .button.linked:only-child, .selection-mode.toolbar .linked .button:last-child, .selection-mode.toolbar .linked .button:only-child {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .selection-mode.header-bar .button.linked:last-child:hover, .selection-mode.header-bar .button.linked:only-child:hover, .selection-mode.header-bar .linked .button:last-child:hover, .selection-mode.header-bar .linked .button:only-child:hover, .selection-mode.toolbar .button.linked:last-child:hover, .selection-mode.toolbar .button.linked:only-child:hover, .selection-mode.toolbar .linked .button:last-child:hover, .selection-mode.toolbar .linked .button:only-child:hover {
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    .selection-mode.header-bar .button.linked:insensitive:last-child, .selection-mode.header-bar .button.linked:insensitive:only-child, .selection-mode.header-bar .button.linked:active:insensitive:last-child, .selection-mode.header-bar .button.linked:active:insensitive:only-child, .selection-mode.header-bar .button.linked:checked:insensitive:last-child, .selection-mode.header-bar .button.linked:checked:insensitive:only-child, .selection-mode.header-bar .linked .button:insensitive:last-child, .selection-mode.header-bar .linked .button:insensitive:only-child, .selection-mode.header-bar .linked .button:active:insensitive:last-child, .selection-mode.header-bar .linked .button:active:insensitive:only-child, .selection-mode.header-bar .linked .button:checked:insensitive:last-child, .selection-mode.header-bar .linked .button:checked:insensitive:only-child, .selection-mode.toolbar .button.linked:insensitive:last-child, .selection-mode.toolbar .button.linked:insensitive:only-child, .selection-mode.toolbar .button.linked:active:insensitive:last-child, .selection-mode.toolbar .button.linked:active:insensitive:only-child, .selection-mode.toolbar .button.linked:checked:insensitive:last-child, .selection-mode.toolbar .button.linked:checked:insensitive:only-child, .selection-mode.toolbar .linked .button:insensitive:last-child, .selection-mode.toolbar .linked .button:insensitive:only-child, .selection-mode.toolbar .linked .button:active:insensitive:last-child, .selection-mode.toolbar .linked .button:active:insensitive:only-child, .selection-mode.toolbar .linked .button:checked:insensitive:last-child, .selection-mode.toolbar .linked .button:checked:insensitive:only-child {
      box-shadow: none; }
    .selection-mode.header-bar .button.linked:active:last-child, .selection-mode.header-bar .button.linked:active:last-child:focus, .selection-mode.header-bar .button.linked:active:last-child:hover, .selection-mode.header-bar .button.linked:active:last-child:hover:focus, .selection-mode.header-bar .button.linked:checked:last-child, .selection-mode.header-bar .button.linked:checked:last-child:focus, .selection-mode.header-bar .button.linked:checked:last-child:hover, .selection-mode.header-bar .button.linked:checked:last-child:hover:focus, .selection-mode.header-bar .linked .button:active:last-child, .selection-mode.header-bar .linked .button:active:last-child:focus, .selection-mode.header-bar .linked .button:active:last-child:hover, .selection-mode.header-bar .linked .button:active:last-child:hover:focus, .selection-mode.header-bar .linked .button:checked:last-child, .selection-mode.header-bar .linked .button:checked:last-child:focus, .selection-mode.header-bar .linked .button:checked:last-child:hover, .selection-mode.header-bar .linked .button:checked:last-child:hover:focus, .selection-mode.toolbar .button.linked:active:last-child, .selection-mode.toolbar .button.linked:active:last-child:focus, .selection-mode.toolbar .button.linked:active:last-child:hover, .selection-mode.toolbar .button.linked:active:last-child:hover:focus, .selection-mode.toolbar .button.linked:checked:last-child, .selection-mode.toolbar .button.linked:checked:last-child:focus, .selection-mode.toolbar .button.linked:checked:last-child:hover, .selection-mode.toolbar .button.linked:checked:last-child:hover:focus, .selection-mode.toolbar .linked .button:active:last-child, .selection-mode.toolbar .linked .button:active:last-child:focus, .selection-mode.toolbar .linked .button:active:last-child:hover, .selection-mode.toolbar .linked .button:active:last-child:hover:focus, .selection-mode.toolbar .linked .button:checked:last-child, .selection-mode.toolbar .linked .button:checked:last-child:focus, .selection-mode.toolbar .linked .button:checked:last-child:hover, .selection-mode.toolbar .linked .button:checked:last-child:hover:focus {
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
    .selection-mode.header-bar .button.linked:active:only-child, .selection-mode.header-bar .button.linked:active:only-child:focus, .selection-mode.header-bar .button.linked:active:only-child:hover, .selection-mode.header-bar .button.linked:active:only-child:hover:focus, .selection-mode.header-bar .button.linked:checked:only-child, .selection-mode.header-bar .button.linked:checked:only-child:focus, .selection-mode.header-bar .button.linked:checked:only-child:hover, .selection-mode.header-bar .button.linked:checked:only-child:hover:focus, .selection-mode.header-bar .linked .button:active:only-child, .selection-mode.header-bar .linked .button:active:only-child:focus, .selection-mode.header-bar .linked .button:active:only-child:hover, .selection-mode.header-bar .linked .button:active:only-child:hover:focus, .selection-mode.header-bar .linked .button:checked:only-child, .selection-mode.header-bar .linked .button:checked:only-child:focus, .selection-mode.header-bar .linked .button:checked:only-child:hover, .selection-mode.header-bar .linked .button:checked:only-child:hover:focus, .selection-mode.toolbar .button.linked:active:only-child, .selection-mode.toolbar .button.linked:active:only-child:focus, .selection-mode.toolbar .button.linked:active:only-child:hover, .selection-mode.toolbar .button.linked:active:only-child:hover:focus, .selection-mode.toolbar .button.linked:checked:only-child, .selection-mode.toolbar .button.linked:checked:only-child:focus, .selection-mode.toolbar .button.linked:checked:only-child:hover, .selection-mode.toolbar .button.linked:checked:only-child:hover:focus, .selection-mode.toolbar .linked .button:active:only-child, .selection-mode.toolbar .linked .button:active:only-child:focus, .selection-mode.toolbar .linked .button:active:only-child:hover, .selection-mode.toolbar .linked .button:active:only-child:hover:focus, .selection-mode.toolbar .linked .button:checked:only-child, .selection-mode.toolbar .linked .button:checked:only-child:focus, .selection-mode.toolbar .linked .button:checked:only-child:hover, .selection-mode.toolbar .linked .button:checked:only-child:hover:focus {
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06); }
  .selection-mode.header-bar GtkComboBox, .selection-mode.header-bar .button, .selection-mode.toolbar GtkComboBox, .selection-mode.toolbar .button {
    padding: 2px; }
    .selection-mode.header-bar GtkComboBox.text-button, .selection-mode.header-bar .button.text-button, .selection-mode.toolbar GtkComboBox.text-button, .selection-mode.toolbar .button.text-button {
      padding: 3px; }
    .selection-mode.header-bar GtkComboBox.image-button, .selection-mode.header-bar .button.image-button, .selection-mode.toolbar GtkComboBox.image-button, .selection-mode.toolbar .button.image-button {
      padding: 4px 2px 4px 3px; }
  .selection-mode.header-bar GtkSeparatorToolItem, .selection-mode.header-bar .separator, .selection-mode.header-bar .separator:insensitive, .selection-mode.toolbar GtkSeparatorToolItem, .selection-mode.toolbar .separator, .selection-mode.toolbar .separator:insensitive {
    color: #a95778;
    border-color: currentColor;
    -GtkWidget-window-dragging: true; }
  .selection-mode.header-bar .menubar, .selection-mode.toolbar .menubar {
    -GtkToolbar-button-relief: normal; }
  .selection-mode.header-bar .button, .selection-mode.toolbar .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #B36A87;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.12);
    color: #000000;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.12); }
    .selection-mode.header-bar .button:focus, .selection-mode.header-bar .button:hover, .selection-mode.toolbar .button:focus, .selection-mode.toolbar .button:hover {
      border-color: rgba(0, 0, 0, 0.12); }
    .selection-mode.header-bar .button:active, .selection-mode.header-bar .button:active:hover, .selection-mode.header-bar .button:active:focus, .selection-mode.header-bar .button:active:hover:focus, .selection-mode.header-bar .button:checked, .selection-mode.header-bar .button:checked:hover, .selection-mode.header-bar .button:checked:focus, .selection-mode.header-bar .button:checked:hover:focus, .selection-mode.toolbar .button:active, .selection-mode.toolbar .button:active:hover, .selection-mode.toolbar .button:active:focus, .selection-mode.toolbar .button:active:hover:focus, .selection-mode.toolbar .button:checked, .selection-mode.toolbar .button:checked:hover, .selection-mode.toolbar .button:checked:focus, .selection-mode.toolbar .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.12); }
    .selection-mode.header-bar .button:insensitive, .selection-mode.toolbar .button:insensitive {
      border-color: rgba(0, 0, 0, 0.12); }
    .selection-mode.header-bar .button:active:insensitive, .selection-mode.header-bar .button:checked:insensitive, .selection-mode.toolbar .button:active:insensitive, .selection-mode.toolbar .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.12); }
    .selection-mode.header-bar .button.flat, .selection-mode.toolbar .button.flat {
      border-color: rgba(179, 106, 135, 0);
      background-color: rgba(179, 106, 135, 0);
      background-image: none;
      box-shadow: none; }
    .selection-mode.header-bar .button:focus, .selection-mode.header-bar .button:hover, .selection-mode.header-bar .button.flat:focus, .selection-mode.header-bar .button.flat:hover, .selection-mode.toolbar .button:focus, .selection-mode.toolbar .button:hover, .selection-mode.toolbar .button.flat:focus, .selection-mode.toolbar .button.flat:hover {
      background-color: #c690a5;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.2);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.32); }
      .selection-mode.header-bar .button:focus:focus, .selection-mode.header-bar .button:focus:hover, .selection-mode.header-bar .button:hover:focus, .selection-mode.header-bar .button:hover:hover, .selection-mode.header-bar .button.flat:focus:focus, .selection-mode.header-bar .button.flat:focus:hover, .selection-mode.header-bar .button.flat:hover:focus, .selection-mode.header-bar .button.flat:hover:hover, .selection-mode.toolbar .button:focus:focus, .selection-mode.toolbar .button:focus:hover, .selection-mode.toolbar .button:hover:focus, .selection-mode.toolbar .button:hover:hover, .selection-mode.toolbar .button.flat:focus:focus, .selection-mode.toolbar .button.flat:focus:hover, .selection-mode.toolbar .button.flat:hover:focus, .selection-mode.toolbar .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.2); }
      .selection-mode.header-bar .button:focus:active, .selection-mode.header-bar .button:focus:active:hover, .selection-mode.header-bar .button:focus:active:focus, .selection-mode.header-bar .button:focus:active:hover:focus, .selection-mode.header-bar .button:focus:checked, .selection-mode.header-bar .button:focus:checked:hover, .selection-mode.header-bar .button:focus:checked:focus, .selection-mode.header-bar .button:focus:checked:hover:focus, .selection-mode.header-bar .button:hover:active, .selection-mode.header-bar .button:hover:active:hover, .selection-mode.header-bar .button:hover:active:focus, .selection-mode.header-bar .button:hover:active:hover:focus, .selection-mode.header-bar .button:hover:checked, .selection-mode.header-bar .button:hover:checked:hover, .selection-mode.header-bar .button:hover:checked:focus, .selection-mode.header-bar .button:hover:checked:hover:focus, .selection-mode.header-bar .button.flat:focus:active, .selection-mode.header-bar .button.flat:focus:active:hover, .selection-mode.header-bar .button.flat:focus:active:focus, .selection-mode.header-bar .button.flat:focus:active:hover:focus, .selection-mode.header-bar .button.flat:focus:checked, .selection-mode.header-bar .button.flat:focus:checked:hover, .selection-mode.header-bar .button.flat:focus:checked:focus, .selection-mode.header-bar .button.flat:focus:checked:hover:focus, .selection-mode.header-bar .button.flat:hover:active, .selection-mode.header-bar .button.flat:hover:active:hover, .selection-mode.header-bar .button.flat:hover:active:focus, .selection-mode.header-bar .button.flat:hover:active:hover:focus, .selection-mode.header-bar .button.flat:hover:checked, .selection-mode.header-bar .button.flat:hover:checked:hover, .selection-mode.header-bar .button.flat:hover:checked:focus, .selection-mode.header-bar .button.flat:hover:checked:hover:focus, .selection-mode.toolbar .button:focus:active, .selection-mode.toolbar .button:focus:active:hover, .selection-mode.toolbar .button:focus:active:focus, .selection-mode.toolbar .button:focus:active:hover:focus, .selection-mode.toolbar .button:focus:checked, .selection-mode.toolbar .button:focus:checked:hover, .selection-mode.toolbar .button:focus:checked:focus, .selection-mode.toolbar .button:focus:checked:hover:focus, .selection-mode.toolbar .button:hover:active, .selection-mode.toolbar .button:hover:active:hover, .selection-mode.toolbar .button:hover:active:focus, .selection-mode.toolbar .button:hover:active:hover:focus, .selection-mode.toolbar .button:hover:checked, .selection-mode.toolbar .button:hover:checked:hover, .selection-mode.toolbar .button:hover:checked:focus, .selection-mode.toolbar .button:hover:checked:hover:focus, .selection-mode.toolbar .button.flat:focus:active, .selection-mode.toolbar .button.flat:focus:active:hover, .selection-mode.toolbar .button.flat:focus:active:focus, .selection-mode.toolbar .button.flat:focus:active:hover:focus, .selection-mode.toolbar .button.flat:focus:checked, .selection-mode.toolbar .button.flat:focus:checked:hover, .selection-mode.toolbar .button.flat:focus:checked:focus, .selection-mode.toolbar .button.flat:focus:checked:hover:focus, .selection-mode.toolbar .button.flat:hover:active, .selection-mode.toolbar .button.flat:hover:active:hover, .selection-mode.toolbar .button.flat:hover:active:focus, .selection-mode.toolbar .button.flat:hover:active:hover:focus, .selection-mode.toolbar .button.flat:hover:checked, .selection-mode.toolbar .button.flat:hover:checked:hover, .selection-mode.toolbar .button.flat:hover:checked:focus, .selection-mode.toolbar .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.2); }
      .selection-mode.header-bar .button:focus:insensitive, .selection-mode.header-bar .button:hover:insensitive, .selection-mode.header-bar .button.flat:focus:insensitive, .selection-mode.header-bar .button.flat:hover:insensitive, .selection-mode.toolbar .button:focus:insensitive, .selection-mode.toolbar .button:hover:insensitive, .selection-mode.toolbar .button.flat:focus:insensitive, .selection-mode.toolbar .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.2); }
      .selection-mode.header-bar .button:focus:active:insensitive, .selection-mode.header-bar .button:focus:checked:insensitive, .selection-mode.header-bar .button:hover:active:insensitive, .selection-mode.header-bar .button:hover:checked:insensitive, .selection-mode.header-bar .button.flat:focus:active:insensitive, .selection-mode.header-bar .button.flat:focus:checked:insensitive, .selection-mode.header-bar .button.flat:hover:active:insensitive, .selection-mode.header-bar .button.flat:hover:checked:insensitive, .selection-mode.toolbar .button:focus:active:insensitive, .selection-mode.toolbar .button:focus:checked:insensitive, .selection-mode.toolbar .button:hover:active:insensitive, .selection-mode.toolbar .button:hover:checked:insensitive, .selection-mode.toolbar .button.flat:focus:active:insensitive, .selection-mode.toolbar .button.flat:focus:checked:insensitive, .selection-mode.toolbar .button.flat:hover:active:insensitive, .selection-mode.toolbar .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.2); }
    .selection-mode.header-bar .button:active, .selection-mode.header-bar .button:checked, .selection-mode.header-bar .button.flat:active, .selection-mode.header-bar .button.flat:checked, .selection-mode.toolbar .button:active, .selection-mode.toolbar .button:checked, .selection-mode.toolbar .button.flat:active, .selection-mode.toolbar .button.flat:checked {
      background-color: #84435d;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .selection-mode.header-bar .button:active:focus, .selection-mode.header-bar .button:active:hover, .selection-mode.header-bar .button:checked:focus, .selection-mode.header-bar .button:checked:hover, .selection-mode.header-bar .button.flat:active:focus, .selection-mode.header-bar .button.flat:active:hover, .selection-mode.header-bar .button.flat:checked:focus, .selection-mode.header-bar .button.flat:checked:hover, .selection-mode.toolbar .button:active:focus, .selection-mode.toolbar .button:active:hover, .selection-mode.toolbar .button:checked:focus, .selection-mode.toolbar .button:checked:hover, .selection-mode.toolbar .button.flat:active:focus, .selection-mode.toolbar .button.flat:active:hover, .selection-mode.toolbar .button.flat:checked:focus, .selection-mode.toolbar .button.flat:checked:hover {
        background-color: #7b3f56;
        background-image: none;
        color: #000000; }
    .selection-mode.header-bar .button:focus, .selection-mode.header-bar .button:hover, .selection-mode.header-bar .button.flat:focus, .selection-mode.header-bar .button.flat:hover, .selection-mode.toolbar .button:focus, .selection-mode.toolbar .button:hover, .selection-mode.toolbar .button.flat:focus, .selection-mode.toolbar .button.flat:hover {
      color: #000000; }
    .selection-mode.header-bar .button:active:insensitive, .selection-mode.header-bar .button:checked:insensitive, .selection-mode.header-bar .button.flat:active:insensitive, .selection-mode.header-bar .button.flat:checked:insensitive, .selection-mode.toolbar .button:active:insensitive, .selection-mode.toolbar .button:checked:insensitive, .selection-mode.toolbar .button.flat:active:insensitive, .selection-mode.toolbar .button.flat:checked:insensitive {
      background-color: #a95778;
      background-image: none;
      color: #000000;
      box-shadow: none; }
    .selection-mode.header-bar .button:insensitive:insensitive, .selection-mode.header-bar .button.flat:insensitive:insensitive, .selection-mode.toolbar .button:insensitive:insensitive, .selection-mode.toolbar .button.flat:insensitive:insensitive {
      background-color: #ae617f;
      background-image: none;
      color: mix(#B36A87,#000000,0.5);
      box-shadow: none; }
    .selection-mode.header-bar .button:active, .selection-mode.toolbar .button:active {
      color: #000000; }
    .selection-mode.header-bar .button.flat:insensitive:insensitive, .selection-mode.toolbar .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#B36A87,#000000,0.5);
      box-shadow: none; }
    .selection-mode.header-bar .button.separator, .selection-mode.header-bar .button .separator, .selection-mode.toolbar .button.separator, .selection-mode.toolbar .button .separator {
      border: 1px solid currentColor;
      color: #a95778; }
      .selection-mode.header-bar .button.separator:insensitive, .selection-mode.header-bar .button .separator:insensitive, .selection-mode.toolbar .button.separator:insensitive, .selection-mode.toolbar .button .separator:insensitive {
        color: #a05271; }
  .selection-mode.header-bar .selection-menu.button, .selection-mode.toolbar .selection-menu.button {
    border: 0;
    background-color: transparent;
    background-image: none;
    color: #974d6a; }
    .selection-mode.header-bar .selection-menu.button:hover, .selection-mode.toolbar .selection-menu.button:hover {
      color: #84435d; }
    .selection-mode.header-bar .selection-menu.button:active, .selection-mode.toolbar .selection-menu.button:active {
      color: #8e4864; }
  .selection-mode.header-bar .dim-label, .selection-mode.header-bar GtkLabel.separator, .selection-menu.button .selection-mode.header-bar .dim-label, .selection-menu.button .selection-mode.header-bar GtkLabel.separator, .selection-mode.toolbar .dim-label, .selection-mode.toolbar GtkLabel.separator, .selection-menu.button .selection-mode.toolbar .dim-label, .selection-menu.button .selection-mode.toolbar GtkLabel.separator {
    color: #84435d; }

.selection-mode.toolbar {
  padding: 3px; }

/**********
 ! Calendar
***********/
GtkCalendar {
  padding: 1px 3px;
  outline-offset: -1px; }
  GtkCalendar:inconsistent {
    color: mix(#000000,#a5a5a5,0.5); }
  GtkCalendar.view, GtkCalendar.view:focus, GtkCalendar.view:hover, GtkCalendar.view:insensitive, GtkCalendar.highlight, GtkCalendar.highlight:focus, GtkCalendar.highlight:hover, GtkCalendar.highlight:insensitive, GtkCalendar.header, GtkCalendar.header:focus, GtkCalendar.header:hover, GtkCalendar.header:insensitive, GtkCalendar.button, GtkCalendar.button:focus, GtkCalendar.button:hover, GtkCalendar.button:insensitive {
    background-color: transparent;
    background-image: none;
    border-width: 0;
    border-radius: 0; }
  GtkCalendar.button, GtkCalendar.button:focus, GtkCalendar.button:hover, GtkCalendar.button:insensitive {
    color: #fff;
    border-width: 0;
    box-shadow: none; }
  GtkCalendar.highlight {
    color: #B36A87; }

/* gnome-calendar */
.calendar-view {
  background-color: #d0d0d0;
  color: #000000; }

/***************
 ! Color chooser
****************/
GtkColorSwatch, GtkColorSwatch:selected {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 3px;
  background-color: transparent;
  background-clip: border-box; }
  GtkColorSwatch:hover, GtkColorSwatch:selected:hover {
    border-color: rgba(0, 0, 0, 0.3); }

GtkColorSwatch.color-light:selected:hover, GtkColorSwatch.color-dark:selected:hover {
  background-image: none; }

GtkColorSwatch.left, GtkColorSwatch:first-child {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px; }

GtkColorSwatch.right, GtkColorSwatch:last-child {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px; }

GtkColorSwatch:only-child {
  border-radius: 3px; }

GtkColorSwatch.top {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px; }

GtkColorSwatch.bottom {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px; }

GtkColorEditor GtkColorSwatch {
  border-radius: 3px; }
  GtkColorEditor GtkColorSwatch.color-dark:hover, GtkColorEditor GtkColorSwatch.color-light:hover {
    background-image: none;
    border-color: rgba(0, 0, 0, 0.3); }

GtkColorChooserWidget #add-color-button {
  background-clip: padding-box;
  border-color: rgba(0, 0, 0, 0.1);
  background-color: #9d9d9d;
  color: #000000; }
  GtkColorChooserWidget #add-color-button:hover {
    border-color: rgba(0, 0, 0, 0.3);
    background-color: #959595;
    color: #000000; }

.color-active-badge, .color-active-badge:selected {
  border-width: 2px;
  border-style: solid;
  background-color: transparent; }

.color-active-badge.color-light, .color-active-badge.color-light:hover {
  border-color: rgba(0, 0, 0, 0.3);
  color: rgba(0, 0, 0, 0.3); }

.color-active-badge.color-dark, .color-active-badge.color-dark:hover {
  border-color: rgba(255, 255, 255, 0.3);
  color: rgba(255, 255, 255, 0.3); }

GtkColorButton.button {
  padding: 3px; }

/***********************
! Font and file choosers
************************/
GtkFontButton .separator, GtkFileChooserButton .separator {
  /* always disable separators */
  -GtkWidget-wide-separators: true;
  -GtkWidget-horizontal-separator: 0;
  -GtkWidget-vertical-separator: 0; }

GtkFontButton GtkLabel:last-child, GtkFileChooserButton GtkLabel:last-child {
  color: alpha(currentColor,0.7); }

GtkFontButton GtkImage:last-child, GtkFileChooserButton GtkImage:last-child {
  color: alpha(currentColor,0.7); }

GtkFileChooser {
  /* for fallback when header bar not used */ }
  GtkFileChooser .pane-separator, GtkFileChooser .pane-separator:hover {
    border-width: 0 1px 0 0;
    border-style: solid;
    border-color: currentColor;
    background-color: #a5a5a5;
    color: #959595; }
  GtkFileChooser .dialog-action-box {
    border-width: 1px 0 0;
    border-style: solid;
    border-color: #747474; }

/******************
 ! Grid and flowbox
*******************/
.list {
  background-color: #a0a0a0;
  color: #000000; }
  .list-row, .list-row.button {
    border: 0;
    border-radius: 0;
    padding: 3px;
    background-image: none;
    background-color: rgba(165, 165, 165, 0);
    box-shadow: none; }
    .list-row:hover, .list-row.button:hover {
      background-image: none;
      background-color: #a8a8a8; }
    .list-row:selected, .list-row:selected:hover, .list-row:selected:focus, .list-row.button:selected, .list-row.button:selected:hover, .list-row.button:selected:focus {
      background-image: none;
      background-color: #B36A87;
      color: #000000; }

.grid-child, GtkFlowBox .grid-child {
  padding: 3px;
  border-radius: 3px; }
  .grid-child:selected, GtkFlowBox .grid-child:selected {
    outline-offset: -2px; }

/*********
 ! Buttons
**********/
/******************
! ComboBoxes *
*******************/
/*********
 ! Infobar
**********/
GtkInfoBar {
  border: 0; }

.info {
  background-color: #03a9f4;
  background-image: none;
  border: 1px solid #0287c3;
  color: #fff; }
  .info .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #03a9f4;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #fff;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .info .button:focus, .info .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .info .button:active, .info .button:active:hover, .info .button:active:focus, .info .button:active:hover:focus, .info .button:checked, .info .button:checked:hover, .info .button:checked:focus, .info .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .info .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .info .button:active:insensitive, .info .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .info .button.flat {
      border-color: rgba(3, 169, 244, 0);
      background-color: rgba(3, 169, 244, 0);
      background-image: none;
      box-shadow: none; }
    .info .button:focus, .info .button:hover, .info .button.flat:focus, .info .button.flat:hover {
      background-color: #2cbcfc;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .info .button:focus:focus, .info .button:focus:hover, .info .button:hover:focus, .info .button:hover:hover, .info .button.flat:focus:focus, .info .button.flat:focus:hover, .info .button.flat:hover:focus, .info .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .info .button:focus:active, .info .button:focus:active:hover, .info .button:focus:active:focus, .info .button:focus:active:hover:focus, .info .button:focus:checked, .info .button:focus:checked:hover, .info .button:focus:checked:focus, .info .button:focus:checked:hover:focus, .info .button:hover:active, .info .button:hover:active:hover, .info .button:hover:active:focus, .info .button:hover:active:hover:focus, .info .button:hover:checked, .info .button:hover:checked:hover, .info .button:hover:checked:focus, .info .button:hover:checked:hover:focus, .info .button.flat:focus:active, .info .button.flat:focus:active:hover, .info .button.flat:focus:active:focus, .info .button.flat:focus:active:hover:focus, .info .button.flat:focus:checked, .info .button.flat:focus:checked:hover, .info .button.flat:focus:checked:focus, .info .button.flat:focus:checked:hover:focus, .info .button.flat:hover:active, .info .button.flat:hover:active:hover, .info .button.flat:hover:active:focus, .info .button.flat:hover:active:hover:focus, .info .button.flat:hover:checked, .info .button.flat:hover:checked:hover, .info .button.flat:hover:checked:focus, .info .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .info .button:focus:insensitive, .info .button:hover:insensitive, .info .button.flat:focus:insensitive, .info .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .info .button:focus:active:insensitive, .info .button:focus:checked:insensitive, .info .button:hover:active:insensitive, .info .button:hover:checked:insensitive, .info .button.flat:focus:active:insensitive, .info .button.flat:focus:checked:insensitive, .info .button.flat:hover:active:insensitive, .info .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .info .button:active, .info .button:checked, .info .button.flat:active, .info .button.flat:checked {
      background-color: #0276ab;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .info .button:active:focus, .info .button:active:hover, .info .button:checked:focus, .info .button:checked:hover, .info .button.flat:active:focus, .info .button.flat:active:hover, .info .button.flat:checked:focus, .info .button.flat:checked:hover {
        background-color: #026e9f;
        background-image: none;
        color: #000000; }
    .info .button:focus, .info .button:hover, .info .button.flat:focus, .info .button.flat:hover {
      color: #fff; }
    .info .button:active:insensitive, .info .button:checked:insensitive, .info .button.flat:active:insensitive, .info .button.flat:checked:insensitive {
      background-color: #0398dc;
      background-image: none;
      color: #fff;
      box-shadow: none; }
    .info .button:insensitive:insensitive, .info .button.flat:insensitive:insensitive {
      background-color: rgba(3, 169, 244, 0.3);
      background-image: none;
      color: mix(#03a9f4,#fff,0.5);
      box-shadow: none; }
    .info .button:active {
      color: #fff; }
    .info .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#03a9f4,#fff,0.5);
      box-shadow: none; }
    .info .button.separator, .info .button .separator {
      border: 1px solid currentColor;
      color: #0398dc; }
      .info .button.separator:insensitive, .info .button .separator:insensitive {
        color: #0390cf; }

.warning {
  background-color: #ef6c00;
  background-image: none;
  border: 1px solid #bf5600;
  color: #fff; }
  .warning .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #ef6c00;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #fff;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .warning .button:focus, .warning .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .warning .button:active, .warning .button:active:hover, .warning .button:active:focus, .warning .button:active:hover:focus, .warning .button:checked, .warning .button:checked:hover, .warning .button:checked:focus, .warning .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .warning .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .warning .button:active:insensitive, .warning .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .warning .button.flat {
      border-color: rgba(239, 108, 0, 0);
      background-color: rgba(239, 108, 0, 0);
      background-image: none;
      box-shadow: none; }
    .warning .button:focus, .warning .button:hover, .warning .button.flat:focus, .warning .button.flat:hover {
      background-color: #ff8520;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .warning .button:focus:focus, .warning .button:focus:hover, .warning .button:hover:focus, .warning .button:hover:hover, .warning .button.flat:focus:focus, .warning .button.flat:focus:hover, .warning .button.flat:hover:focus, .warning .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .warning .button:focus:active, .warning .button:focus:active:hover, .warning .button:focus:active:focus, .warning .button:focus:active:hover:focus, .warning .button:focus:checked, .warning .button:focus:checked:hover, .warning .button:focus:checked:focus, .warning .button:focus:checked:hover:focus, .warning .button:hover:active, .warning .button:hover:active:hover, .warning .button:hover:active:focus, .warning .button:hover:active:hover:focus, .warning .button:hover:checked, .warning .button:hover:checked:hover, .warning .button:hover:checked:focus, .warning .button:hover:checked:hover:focus, .warning .button.flat:focus:active, .warning .button.flat:focus:active:hover, .warning .button.flat:focus:active:focus, .warning .button.flat:focus:active:hover:focus, .warning .button.flat:focus:checked, .warning .button.flat:focus:checked:hover, .warning .button.flat:focus:checked:focus, .warning .button.flat:focus:checked:hover:focus, .warning .button.flat:hover:active, .warning .button.flat:hover:active:hover, .warning .button.flat:hover:active:focus, .warning .button.flat:hover:active:hover:focus, .warning .button.flat:hover:checked, .warning .button.flat:hover:checked:hover, .warning .button.flat:hover:checked:focus, .warning .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .warning .button:focus:insensitive, .warning .button:hover:insensitive, .warning .button.flat:focus:insensitive, .warning .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .warning .button:focus:active:insensitive, .warning .button:focus:checked:insensitive, .warning .button:hover:active:insensitive, .warning .button:hover:checked:insensitive, .warning .button.flat:focus:active:insensitive, .warning .button.flat:focus:checked:insensitive, .warning .button.flat:hover:active:insensitive, .warning .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .warning .button:active, .warning .button:checked, .warning .button.flat:active, .warning .button.flat:checked {
      background-color: #a74c00;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .warning .button:active:focus, .warning .button:active:hover, .warning .button:checked:focus, .warning .button:checked:hover, .warning .button.flat:active:focus, .warning .button.flat:active:hover, .warning .button.flat:checked:focus, .warning .button.flat:checked:hover {
        background-color: #9b4600;
        background-image: none;
        color: #000000; }
    .warning .button:focus, .warning .button:hover, .warning .button.flat:focus, .warning .button.flat:hover {
      color: #fff; }
    .warning .button:active:insensitive, .warning .button:checked:insensitive, .warning .button.flat:active:insensitive, .warning .button.flat:checked:insensitive {
      background-color: #d76100;
      background-image: none;
      color: #fff;
      box-shadow: none; }
    .warning .button:insensitive:insensitive, .warning .button.flat:insensitive:insensitive {
      background-color: rgba(239, 108, 0, 0.3);
      background-image: none;
      color: mix(#ef6c00,#fff,0.5);
      box-shadow: none; }
    .warning .button:active {
      color: #fff; }
    .warning .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#ef6c00,#fff,0.5);
      box-shadow: none; }
    .warning .button.separator, .warning .button .separator {
      border: 1px solid currentColor;
      color: #d76100; }
      .warning .button.separator:insensitive, .warning .button .separator:insensitive {
        color: #cb5c00; }

.question {
  background-color: #673ab7;
  background-image: none;
  border: 1px solid #522e92;
  color: #fff; }
  .question .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #673ab7;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #fff;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .question .button:focus, .question .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .question .button:active, .question .button:active:hover, .question .button:active:focus, .question .button:active:hover:focus, .question .button:checked, .question .button:checked:hover, .question .button:checked:focus, .question .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .question .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .question .button:active:insensitive, .question .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .question .button.flat {
      border-color: rgba(103, 58, 183, 0);
      background-color: rgba(103, 58, 183, 0);
      background-image: none;
      box-shadow: none; }
    .question .button:focus, .question .button:hover, .question .button.flat:focus, .question .button.flat:hover {
      background-color: #8157ca;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .question .button:focus:focus, .question .button:focus:hover, .question .button:hover:focus, .question .button:hover:hover, .question .button.flat:focus:focus, .question .button.flat:focus:hover, .question .button.flat:hover:focus, .question .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .question .button:focus:active, .question .button:focus:active:hover, .question .button:focus:active:focus, .question .button:focus:active:hover:focus, .question .button:focus:checked, .question .button:focus:checked:hover, .question .button:focus:checked:focus, .question .button:focus:checked:hover:focus, .question .button:hover:active, .question .button:hover:active:hover, .question .button:hover:active:focus, .question .button:hover:active:hover:focus, .question .button:hover:checked, .question .button:hover:checked:hover, .question .button:hover:checked:focus, .question .button:hover:checked:hover:focus, .question .button.flat:focus:active, .question .button.flat:focus:active:hover, .question .button.flat:focus:active:focus, .question .button.flat:focus:active:hover:focus, .question .button.flat:focus:checked, .question .button.flat:focus:checked:hover, .question .button.flat:focus:checked:focus, .question .button.flat:focus:checked:hover:focus, .question .button.flat:hover:active, .question .button.flat:hover:active:hover, .question .button.flat:hover:active:focus, .question .button.flat:hover:active:hover:focus, .question .button.flat:hover:checked, .question .button.flat:hover:checked:hover, .question .button.flat:hover:checked:focus, .question .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .question .button:focus:insensitive, .question .button:hover:insensitive, .question .button.flat:focus:insensitive, .question .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .question .button:focus:active:insensitive, .question .button:focus:checked:insensitive, .question .button:hover:active:insensitive, .question .button:hover:checked:insensitive, .question .button.flat:focus:active:insensitive, .question .button.flat:focus:checked:insensitive, .question .button.flat:hover:active:insensitive, .question .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .question .button:active, .question .button:checked, .question .button.flat:active, .question .button.flat:checked {
      background-color: #482980;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .question .button:active:focus, .question .button:active:hover, .question .button:checked:focus, .question .button:checked:hover, .question .button.flat:active:focus, .question .button.flat:active:hover, .question .button.flat:checked:focus, .question .button.flat:checked:hover {
        background-color: #432677;
        background-image: none;
        color: #000000; }
    .question .button:focus, .question .button:hover, .question .button.flat:focus, .question .button.flat:hover {
      color: #fff; }
    .question .button:active:insensitive, .question .button:checked:insensitive, .question .button.flat:active:insensitive, .question .button.flat:checked:insensitive {
      background-color: #5d34a5;
      background-image: none;
      color: #fff;
      box-shadow: none; }
    .question .button:insensitive:insensitive, .question .button.flat:insensitive:insensitive {
      background-color: rgba(103, 58, 183, 0.3);
      background-image: none;
      color: mix(#673ab7,#fff,0.5);
      box-shadow: none; }
    .question .button:active {
      color: #fff; }
    .question .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#673ab7,#fff,0.5);
      box-shadow: none; }
    .question .button.separator, .question .button .separator {
      border: 1px solid currentColor;
      color: #5d34a5; }
      .question .button.separator:insensitive, .question .button .separator:insensitive {
        color: #58319c; }

.error {
  background-color: #f44336;
  background-image: none;
  border: 1px solid #e21b0c;
  color: #fff; }
  .error .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #f44336;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.12);
    color: #fff;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.12); }
    .error .button:focus, .error .button:hover {
      border-color: rgba(0, 0, 0, 0.12); }
    .error .button:active, .error .button:active:hover, .error .button:active:focus, .error .button:active:hover:focus, .error .button:checked, .error .button:checked:hover, .error .button:checked:focus, .error .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.12); }
    .error .button:insensitive {
      border-color: rgba(0, 0, 0, 0.12); }
    .error .button:active:insensitive, .error .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.12); }
    .error .button.flat {
      border-color: rgba(244, 67, 54, 0);
      background-color: rgba(244, 67, 54, 0);
      background-image: none;
      box-shadow: none; }
    .error .button:focus, .error .button:hover, .error .button.flat:focus, .error .button.flat:hover {
      background-color: #f7786f;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.2);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.32); }
      .error .button:focus:focus, .error .button:focus:hover, .error .button:hover:focus, .error .button:hover:hover, .error .button.flat:focus:focus, .error .button.flat:focus:hover, .error .button.flat:hover:focus, .error .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.2); }
      .error .button:focus:active, .error .button:focus:active:hover, .error .button:focus:active:focus, .error .button:focus:active:hover:focus, .error .button:focus:checked, .error .button:focus:checked:hover, .error .button:focus:checked:focus, .error .button:focus:checked:hover:focus, .error .button:hover:active, .error .button:hover:active:hover, .error .button:hover:active:focus, .error .button:hover:active:hover:focus, .error .button:hover:checked, .error .button:hover:checked:hover, .error .button:hover:checked:focus, .error .button:hover:checked:hover:focus, .error .button.flat:focus:active, .error .button.flat:focus:active:hover, .error .button.flat:focus:active:focus, .error .button.flat:focus:active:hover:focus, .error .button.flat:focus:checked, .error .button.flat:focus:checked:hover, .error .button.flat:focus:checked:focus, .error .button.flat:focus:checked:hover:focus, .error .button.flat:hover:active, .error .button.flat:hover:active:hover, .error .button.flat:hover:active:focus, .error .button.flat:hover:active:hover:focus, .error .button.flat:hover:checked, .error .button.flat:hover:checked:hover, .error .button.flat:hover:checked:focus, .error .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.2); }
      .error .button:focus:insensitive, .error .button:hover:insensitive, .error .button.flat:focus:insensitive, .error .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.2); }
      .error .button:focus:active:insensitive, .error .button:focus:checked:insensitive, .error .button:hover:active:insensitive, .error .button:hover:checked:insensitive, .error .button.flat:focus:active:insensitive, .error .button.flat:focus:checked:insensitive, .error .button.flat:hover:active:insensitive, .error .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.2); }
    .error .button:active, .error .button:checked, .error .button.flat:active, .error .button.flat:checked {
      background-color: #c6180b;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .error .button:active:focus, .error .button:active:hover, .error .button:checked:focus, .error .button:checked:hover, .error .button.flat:active:focus, .error .button.flat:active:hover, .error .button.flat:checked:focus, .error .button.flat:checked:hover {
        background-color: #b8160a;
        background-image: none;
        color: #000000; }
    .error .button:focus, .error .button:hover, .error .button.flat:focus, .error .button.flat:hover {
      color: #fff; }
    .error .button:active:insensitive, .error .button:checked:insensitive, .error .button.flat:active:insensitive, .error .button.flat:checked:insensitive {
      background-color: #f2291a;
      background-image: none;
      color: #fff;
      box-shadow: none; }
    .error .button:insensitive:insensitive, .error .button.flat:insensitive:insensitive {
      background-color: #f33628;
      background-image: none;
      color: mix(#f44336,#fff,0.5);
      box-shadow: none; }
    .error .button:active {
      color: #fff; }
    .error .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#f44336,#fff,0.5);
      box-shadow: none; }
    .error .button.separator, .error .button .separator {
      border: 1px solid currentColor;
      color: #f2291a; }
      .error .button.separator:insensitive, .error .button .separator:insensitive {
        color: #f01d0d; }

/*********
 ! Entry *
**********/
.entry.linked, .linked .entry {
  border-width: 1px;
  border-radius: 0;
  border-right-width: 0;
  border-left-width: 0; }
  .entry.linked:first-child, .linked .entry:first-child {
    border-width: 1px;
    border-radius: 3px;
    border-right-width: 0;
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }
  .entry.linked:last-child, .linked .entry:last-child {
    border-width: 1px;
    border-radius: 3px;
    border-left-width: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  .entry.linked:only-child, .linked .entry:only-child {
    border-width: 1px;
    border-radius: 3px; }

.entry, .menuitem .entry, GtkPopover .entry {
  padding: 2px 3px;
  border-width: 1px;
  border-style: solid;
  border-radius: 3px;
  transition: border 150ms ease;
  box-shadow: inset 1px 1px rgba(0, 0, 0, 0.06), inset -1px 0 rgba(0, 0, 0, 0.06); }
  .entry:focus, .entry:hover, .entry:active {
    transition: none; }
  .entry:selected, .entry:selected:focus {
    background-color: #B36A87;
    color: #000000; }
  .entry:insensitive {
    box-shadow: none; }
  .progressbar.entry {
    background-color: #B36A87;
    background-image: none;
    border-width: 0;
    border-radius: 3px;
    color: #000000; }
  .image.left.entry {
    padding-right: 3px; }

/*********
 ! Menubar
**********/
.menubar {
  -GtkWidget-window-dragging: true;
  border: 0;
  background-color: #0f0f0f;
  background-image: none;
  color: #a5a5a5; }
  .menubar.menuitem, .menubar .menuitem {
    padding: 3px 6px;
    border: 1px solid transparent;
    background-color: transparent;
    background-image: none;
    color: #a5a5a5; }
    .menubar.menuitem:hover, .menubar .menuitem:hover {
      border-color: mix(#0f0f0f,#a5a5a5,0.21);
      background-color: mix(#0f0f0f,#a5a5a5,0.21);
      background-image: none;
      color: #b2b2b2; }
    .menubar.menuitem *:hover, .menubar .menuitem *:hover {
      color: #b2b2b2; }

/******
 ! Menu
*******/
* {
  -GtkMenu-horizontal-padding: 0;
  -GtkMenu-vertical-padding: 0; }

GtkTreeMenu.menu, GtkTreeMenu .menu, GtkMenuToolButton.menu, GtkMenuToolButton .menu, GtkComboBox.menu, GtkComboBox .menu {
  background-color: #0f0f0f;
  margin: 3px; }

#toolbar-popup, .menu {
  padding: 0;
  border-radius: 0;
  border: 0;
  background-color: #0f0f0f;
  color: #a5a5a5; }
  #toolbar-popup:selected, .menu:selected {
    background-color: #B36A87; }
  #toolbar-popup .button, #toolbar-popup .button:hover, #toolbar-popup .button:active, #toolbar-popup .button:active *:insensitive, #toolbar-popup .button:insensitive, .menu .button, .menu .button:hover, .menu .button:active, .menu .button:active *:insensitive, .menu .button:insensitive {
    border-width: 0;
    background-color: transparent;
    background-image: none; }

.context-menu {
  font: initial; }

GtkTreeMenu .menuitem {
  padding: 0;
  border-width: 0; }

.menuitem, .menu .menuitem {
  margin: 3px;
  padding: 3px;
  border: 0;
  border-radius: 0;
  background-color: transparent;
  background-image: none;
  -GtkMenuItem-arrow-scaling: .5; }
  .menuitem:active, .menuitem:hover, .menu .menuitem:active, .menu .menuitem:hover {
    border: 0;
    background-color: #B36A87;
    background-image: none;
    color: #000000; }
  .menuitem *:active, .menuitem *:hover, .menu .menuitem *:active, .menu .menuitem *:hover {
    color: #000000; }
  .menuitem:insensitive, .menuitem *:insensitive, .menu .menuitem:insensitive, .menu .menuitem *:insensitive {
    color: mix(#a5a5a5,#0f0f0f,0.5); }

.menuitem.check, .menuitem.check:focus, .menuitem.check:hover, .menuitem.check:insensitive, .menuitem.radio, .menuitem.radio:focus, .menuitem.radio:hover, .menuitem.radio:insensitive {
  background-image: none; }

.menuitem.check, .menuitem.check:focus, .menuitem.check:hover, .menuitem.check:active, .menuitem.check:insensitive, .menuitem.radio, .menuitem.radio:focus, .menuitem.radio:hover, .menuitem.radio:active, .menuitem.radio:insensitive {
  border-style: none;
  background-color: transparent; }

.menuitem.separator {
  -GtkMenuItem-horizontal-padding: 0;
  -GtkWidget-separator-height: 1;
  border-style: none;
  color: #0e0e0e; }

.menuitem.button, .menuitem.button:focus, .menuitem.button:active, .menuitem.button:insensitive, .menuitem.button:active:insensitive, .menuitem.button.flat, .menuitem.button.flat:focus, .menuitem.button.flat:active, .menuitem.button.flat:insensitive, .menuitem.button.flat:active:insensitive {
  background-color: transparent;
  background-image: none;
  border: 0;
  box-shadow: none;
  color: currentColor; }

.menuitem.button:hover, .menuitem.button:focus:hover, .menuitem.button:active:hover, .menuitem.button:selected, .menuitem.button.flat:hover, .menuitem.button.flat:focus:hover, .menuitem.button.flat:active:hover, .menuitem.button.flat:selected {
  background-image: none;
  background-color: #B36A87;
  color: #000000; }

.menuitem GtkCalendar:inconsistent {
  color: mix(#a5a5a5,#0f0f0f,0.5); }

.menuitem GtkCalendar .button {
  border-style: none;
  background-color: transparent;
  background-image: none; }

.menuitem .accelerator {
  color: rgba(165, 165, 165, 0.6); }
  .menuitem .accelerator:hover {
    color: rgba(0, 0, 0, 0.8); }
  .menuitem .accelerator:insensitive {
    color: alpha(mix(#a5a5a5,#0f0f0f,0.5),0.4); }

.menuitem .entry {
  background-color: #0f0f0f;
  background-image: none;
  border-color: #0c0c0c;
  color: #a5a5a5; }
  .menuitem .entry:focus, .menuitem .entry:hover {
    border-color: #0b0b0b; }
  .menuitem .entry:active, .menuitem .entry:active:hover, .menuitem .entry:active:focus, .menuitem .entry:active:hover:focus, .menuitem .entry:checked, .menuitem .entry:checked:hover, .menuitem .entry:checked:focus, .menuitem .entry:checked:hover:focus {
    border-color: #0b0b0b; }
  .menuitem .entry:insensitive {
    border-color: #0d0d0d; }
  .menuitem .entry:active:insensitive, .menuitem .entry:checked:insensitive {
    border-color: #0c0c0c; }
  .menuitem .entry:focus, .menuitem .entry:active {
    border-color: #B36A87; }
  .menuitem .entry:insensitive {
    background-color: #0e0e0e;
    background-image: none;
    color: mix(#0f0f0f,#a5a5a5,0.5); }

GtkModelMenuItem GtkBox GtkImage {
  padding-right: 3px; }

/*********
 ! Popover
**********/
GtkPopover {
  border-color: #0c0c0c;
  margin: 10px;
  padding: 3px;
  border-radius: 3px;
  border-width: 1px;
  border-style: solid;
  background-clip: border-box;
  background-color: #0f0f0f;
  background-image: none;
  color: #a5a5a5;
  box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16); }
  GtkPopover:focus, GtkPopover:hover {
    border-color: #0b0b0b; }
  GtkPopover:active, GtkPopover:active:hover, GtkPopover:active:focus, GtkPopover:active:hover:focus, GtkPopover:checked, GtkPopover:checked:hover, GtkPopover:checked:focus, GtkPopover:checked:hover:focus {
    border-color: #0b0b0b; }
  GtkPopover:insensitive {
    border-color: #0d0d0d; }
  GtkPopover:active:insensitive, GtkPopover:checked:insensitive {
    border-color: #0c0c0c; }
  GtkPopover.background {
    background-image: none;
    background-color: #0f0f0f;
    color: #a5a5a5; }
  GtkPopover:backdrop {
    box-shadow: none; }
  GtkPopover.osd {
    box-shadow: 0 2px 7px 3px rgba(0, 0, 0, 0.5); }
    GtkPopover.osd > .toolbar .button {
      border-radius: 0;
      border-width: 0;
      background-color: transparent;
      background-image: none; }
  GtkPopover .view, GtkPopover GtkHTML, GtkPopover .list {
    background-color: #141414;
    background-image: none;
    color: #a5a5a5; }
    GtkPopover .view:hover, GtkPopover GtkHTML:hover, GtkPopover .list:hover {
      background-image: none;
      background-color: #B36A87;
      color: #000000; }
  GtkPopover .list-row, GtkPopover .list-row.button {
    background-color: transparent;
    background-image: none;
    color: #a5a5a5; }
    GtkPopover .list-row:focus, GtkPopover .list-row:hover, GtkPopover .list-row:active, GtkPopover .list-row.button:focus, GtkPopover .list-row.button:hover, GtkPopover .list-row.button:active {
      background-image: none;
      background-color: #B36A87;
      color: #000000; }
  GtkPopover .frame {
    border-color: #0c0c0c;
    border-radius: 3px; }
  GtkPopover .entry {
    background-color: #d0d0d0;
    background-image: none;
    border-color: #a6a6a6;
    color: #000000; }
    GtkPopover .entry:focus, GtkPopover .entry:hover {
      border-color: #9c9c9c; }
    GtkPopover .entry:active, GtkPopover .entry:active:hover, GtkPopover .entry:active:focus, GtkPopover .entry:active:hover:focus, GtkPopover .entry:checked, GtkPopover .entry:checked:hover, GtkPopover .entry:checked:focus, GtkPopover .entry:checked:hover:focus {
      border-color: #929292; }
    GtkPopover .entry:insensitive {
      border-color: #b1b1b1; }
    GtkPopover .entry:active:insensitive, GtkPopover .entry:checked:insensitive {
      border-color: #a6a6a6; }
    GtkPopover .entry:focus, GtkPopover .entry:active {
      border-color: #B36A87; }
    GtkPopover .entry:insensitive {
      background-color: #bbbbbb;
      background-image: none;
      color: mix(#d0d0d0,#000000,0.5); }
  GtkPopover .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: #8b639b;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #000000;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    GtkPopover .button:focus, GtkPopover .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    GtkPopover .button:active, GtkPopover .button:active:hover, GtkPopover .button:active:focus, GtkPopover .button:active:hover:focus, GtkPopover .button:checked, GtkPopover .button:checked:hover, GtkPopover .button:checked:focus, GtkPopover .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    GtkPopover .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    GtkPopover .button:active:insensitive, GtkPopover .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    GtkPopover .button.flat {
      border-color: rgba(139, 99, 155, 0);
      background-color: rgba(139, 99, 155, 0);
      background-image: none;
      box-shadow: none; }
    GtkPopover .button:focus, GtkPopover .button:hover, GtkPopover .button.flat:focus, GtkPopover .button.flat:hover {
      background-color: #a282af;
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      GtkPopover .button:focus:focus, GtkPopover .button:focus:hover, GtkPopover .button:hover:focus, GtkPopover .button:hover:hover, GtkPopover .button.flat:focus:focus, GtkPopover .button.flat:focus:hover, GtkPopover .button.flat:hover:focus, GtkPopover .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      GtkPopover .button:focus:active, GtkPopover .button:focus:active:hover, GtkPopover .button:focus:active:focus, GtkPopover .button:focus:active:hover:focus, GtkPopover .button:focus:checked, GtkPopover .button:focus:checked:hover, GtkPopover .button:focus:checked:focus, GtkPopover .button:focus:checked:hover:focus, GtkPopover .button:hover:active, GtkPopover .button:hover:active:hover, GtkPopover .button:hover:active:focus, GtkPopover .button:hover:active:hover:focus, GtkPopover .button:hover:checked, GtkPopover .button:hover:checked:hover, GtkPopover .button:hover:checked:focus, GtkPopover .button:hover:checked:hover:focus, GtkPopover .button.flat:focus:active, GtkPopover .button.flat:focus:active:hover, GtkPopover .button.flat:focus:active:focus, GtkPopover .button.flat:focus:active:hover:focus, GtkPopover .button.flat:focus:checked, GtkPopover .button.flat:focus:checked:hover, GtkPopover .button.flat:focus:checked:focus, GtkPopover .button.flat:focus:checked:hover:focus, GtkPopover .button.flat:hover:active, GtkPopover .button.flat:hover:active:hover, GtkPopover .button.flat:hover:active:focus, GtkPopover .button.flat:hover:active:hover:focus, GtkPopover .button.flat:hover:checked, GtkPopover .button.flat:hover:checked:hover, GtkPopover .button.flat:hover:checked:focus, GtkPopover .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      GtkPopover .button:focus:insensitive, GtkPopover .button:hover:insensitive, GtkPopover .button.flat:focus:insensitive, GtkPopover .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      GtkPopover .button:focus:active:insensitive, GtkPopover .button:focus:checked:insensitive, GtkPopover .button:hover:active:insensitive, GtkPopover .button:hover:checked:insensitive, GtkPopover .button.flat:focus:active:insensitive, GtkPopover .button.flat:focus:checked:insensitive, GtkPopover .button.flat:hover:active:insensitive, GtkPopover .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    GtkPopover .button:active, GtkPopover .button:checked, GtkPopover .button.flat:active, GtkPopover .button.flat:checked {
      background-color: #61456d;
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      GtkPopover .button:active:focus, GtkPopover .button:active:hover, GtkPopover .button:checked:focus, GtkPopover .button:checked:hover, GtkPopover .button.flat:active:focus, GtkPopover .button.flat:active:hover, GtkPopover .button.flat:checked:focus, GtkPopover .button.flat:checked:hover {
        background-color: #5a4065;
        background-image: none;
        color: #000000; }
    GtkPopover .button:focus, GtkPopover .button:hover, GtkPopover .button.flat:focus, GtkPopover .button.flat:hover {
      color: #000000; }
    GtkPopover .button:active:insensitive, GtkPopover .button:checked:insensitive, GtkPopover .button.flat:active:insensitive, GtkPopover .button.flat:checked:insensitive {
      background-color: #7d598c;
      background-image: none;
      color: #000000;
      box-shadow: none; }
    GtkPopover .button:insensitive:insensitive, GtkPopover .button.flat:insensitive:insensitive {
      background-color: rgba(139, 99, 155, 0.3);
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    GtkPopover .button:active {
      color: #000000; }
    GtkPopover .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(#8b639b,#000000,0.5);
      box-shadow: none; }
    GtkPopover .button.separator, GtkPopover .button .separator {
      border: 1px solid currentColor;
      color: #7d598c; }
      GtkPopover .button.separator:insensitive, GtkPopover .button .separator:insensitive {
        color: #765484; }
  GtkPopover > .list, GtkPopover > .view, GtkPopover > GtkHTML, GtkPopover > .toolbar {
    background-color: transparent; }
  GtkPopover .separator {
    border: 0;
    background-color: transparent;
    color: #0e0e0e;
    font-size: 80%;
    font-weight: bold; }

GtkModelButton.button, GtkModelButton.button:backdrop {
  /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
  background-color: transparent;
  background-image: none;
  border-color: rgba(0, 0, 0, 0.22);
  color: currentColor;
  box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
  GtkModelButton.button:focus, GtkModelButton.button:hover, GtkModelButton.button:backdrop:focus, GtkModelButton.button:backdrop:hover {
    border-color: rgba(0, 0, 0, 0.22); }
  GtkModelButton.button:active, GtkModelButton.button:active:hover, GtkModelButton.button:active:focus, GtkModelButton.button:active:hover:focus, GtkModelButton.button:checked, GtkModelButton.button:checked:hover, GtkModelButton.button:checked:focus, GtkModelButton.button:checked:hover:focus, GtkModelButton.button:backdrop:active, GtkModelButton.button:backdrop:active:hover, GtkModelButton.button:backdrop:active:focus, GtkModelButton.button:backdrop:active:hover:focus, GtkModelButton.button:backdrop:checked, GtkModelButton.button:backdrop:checked:hover, GtkModelButton.button:backdrop:checked:focus, GtkModelButton.button:backdrop:checked:hover:focus {
    border-color: rgba(0, 0, 0, 0.22); }
  GtkModelButton.button:insensitive, GtkModelButton.button:backdrop:insensitive {
    border-color: rgba(0, 0, 0, 0.22); }
  GtkModelButton.button:active:insensitive, GtkModelButton.button:checked:insensitive, GtkModelButton.button:backdrop:active:insensitive, GtkModelButton.button:backdrop:checked:insensitive {
    border-color: rgba(0, 0, 0, 0.22); }
  GtkModelButton.button.flat, GtkModelButton.button:backdrop.flat {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none; }
  GtkModelButton.button:focus, GtkModelButton.button:hover, GtkModelButton.button.flat:focus, GtkModelButton.button.flat:hover, GtkModelButton.button:backdrop:focus, GtkModelButton.button:backdrop:hover, GtkModelButton.button:backdrop.flat:focus, GtkModelButton.button:backdrop.flat:hover {
    background-color: transparent;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.3);
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
    GtkModelButton.button:focus:focus, GtkModelButton.button:focus:hover, GtkModelButton.button:hover:focus, GtkModelButton.button:hover:hover, GtkModelButton.button.flat:focus:focus, GtkModelButton.button.flat:focus:hover, GtkModelButton.button.flat:hover:focus, GtkModelButton.button.flat:hover:hover, GtkModelButton.button:backdrop:focus:focus, GtkModelButton.button:backdrop:focus:hover, GtkModelButton.button:backdrop:hover:focus, GtkModelButton.button:backdrop:hover:hover, GtkModelButton.button:backdrop.flat:focus:focus, GtkModelButton.button:backdrop.flat:focus:hover, GtkModelButton.button:backdrop.flat:hover:focus, GtkModelButton.button:backdrop.flat:hover:hover {
      border-color: rgba(0, 0, 0, 0.3); }
    GtkModelButton.button:focus:active, GtkModelButton.button:focus:active:hover, GtkModelButton.button:focus:active:focus, GtkModelButton.button:focus:active:hover:focus, GtkModelButton.button:focus:checked, GtkModelButton.button:focus:checked:hover, GtkModelButton.button:focus:checked:focus, GtkModelButton.button:focus:checked:hover:focus, GtkModelButton.button:hover:active, GtkModelButton.button:hover:active:hover, GtkModelButton.button:hover:active:focus, GtkModelButton.button:hover:active:hover:focus, GtkModelButton.button:hover:checked, GtkModelButton.button:hover:checked:hover, GtkModelButton.button:hover:checked:focus, GtkModelButton.button:hover:checked:hover:focus, GtkModelButton.button.flat:focus:active, GtkModelButton.button.flat:focus:active:hover, GtkModelButton.button.flat:focus:active:focus, GtkModelButton.button.flat:focus:active:hover:focus, GtkModelButton.button.flat:focus:checked, GtkModelButton.button.flat:focus:checked:hover, GtkModelButton.button.flat:focus:checked:focus, GtkModelButton.button.flat:focus:checked:hover:focus, GtkModelButton.button.flat:hover:active, GtkModelButton.button.flat:hover:active:hover, GtkModelButton.button.flat:hover:active:focus, GtkModelButton.button.flat:hover:active:hover:focus, GtkModelButton.button.flat:hover:checked, GtkModelButton.button.flat:hover:checked:hover, GtkModelButton.button.flat:hover:checked:focus, GtkModelButton.button.flat:hover:checked:hover:focus, GtkModelButton.button:backdrop:focus:active, GtkModelButton.button:backdrop:focus:active:hover, GtkModelButton.button:backdrop:focus:active:focus, GtkModelButton.button:backdrop:focus:active:hover:focus, GtkModelButton.button:backdrop:focus:checked, GtkModelButton.button:backdrop:focus:checked:hover, GtkModelButton.button:backdrop:focus:checked:focus, GtkModelButton.button:backdrop:focus:checked:hover:focus, GtkModelButton.button:backdrop:hover:active, GtkModelButton.button:backdrop:hover:active:hover, GtkModelButton.button:backdrop:hover:active:focus, GtkModelButton.button:backdrop:hover:active:hover:focus, GtkModelButton.button:backdrop:hover:checked, GtkModelButton.button:backdrop:hover:checked:hover, GtkModelButton.button:backdrop:hover:checked:focus, GtkModelButton.button:backdrop:hover:checked:hover:focus, GtkModelButton.button:backdrop.flat:focus:active, GtkModelButton.button:backdrop.flat:focus:active:hover, GtkModelButton.button:backdrop.flat:focus:active:focus, GtkModelButton.button:backdrop.flat:focus:active:hover:focus, GtkModelButton.button:backdrop.flat:focus:checked, GtkModelButton.button:backdrop.flat:focus:checked:hover, GtkModelButton.button:backdrop.flat:focus:checked:focus, GtkModelButton.button:backdrop.flat:focus:checked:hover:focus, GtkModelButton.button:backdrop.flat:hover:active, GtkModelButton.button:backdrop.flat:hover:active:hover, GtkModelButton.button:backdrop.flat:hover:active:focus, GtkModelButton.button:backdrop.flat:hover:active:hover:focus, GtkModelButton.button:backdrop.flat:hover:checked, GtkModelButton.button:backdrop.flat:hover:checked:hover, GtkModelButton.button:backdrop.flat:hover:checked:focus, GtkModelButton.button:backdrop.flat:hover:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.3); }
    GtkModelButton.button:focus:insensitive, GtkModelButton.button:hover:insensitive, GtkModelButton.button.flat:focus:insensitive, GtkModelButton.button.flat:hover:insensitive, GtkModelButton.button:backdrop:focus:insensitive, GtkModelButton.button:backdrop:hover:insensitive, GtkModelButton.button:backdrop.flat:focus:insensitive, GtkModelButton.button:backdrop.flat:hover:insensitive {
      border-color: rgba(0, 0, 0, 0.3); }
    GtkModelButton.button:focus:active:insensitive, GtkModelButton.button:focus:checked:insensitive, GtkModelButton.button:hover:active:insensitive, GtkModelButton.button:hover:checked:insensitive, GtkModelButton.button.flat:focus:active:insensitive, GtkModelButton.button.flat:focus:checked:insensitive, GtkModelButton.button.flat:hover:active:insensitive, GtkModelButton.button.flat:hover:checked:insensitive, GtkModelButton.button:backdrop:focus:active:insensitive, GtkModelButton.button:backdrop:focus:checked:insensitive, GtkModelButton.button:backdrop:hover:active:insensitive, GtkModelButton.button:backdrop:hover:checked:insensitive, GtkModelButton.button:backdrop.flat:focus:active:insensitive, GtkModelButton.button:backdrop.flat:focus:checked:insensitive, GtkModelButton.button:backdrop.flat:hover:active:insensitive, GtkModelButton.button:backdrop.flat:hover:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.3); }
  GtkModelButton.button:active, GtkModelButton.button:checked, GtkModelButton.button.flat:active, GtkModelButton.button.flat:checked, GtkModelButton.button:backdrop:active, GtkModelButton.button:backdrop:checked, GtkModelButton.button:backdrop.flat:active, GtkModelButton.button:backdrop.flat:checked {
    background-color: transparent;
    background-image: none;
    color: #000000;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
    GtkModelButton.button:active:focus, GtkModelButton.button:active:hover, GtkModelButton.button:checked:focus, GtkModelButton.button:checked:hover, GtkModelButton.button.flat:active:focus, GtkModelButton.button.flat:active:hover, GtkModelButton.button.flat:checked:focus, GtkModelButton.button.flat:checked:hover, GtkModelButton.button:backdrop:active:focus, GtkModelButton.button:backdrop:active:hover, GtkModelButton.button:backdrop:checked:focus, GtkModelButton.button:backdrop:checked:hover, GtkModelButton.button:backdrop.flat:active:focus, GtkModelButton.button:backdrop.flat:active:hover, GtkModelButton.button:backdrop.flat:checked:focus, GtkModelButton.button:backdrop.flat:checked:hover {
      background-color: transparent;
      background-image: none;
      color: #000000; }
  GtkModelButton.button:focus, GtkModelButton.button:hover, GtkModelButton.button.flat:focus, GtkModelButton.button.flat:hover, GtkModelButton.button:backdrop:focus, GtkModelButton.button:backdrop:hover, GtkModelButton.button:backdrop.flat:focus, GtkModelButton.button:backdrop.flat:hover {
    color: currentColor; }
  GtkModelButton.button:active:insensitive, GtkModelButton.button:checked:insensitive, GtkModelButton.button.flat:active:insensitive, GtkModelButton.button.flat:checked:insensitive, GtkModelButton.button:backdrop:active:insensitive, GtkModelButton.button:backdrop:checked:insensitive, GtkModelButton.button:backdrop.flat:active:insensitive, GtkModelButton.button:backdrop.flat:checked:insensitive {
    background-color: transparent;
    background-image: none;
    color: currentColor;
    box-shadow: none; }
  GtkModelButton.button:insensitive:insensitive, GtkModelButton.button.flat:insensitive:insensitive, GtkModelButton.button:backdrop:insensitive:insensitive, GtkModelButton.button:backdrop.flat:insensitive:insensitive {
    background-color: transparent;
    background-image: none;
    color: mix(transparent,currentColor,0.5);
    box-shadow: none; }
  GtkModelButton.button:active, GtkModelButton.button:backdrop:active {
    color: currentColor; }
  GtkModelButton.button.flat:insensitive:insensitive, GtkModelButton.button:backdrop.flat:insensitive:insensitive {
    background-color: transparent;
    background-image: none;
    color: mix(transparent,currentColor,0.5);
    box-shadow: none; }
  GtkModelButton.button.separator, GtkModelButton.button .separator, GtkModelButton.button:backdrop.separator, GtkModelButton.button:backdrop .separator {
    border: 1px solid currentColor;
    color: transparent; }
    GtkModelButton.button.separator:insensitive, GtkModelButton.button .separator:insensitive, GtkModelButton.button:backdrop.separator:insensitive, GtkModelButton.button:backdrop .separator:insensitive {
      color: transparent; }
  GtkModelButton.button:focus:hover, GtkModelButton.button.flat:checked:hover, GtkModelButton.button:active:hover, GtkModelButton.button:hover, GtkModelButton.button:selected, GtkModelButton.button:backdrop:focus:hover, GtkModelButton.button:backdrop.flat:checked:hover, GtkModelButton.button:backdrop:active:hover, GtkModelButton.button:backdrop:hover, GtkModelButton.button:backdrop:selected {
    background-image: none;
    background-color: #B36A87;
    color: #000000;
    box-shadow: none; }
  GtkModelButton.button.flat:checked, GtkModelButton.button:backdrop.flat:checked {
    box-shadow: none; }
  GtkModelButton.button.flat, GtkModelButton.button.flat:hover, GtkModelButton.button:backdrop.flat, GtkModelButton.button:backdrop.flat:hover {
    transition: none; }

/***************
! Dimmed label *
****************/
.dim-label, GtkLabel.separator {
  opacity: .5;
  text-shadow: none; }

/***********
 ! Tooltip *
************/
.tooltip.background {
  background-color: #a5a5a5;
  background-image: none;
  border: 0;
  border-radius: 3px;
  color: #000000; }

.tooltip * {
  background-color: transparent;
  color: inherit; }

/***********
 ! Dialogs *
************/
GtkMessageDialog, .message-dialog, .prompt {
  -GtkDialog-content-area-border: 3px;
  -GtkDialog-action-area-border: 3px;
  -GtkDialog-button-spacing: 3px;
  margin: 0;
  padding: 0; }

/*********************
 ! App notifications *
**********************/
.app-notification, .app-notification.frame {
  border-style: solid;
  border-color: rgba(12, 12, 12, 0.8);
  border-width: 0 1px 1px;
  border-radius: 0 0 3px 3px;
  padding: 6px;
  background-color: rgba(15, 15, 15, 0.8);
  background-image: none;
  color: #a5a5a5; }
  .app-notification .button, .app-notification.frame .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: rgba(15, 15, 15, 0.8);
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #a5a5a5;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .app-notification .button:focus, .app-notification .button:hover, .app-notification.frame .button:focus, .app-notification.frame .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .app-notification .button:active, .app-notification .button:active:hover, .app-notification .button:active:focus, .app-notification .button:active:hover:focus, .app-notification .button:checked, .app-notification .button:checked:hover, .app-notification .button:checked:focus, .app-notification .button:checked:hover:focus, .app-notification.frame .button:active, .app-notification.frame .button:active:hover, .app-notification.frame .button:active:focus, .app-notification.frame .button:active:hover:focus, .app-notification.frame .button:checked, .app-notification.frame .button:checked:hover, .app-notification.frame .button:checked:focus, .app-notification.frame .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .app-notification .button:insensitive, .app-notification.frame .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .app-notification .button:active:insensitive, .app-notification .button:checked:insensitive, .app-notification.frame .button:active:insensitive, .app-notification.frame .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .app-notification .button.flat, .app-notification.frame .button.flat {
      border-color: rgba(15, 15, 15, 0);
      background-color: rgba(15, 15, 15, 0);
      background-image: none;
      box-shadow: none; }
    .app-notification .button:focus, .app-notification .button:hover, .app-notification .button.flat:focus, .app-notification .button.flat:hover, .app-notification.frame .button:focus, .app-notification.frame .button:hover, .app-notification.frame .button.flat:focus, .app-notification.frame .button.flat:hover {
      background-color: rgba(18, 18, 18, 0.8);
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .app-notification .button:focus:focus, .app-notification .button:focus:hover, .app-notification .button:hover:focus, .app-notification .button:hover:hover, .app-notification .button.flat:focus:focus, .app-notification .button.flat:focus:hover, .app-notification .button.flat:hover:focus, .app-notification .button.flat:hover:hover, .app-notification.frame .button:focus:focus, .app-notification.frame .button:focus:hover, .app-notification.frame .button:hover:focus, .app-notification.frame .button:hover:hover, .app-notification.frame .button.flat:focus:focus, .app-notification.frame .button.flat:focus:hover, .app-notification.frame .button.flat:hover:focus, .app-notification.frame .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .app-notification .button:focus:active, .app-notification .button:focus:active:hover, .app-notification .button:focus:active:focus, .app-notification .button:focus:active:hover:focus, .app-notification .button:focus:checked, .app-notification .button:focus:checked:hover, .app-notification .button:focus:checked:focus, .app-notification .button:focus:checked:hover:focus, .app-notification .button:hover:active, .app-notification .button:hover:active:hover, .app-notification .button:hover:active:focus, .app-notification .button:hover:active:hover:focus, .app-notification .button:hover:checked, .app-notification .button:hover:checked:hover, .app-notification .button:hover:checked:focus, .app-notification .button:hover:checked:hover:focus, .app-notification .button.flat:focus:active, .app-notification .button.flat:focus:active:hover, .app-notification .button.flat:focus:active:focus, .app-notification .button.flat:focus:active:hover:focus, .app-notification .button.flat:focus:checked, .app-notification .button.flat:focus:checked:hover, .app-notification .button.flat:focus:checked:focus, .app-notification .button.flat:focus:checked:hover:focus, .app-notification .button.flat:hover:active, .app-notification .button.flat:hover:active:hover, .app-notification .button.flat:hover:active:focus, .app-notification .button.flat:hover:active:hover:focus, .app-notification .button.flat:hover:checked, .app-notification .button.flat:hover:checked:hover, .app-notification .button.flat:hover:checked:focus, .app-notification .button.flat:hover:checked:hover:focus, .app-notification.frame .button:focus:active, .app-notification.frame .button:focus:active:hover, .app-notification.frame .button:focus:active:focus, .app-notification.frame .button:focus:active:hover:focus, .app-notification.frame .button:focus:checked, .app-notification.frame .button:focus:checked:hover, .app-notification.frame .button:focus:checked:focus, .app-notification.frame .button:focus:checked:hover:focus, .app-notification.frame .button:hover:active, .app-notification.frame .button:hover:active:hover, .app-notification.frame .button:hover:active:focus, .app-notification.frame .button:hover:active:hover:focus, .app-notification.frame .button:hover:checked, .app-notification.frame .button:hover:checked:hover, .app-notification.frame .button:hover:checked:focus, .app-notification.frame .button:hover:checked:hover:focus, .app-notification.frame .button.flat:focus:active, .app-notification.frame .button.flat:focus:active:hover, .app-notification.frame .button.flat:focus:active:focus, .app-notification.frame .button.flat:focus:active:hover:focus, .app-notification.frame .button.flat:focus:checked, .app-notification.frame .button.flat:focus:checked:hover, .app-notification.frame .button.flat:focus:checked:focus, .app-notification.frame .button.flat:focus:checked:hover:focus, .app-notification.frame .button.flat:hover:active, .app-notification.frame .button.flat:hover:active:hover, .app-notification.frame .button.flat:hover:active:focus, .app-notification.frame .button.flat:hover:active:hover:focus, .app-notification.frame .button.flat:hover:checked, .app-notification.frame .button.flat:hover:checked:hover, .app-notification.frame .button.flat:hover:checked:focus, .app-notification.frame .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .app-notification .button:focus:insensitive, .app-notification .button:hover:insensitive, .app-notification .button.flat:focus:insensitive, .app-notification .button.flat:hover:insensitive, .app-notification.frame .button:focus:insensitive, .app-notification.frame .button:hover:insensitive, .app-notification.frame .button.flat:focus:insensitive, .app-notification.frame .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .app-notification .button:focus:active:insensitive, .app-notification .button:focus:checked:insensitive, .app-notification .button:hover:active:insensitive, .app-notification .button:hover:checked:insensitive, .app-notification .button.flat:focus:active:insensitive, .app-notification .button.flat:focus:checked:insensitive, .app-notification .button.flat:hover:active:insensitive, .app-notification .button.flat:hover:checked:insensitive, .app-notification.frame .button:focus:active:insensitive, .app-notification.frame .button:focus:checked:insensitive, .app-notification.frame .button:hover:active:insensitive, .app-notification.frame .button:hover:checked:insensitive, .app-notification.frame .button.flat:focus:active:insensitive, .app-notification.frame .button.flat:focus:checked:insensitive, .app-notification.frame .button.flat:hover:active:insensitive, .app-notification.frame .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .app-notification .button:active, .app-notification .button:checked, .app-notification .button.flat:active, .app-notification .button.flat:checked, .app-notification.frame .button:active, .app-notification.frame .button:checked, .app-notification.frame .button.flat:active, .app-notification.frame .button.flat:checked {
      background-color: rgba(11, 11, 11, 0.8);
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .app-notification .button:active:focus, .app-notification .button:active:hover, .app-notification .button:checked:focus, .app-notification .button:checked:hover, .app-notification .button.flat:active:focus, .app-notification .button.flat:active:hover, .app-notification .button.flat:checked:focus, .app-notification .button.flat:checked:hover, .app-notification.frame .button:active:focus, .app-notification.frame .button:active:hover, .app-notification.frame .button:checked:focus, .app-notification.frame .button:checked:hover, .app-notification.frame .button.flat:active:focus, .app-notification.frame .button.flat:active:hover, .app-notification.frame .button.flat:checked:focus, .app-notification.frame .button.flat:checked:hover {
        background-color: rgba(10, 10, 10, 0.8);
        background-image: none;
        color: #000000; }
    .app-notification .button:focus, .app-notification .button:hover, .app-notification .button.flat:focus, .app-notification .button.flat:hover, .app-notification.frame .button:focus, .app-notification.frame .button:hover, .app-notification.frame .button.flat:focus, .app-notification.frame .button.flat:hover {
      color: #a5a5a5; }
    .app-notification .button:active:insensitive, .app-notification .button:checked:insensitive, .app-notification .button.flat:active:insensitive, .app-notification .button.flat:checked:insensitive, .app-notification.frame .button:active:insensitive, .app-notification.frame .button:checked:insensitive, .app-notification.frame .button.flat:active:insensitive, .app-notification.frame .button.flat:checked:insensitive {
      background-color: rgba(14, 14, 14, 0.8);
      background-image: none;
      color: #a5a5a5;
      box-shadow: none; }
    .app-notification .button:insensitive:insensitive, .app-notification .button.flat:insensitive:insensitive, .app-notification.frame .button:insensitive:insensitive, .app-notification.frame .button.flat:insensitive:insensitive {
      background-color: rgba(15, 15, 15, 0.1);
      background-image: none;
      color: mix(rgba(15, 15, 15, 0.8),#a5a5a5,0.5);
      box-shadow: none; }
    .app-notification .button:active, .app-notification.frame .button:active {
      color: #a5a5a5; }
    .app-notification .button.flat:insensitive:insensitive, .app-notification.frame .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(rgba(15, 15, 15, 0.8),#a5a5a5,0.5);
      box-shadow: none; }
    .app-notification .button.separator, .app-notification .button .separator, .app-notification.frame .button.separator, .app-notification.frame .button .separator {
      border: 1px solid currentColor;
      color: rgba(14, 14, 14, 0.8); }
      .app-notification .button.separator:insensitive, .app-notification .button .separator:insensitive, .app-notification.frame .button.separator:insensitive, .app-notification.frame .button .separator:insensitive {
        color: rgba(13, 13, 13, 0.8); }

/*************
 ! Expanders *
**************/
GtkExpander {
  padding: 3px;
  outline-offset: 1px; }

.expander {
  color: alpha(currentColor,0.7);
  border: alpha(currentColor,0.7); }
  .expander:hover {
    color: alpha(currentColor,0.8);
    border-color: alpha(currentColor,0.8); }
  .expander:active {
    color: alpha(currentColor,0.9);
    border-color: alpha(currentColor,0.9); }

/*******************
 ! Symbolic images *
********************/
.image {
  color: alpha(currentColor,0.5); }
  .image:hover {
    color: alpha(currentColor,0.9); }
  .image:selected, .image:selected:hover {
    color: #000000; }

/****************
 ! Floating bar *
*****************/
.floating-bar {
  background-color: #a5a5a5;
  background-image: none;
  border: 1px solid #848484;
  border-radius: 3px;
  color: #000000; }
  .floating-bar.top {
    border-top-width: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0; }
  .floating-bar.right {
    border-right-width: 0;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
  .floating-bar.bottom {
    border-bottom-width: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0; }
  .floating-bar.left {
    border-left-width: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  .floating-bar .button {
    -GtkButton-image-spacing: 0;
    -GtkButton-inner-border: 0;
    border: 0;
    background-color: transparent;
    background-image: none; }

/*************************
 ! Touch text selections *
**************************/
GtkBubbleWindow {
  border-radius: 3px;
  background-clip: border-box; }
  GtkBubbleWindow.osd.background {
    background-color: rgba(15, 15, 15, 0.8); }
  GtkBubbleWindow .toolbar {
    background-color: transparent; }

/***************
 ! Font-viewer *
****************/
SushiFontWidget {
  padding: 3px 6px; }

/*************
 ! Gucharmap *
**************/
GucharmapChartable {
  background-color: #d0d0d0;
  color: #000000; }

/*************
 ! Evolution *
**************/
EPreviewPane .entry {
  background-color: #d0d0d0;
  color: #000000; }

/*******************
 ! Gnome Bluetooth *
********************/
GtkEntry.entry.pin-entry {
  font: regular 50;
  padding-left: 25px;
  padding-right: 25px; }

GtkLabel.pin-label {
  font: regular 50; }

/*********
 ! Buttons
**********/
/******************
! ComboBoxes *
*******************/
/**********
 ! Notebook
***********/
.notebook {
  padding: 0;
  border-style: solid;
  border-color: #848484;
  border-radius: 0;
  background-color: #a5a5a5;
  background-image: none;
  background-clip: border-box;
  color: #000000;
  -GtkNotebook-initial-gap: 0;
  -GtkNotebook-arrow-spacing: 5;
  -GtkNotebook-tab-curvature: 0;
  -GtkNotebook-tab-overlap: 1;
  -GtkNotebook-has-tab-gap: false; }
  .notebook.frame.top {
    border-width: 0 1px 1px; }
  .notebook.frame.right {
    border-width: 1px 0 1px 1px; }
  .notebook.frame.bottom {
    border-width: 1px 1px 0; }
  .notebook.frame.left {
    border-width: 1px 1px 1px 0; }
  .notebook.header {
    border-width: 2px;
    background-color: transparent; }
  .notebook GtkViewport {
    border-width: 0;
    background-color: #d0d0d0;
    color: #000000; }
  .notebook tab {
    padding: 4px 6px;
    border-style: solid;
    border-color: #6a6a6a;
    background-color: #848484;
    background-image: none;
    /* close button styling */ }
    .notebook tab:active {
      background-color: #a5a5a5;
      background-image: none; }
    .notebook tab.top {
      border-width: 2px 1px 1px;
      border-bottom-right-radius: 0;
      border-bottom-left-radius: 0; }
      .notebook tab.top:active {
        border-top-width: 3px;
        border-top-color: #B36A87;
        border-bottom-width: 0; }
    .notebook tab.right {
      border-width: 1px 2px 1px 1px;
      border-bottom-left-radius: 0;
      border-top-left-radius: 0; }
      .notebook tab.right:active {
        border-right-width: 3px;
        border-right-color: #B36A87;
        border-left-width: 0; }
    .notebook tab.bottom {
      border-width: 1px 1px 2px;
      border-top-right-radius: 0;
      border-top-left-radius: 0; }
      .notebook tab.bottom:active {
        border-bottom-width: 3px;
        border-bottom-color: #B36A87;
        border-top-width: 0; }
    .notebook tab.left {
      border-width: 1px 1px 1px 2px;
      border-top-right-radius: 0;
      border-bottom-right-radius: 0; }
      .notebook tab.left:active {
        border-left-width: 3px;
        border-left-color: #B36A87;
        border-right-width: 0; }
    .notebook tab GtkLabel {
      color: mix(#000000,#d0d0d0,0.3); }
    .notebook tab.reorderable-page:hover {
      background-color: #b1b1b1;
      border-left: 0;
      border-right: 0;
      /* using box shadows instead of borders due to slanted edges */
      box-shadow: inset 0 3px rgba(0, 0, 0, 0.03), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.03), inset 1px 0 #929292, inset -1px 0 #929292; }
    .notebook tab.reorderable-page:active {
      background-color: #bbbbbb;
      border-left: 0;
      border-right: 0;
      box-shadow: inset 0 3px rgba(0, 0, 0, 0.03), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.03), inset 1px 0 #9c9c9c, inset -1px 0 #9c9c9c; }
  .notebook .prelight-page, .notebook .prelight-page GtkLabel {
    color: mix(#000000,#d0d0d0,0.15); }
  .notebook .active-page, .notebook .active-page GtkLabel {
    color: #000000; }

/*********
 ! Buttons
**********/
/******************
! ComboBoxes *
*******************/
/*******
 ! OSD *
********/
GtkOverlay.osd {
  background-color: transparent; }

.osd,
#XfceNotifyWindow {
  /* used by gnome-settings-daemon's media-keys OSD */
  /* used by Documents */ }
  .osd.background,
  #XfceNotifyWindow.background {
    background-color: rgba(15, 15, 15, 0.6);
    color: #a5a5a5; }
  .osd.frame,
  #XfceNotifyWindow.frame {
    background-clip: border-box;
    background-origin: border-box; }
  .osd.button, .osd .button,
  #XfceNotifyWindow.button,
  #XfceNotifyWindow .button {
    /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
    background-color: rgba(15, 15, 15, 0.8);
    background-image: none;
    border-color: rgba(0, 0, 0, 0.22);
    color: #a5a5a5;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.22); }
    .osd.button:focus, .osd.button:hover, .osd .button:focus, .osd .button:hover,
    #XfceNotifyWindow.button:focus,
    #XfceNotifyWindow.button:hover,
    #XfceNotifyWindow .button:focus,
    #XfceNotifyWindow .button:hover {
      border-color: rgba(0, 0, 0, 0.22); }
    .osd.button:active, .osd.button:active:hover, .osd.button:active:focus, .osd.button:active:hover:focus, .osd.button:checked, .osd.button:checked:hover, .osd.button:checked:focus, .osd.button:checked:hover:focus, .osd .button:active, .osd .button:active:hover, .osd .button:active:focus, .osd .button:active:hover:focus, .osd .button:checked, .osd .button:checked:hover, .osd .button:checked:focus, .osd .button:checked:hover:focus,
    #XfceNotifyWindow.button:active,
    #XfceNotifyWindow.button:active:hover,
    #XfceNotifyWindow.button:active:focus,
    #XfceNotifyWindow.button:active:hover:focus,
    #XfceNotifyWindow.button:checked,
    #XfceNotifyWindow.button:checked:hover,
    #XfceNotifyWindow.button:checked:focus,
    #XfceNotifyWindow.button:checked:hover:focus,
    #XfceNotifyWindow .button:active,
    #XfceNotifyWindow .button:active:hover,
    #XfceNotifyWindow .button:active:focus,
    #XfceNotifyWindow .button:active:hover:focus,
    #XfceNotifyWindow .button:checked,
    #XfceNotifyWindow .button:checked:hover,
    #XfceNotifyWindow .button:checked:focus,
    #XfceNotifyWindow .button:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.22); }
    .osd.button:insensitive, .osd .button:insensitive,
    #XfceNotifyWindow.button:insensitive,
    #XfceNotifyWindow .button:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .osd.button:active:insensitive, .osd.button:checked:insensitive, .osd .button:active:insensitive, .osd .button:checked:insensitive,
    #XfceNotifyWindow.button:active:insensitive,
    #XfceNotifyWindow.button:checked:insensitive,
    #XfceNotifyWindow .button:active:insensitive,
    #XfceNotifyWindow .button:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.22); }
    .osd.button.flat, .osd .button.flat,
    #XfceNotifyWindow.button.flat,
    #XfceNotifyWindow .button.flat {
      border-color: rgba(15, 15, 15, 0);
      background-color: rgba(15, 15, 15, 0);
      background-image: none;
      box-shadow: none; }
    .osd.button:focus, .osd.button:hover, .osd.button.flat:focus, .osd.button.flat:hover, .osd .button:focus, .osd .button:hover, .osd .button.flat:focus, .osd .button.flat:hover,
    #XfceNotifyWindow.button:focus,
    #XfceNotifyWindow.button:hover,
    #XfceNotifyWindow.button.flat:focus,
    #XfceNotifyWindow.button.flat:hover,
    #XfceNotifyWindow .button:focus,
    #XfceNotifyWindow .button:hover,
    #XfceNotifyWindow .button.flat:focus,
    #XfceNotifyWindow .button.flat:hover {
      background-color: rgba(18, 18, 18, 0.8);
      background-image: none;
      border-color: rgba(0, 0, 0, 0.3);
      box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.42); }
      .osd.button:focus:focus, .osd.button:focus:hover, .osd.button:hover:focus, .osd.button:hover:hover, .osd.button.flat:focus:focus, .osd.button.flat:focus:hover, .osd.button.flat:hover:focus, .osd.button.flat:hover:hover, .osd .button:focus:focus, .osd .button:focus:hover, .osd .button:hover:focus, .osd .button:hover:hover, .osd .button.flat:focus:focus, .osd .button.flat:focus:hover, .osd .button.flat:hover:focus, .osd .button.flat:hover:hover,
      #XfceNotifyWindow.button:focus:focus,
      #XfceNotifyWindow.button:focus:hover,
      #XfceNotifyWindow.button:hover:focus,
      #XfceNotifyWindow.button:hover:hover,
      #XfceNotifyWindow.button.flat:focus:focus,
      #XfceNotifyWindow.button.flat:focus:hover,
      #XfceNotifyWindow.button.flat:hover:focus,
      #XfceNotifyWindow.button.flat:hover:hover,
      #XfceNotifyWindow .button:focus:focus,
      #XfceNotifyWindow .button:focus:hover,
      #XfceNotifyWindow .button:hover:focus,
      #XfceNotifyWindow .button:hover:hover,
      #XfceNotifyWindow .button.flat:focus:focus,
      #XfceNotifyWindow .button.flat:focus:hover,
      #XfceNotifyWindow .button.flat:hover:focus,
      #XfceNotifyWindow .button.flat:hover:hover {
        border-color: rgba(0, 0, 0, 0.3); }
      .osd.button:focus:active, .osd.button:focus:active:hover, .osd.button:focus:active:focus, .osd.button:focus:active:hover:focus, .osd.button:focus:checked, .osd.button:focus:checked:hover, .osd.button:focus:checked:focus, .osd.button:focus:checked:hover:focus, .osd.button:hover:active, .osd.button:hover:active:hover, .osd.button:hover:active:focus, .osd.button:hover:active:hover:focus, .osd.button:hover:checked, .osd.button:hover:checked:hover, .osd.button:hover:checked:focus, .osd.button:hover:checked:hover:focus, .osd.button.flat:focus:active, .osd.button.flat:focus:active:hover, .osd.button.flat:focus:active:focus, .osd.button.flat:focus:active:hover:focus, .osd.button.flat:focus:checked, .osd.button.flat:focus:checked:hover, .osd.button.flat:focus:checked:focus, .osd.button.flat:focus:checked:hover:focus, .osd.button.flat:hover:active, .osd.button.flat:hover:active:hover, .osd.button.flat:hover:active:focus, .osd.button.flat:hover:active:hover:focus, .osd.button.flat:hover:checked, .osd.button.flat:hover:checked:hover, .osd.button.flat:hover:checked:focus, .osd.button.flat:hover:checked:hover:focus, .osd .button:focus:active, .osd .button:focus:active:hover, .osd .button:focus:active:focus, .osd .button:focus:active:hover:focus, .osd .button:focus:checked, .osd .button:focus:checked:hover, .osd .button:focus:checked:focus, .osd .button:focus:checked:hover:focus, .osd .button:hover:active, .osd .button:hover:active:hover, .osd .button:hover:active:focus, .osd .button:hover:active:hover:focus, .osd .button:hover:checked, .osd .button:hover:checked:hover, .osd .button:hover:checked:focus, .osd .button:hover:checked:hover:focus, .osd .button.flat:focus:active, .osd .button.flat:focus:active:hover, .osd .button.flat:focus:active:focus, .osd .button.flat:focus:active:hover:focus, .osd .button.flat:focus:checked, .osd .button.flat:focus:checked:hover, .osd .button.flat:focus:checked:focus, .osd .button.flat:focus:checked:hover:focus, .osd .button.flat:hover:active, .osd .button.flat:hover:active:hover, .osd .button.flat:hover:active:focus, .osd .button.flat:hover:active:hover:focus, .osd .button.flat:hover:checked, .osd .button.flat:hover:checked:hover, .osd .button.flat:hover:checked:focus, .osd .button.flat:hover:checked:hover:focus,
      #XfceNotifyWindow.button:focus:active,
      #XfceNotifyWindow.button:focus:active:hover,
      #XfceNotifyWindow.button:focus:active:focus,
      #XfceNotifyWindow.button:focus:active:hover:focus,
      #XfceNotifyWindow.button:focus:checked,
      #XfceNotifyWindow.button:focus:checked:hover,
      #XfceNotifyWindow.button:focus:checked:focus,
      #XfceNotifyWindow.button:focus:checked:hover:focus,
      #XfceNotifyWindow.button:hover:active,
      #XfceNotifyWindow.button:hover:active:hover,
      #XfceNotifyWindow.button:hover:active:focus,
      #XfceNotifyWindow.button:hover:active:hover:focus,
      #XfceNotifyWindow.button:hover:checked,
      #XfceNotifyWindow.button:hover:checked:hover,
      #XfceNotifyWindow.button:hover:checked:focus,
      #XfceNotifyWindow.button:hover:checked:hover:focus,
      #XfceNotifyWindow.button.flat:focus:active,
      #XfceNotifyWindow.button.flat:focus:active:hover,
      #XfceNotifyWindow.button.flat:focus:active:focus,
      #XfceNotifyWindow.button.flat:focus:active:hover:focus,
      #XfceNotifyWindow.button.flat:focus:checked,
      #XfceNotifyWindow.button.flat:focus:checked:hover,
      #XfceNotifyWindow.button.flat:focus:checked:focus,
      #XfceNotifyWindow.button.flat:focus:checked:hover:focus,
      #XfceNotifyWindow.button.flat:hover:active,
      #XfceNotifyWindow.button.flat:hover:active:hover,
      #XfceNotifyWindow.button.flat:hover:active:focus,
      #XfceNotifyWindow.button.flat:hover:active:hover:focus,
      #XfceNotifyWindow.button.flat:hover:checked,
      #XfceNotifyWindow.button.flat:hover:checked:hover,
      #XfceNotifyWindow.button.flat:hover:checked:focus,
      #XfceNotifyWindow.button.flat:hover:checked:hover:focus,
      #XfceNotifyWindow .button:focus:active,
      #XfceNotifyWindow .button:focus:active:hover,
      #XfceNotifyWindow .button:focus:active:focus,
      #XfceNotifyWindow .button:focus:active:hover:focus,
      #XfceNotifyWindow .button:focus:checked,
      #XfceNotifyWindow .button:focus:checked:hover,
      #XfceNotifyWindow .button:focus:checked:focus,
      #XfceNotifyWindow .button:focus:checked:hover:focus,
      #XfceNotifyWindow .button:hover:active,
      #XfceNotifyWindow .button:hover:active:hover,
      #XfceNotifyWindow .button:hover:active:focus,
      #XfceNotifyWindow .button:hover:active:hover:focus,
      #XfceNotifyWindow .button:hover:checked,
      #XfceNotifyWindow .button:hover:checked:hover,
      #XfceNotifyWindow .button:hover:checked:focus,
      #XfceNotifyWindow .button:hover:checked:hover:focus,
      #XfceNotifyWindow .button.flat:focus:active,
      #XfceNotifyWindow .button.flat:focus:active:hover,
      #XfceNotifyWindow .button.flat:focus:active:focus,
      #XfceNotifyWindow .button.flat:focus:active:hover:focus,
      #XfceNotifyWindow .button.flat:focus:checked,
      #XfceNotifyWindow .button.flat:focus:checked:hover,
      #XfceNotifyWindow .button.flat:focus:checked:focus,
      #XfceNotifyWindow .button.flat:focus:checked:hover:focus,
      #XfceNotifyWindow .button.flat:hover:active,
      #XfceNotifyWindow .button.flat:hover:active:hover,
      #XfceNotifyWindow .button.flat:hover:active:focus,
      #XfceNotifyWindow .button.flat:hover:active:hover:focus,
      #XfceNotifyWindow .button.flat:hover:checked,
      #XfceNotifyWindow .button.flat:hover:checked:hover,
      #XfceNotifyWindow .button.flat:hover:checked:focus,
      #XfceNotifyWindow .button.flat:hover:checked:hover:focus {
        border-color: rgba(0, 0, 0, 0.3); }
      .osd.button:focus:insensitive, .osd.button:hover:insensitive, .osd.button.flat:focus:insensitive, .osd.button.flat:hover:insensitive, .osd .button:focus:insensitive, .osd .button:hover:insensitive, .osd .button.flat:focus:insensitive, .osd .button.flat:hover:insensitive,
      #XfceNotifyWindow.button:focus:insensitive,
      #XfceNotifyWindow.button:hover:insensitive,
      #XfceNotifyWindow.button.flat:focus:insensitive,
      #XfceNotifyWindow.button.flat:hover:insensitive,
      #XfceNotifyWindow .button:focus:insensitive,
      #XfceNotifyWindow .button:hover:insensitive,
      #XfceNotifyWindow .button.flat:focus:insensitive,
      #XfceNotifyWindow .button.flat:hover:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
      .osd.button:focus:active:insensitive, .osd.button:focus:checked:insensitive, .osd.button:hover:active:insensitive, .osd.button:hover:checked:insensitive, .osd.button.flat:focus:active:insensitive, .osd.button.flat:focus:checked:insensitive, .osd.button.flat:hover:active:insensitive, .osd.button.flat:hover:checked:insensitive, .osd .button:focus:active:insensitive, .osd .button:focus:checked:insensitive, .osd .button:hover:active:insensitive, .osd .button:hover:checked:insensitive, .osd .button.flat:focus:active:insensitive, .osd .button.flat:focus:checked:insensitive, .osd .button.flat:hover:active:insensitive, .osd .button.flat:hover:checked:insensitive,
      #XfceNotifyWindow.button:focus:active:insensitive,
      #XfceNotifyWindow.button:focus:checked:insensitive,
      #XfceNotifyWindow.button:hover:active:insensitive,
      #XfceNotifyWindow.button:hover:checked:insensitive,
      #XfceNotifyWindow.button.flat:focus:active:insensitive,
      #XfceNotifyWindow.button.flat:focus:checked:insensitive,
      #XfceNotifyWindow.button.flat:hover:active:insensitive,
      #XfceNotifyWindow.button.flat:hover:checked:insensitive,
      #XfceNotifyWindow .button:focus:active:insensitive,
      #XfceNotifyWindow .button:focus:checked:insensitive,
      #XfceNotifyWindow .button:hover:active:insensitive,
      #XfceNotifyWindow .button:hover:checked:insensitive,
      #XfceNotifyWindow .button.flat:focus:active:insensitive,
      #XfceNotifyWindow .button.flat:focus:checked:insensitive,
      #XfceNotifyWindow .button.flat:hover:active:insensitive,
      #XfceNotifyWindow .button.flat:hover:checked:insensitive {
        border-color: rgba(0, 0, 0, 0.3); }
    .osd.button:active, .osd.button:checked, .osd.button.flat:active, .osd.button.flat:checked, .osd .button:active, .osd .button:checked, .osd .button.flat:active, .osd .button.flat:checked,
    #XfceNotifyWindow.button:active,
    #XfceNotifyWindow.button:checked,
    #XfceNotifyWindow.button.flat:active,
    #XfceNotifyWindow.button.flat:checked,
    #XfceNotifyWindow .button:active,
    #XfceNotifyWindow .button:checked,
    #XfceNotifyWindow .button.flat:active,
    #XfceNotifyWindow .button.flat:checked {
      background-color: rgba(11, 11, 11, 0.8);
      background-image: none;
      color: #000000;
      box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
      .osd.button:active:focus, .osd.button:active:hover, .osd.button:checked:focus, .osd.button:checked:hover, .osd.button.flat:active:focus, .osd.button.flat:active:hover, .osd.button.flat:checked:focus, .osd.button.flat:checked:hover, .osd .button:active:focus, .osd .button:active:hover, .osd .button:checked:focus, .osd .button:checked:hover, .osd .button.flat:active:focus, .osd .button.flat:active:hover, .osd .button.flat:checked:focus, .osd .button.flat:checked:hover,
      #XfceNotifyWindow.button:active:focus,
      #XfceNotifyWindow.button:active:hover,
      #XfceNotifyWindow.button:checked:focus,
      #XfceNotifyWindow.button:checked:hover,
      #XfceNotifyWindow.button.flat:active:focus,
      #XfceNotifyWindow.button.flat:active:hover,
      #XfceNotifyWindow.button.flat:checked:focus,
      #XfceNotifyWindow.button.flat:checked:hover,
      #XfceNotifyWindow .button:active:focus,
      #XfceNotifyWindow .button:active:hover,
      #XfceNotifyWindow .button:checked:focus,
      #XfceNotifyWindow .button:checked:hover,
      #XfceNotifyWindow .button.flat:active:focus,
      #XfceNotifyWindow .button.flat:active:hover,
      #XfceNotifyWindow .button.flat:checked:focus,
      #XfceNotifyWindow .button.flat:checked:hover {
        background-color: rgba(10, 10, 10, 0.8);
        background-image: none;
        color: #000000; }
    .osd.button:focus, .osd.button:hover, .osd.button.flat:focus, .osd.button.flat:hover, .osd .button:focus, .osd .button:hover, .osd .button.flat:focus, .osd .button.flat:hover,
    #XfceNotifyWindow.button:focus,
    #XfceNotifyWindow.button:hover,
    #XfceNotifyWindow.button.flat:focus,
    #XfceNotifyWindow.button.flat:hover,
    #XfceNotifyWindow .button:focus,
    #XfceNotifyWindow .button:hover,
    #XfceNotifyWindow .button.flat:focus,
    #XfceNotifyWindow .button.flat:hover {
      color: #a5a5a5; }
    .osd.button:active:insensitive, .osd.button:checked:insensitive, .osd.button.flat:active:insensitive, .osd.button.flat:checked:insensitive, .osd .button:active:insensitive, .osd .button:checked:insensitive, .osd .button.flat:active:insensitive, .osd .button.flat:checked:insensitive,
    #XfceNotifyWindow.button:active:insensitive,
    #XfceNotifyWindow.button:checked:insensitive,
    #XfceNotifyWindow.button.flat:active:insensitive,
    #XfceNotifyWindow.button.flat:checked:insensitive,
    #XfceNotifyWindow .button:active:insensitive,
    #XfceNotifyWindow .button:checked:insensitive,
    #XfceNotifyWindow .button.flat:active:insensitive,
    #XfceNotifyWindow .button.flat:checked:insensitive {
      background-color: rgba(14, 14, 14, 0.8);
      background-image: none;
      color: #a5a5a5;
      box-shadow: none; }
    .osd.button:insensitive:insensitive, .osd.button.flat:insensitive:insensitive, .osd .button:insensitive:insensitive, .osd .button.flat:insensitive:insensitive,
    #XfceNotifyWindow.button:insensitive:insensitive,
    #XfceNotifyWindow.button.flat:insensitive:insensitive,
    #XfceNotifyWindow .button:insensitive:insensitive,
    #XfceNotifyWindow .button.flat:insensitive:insensitive {
      background-color: rgba(15, 15, 15, 0.1);
      background-image: none;
      color: mix(rgba(15, 15, 15, 0.8),#a5a5a5,0.5);
      box-shadow: none; }
    .osd.button:active, .osd .button:active,
    #XfceNotifyWindow.button:active,
    #XfceNotifyWindow .button:active {
      color: #a5a5a5; }
    .osd.button.flat:insensitive:insensitive, .osd .button.flat:insensitive:insensitive,
    #XfceNotifyWindow.button.flat:insensitive:insensitive,
    #XfceNotifyWindow .button.flat:insensitive:insensitive {
      background-color: transparent;
      background-image: none;
      color: mix(rgba(15, 15, 15, 0.8),#a5a5a5,0.5);
      box-shadow: none; }
    .osd.button.separator, .osd.button .separator, .osd .button.separator, .osd .button .separator,
    #XfceNotifyWindow.button.separator,
    #XfceNotifyWindow.button .separator,
    #XfceNotifyWindow .button.separator,
    #XfceNotifyWindow .button .separator {
      border: 1px solid currentColor;
      color: rgba(14, 14, 14, 0.8); }
      .osd.button.separator:insensitive, .osd.button .separator:insensitive, .osd .button.separator:insensitive, .osd .button .separator:insensitive,
      #XfceNotifyWindow.button.separator:insensitive,
      #XfceNotifyWindow.button .separator:insensitive,
      #XfceNotifyWindow .button.separator:insensitive,
      #XfceNotifyWindow .button .separator:insensitive {
        color: rgba(13, 13, 13, 0.8); }
  .osd.toolbar,
  #XfceNotifyWindow.toolbar {
    -GtkToolbar-button-relief: normal;
    padding: 3px;
    border: 1px solid rgba(12, 12, 12, 0.8);
    border-radius: 3px;
    background-color: rgba(15, 15, 15, 0.8);
    background-image: none;
    color: #a5a5a5; }
    .osd.toolbar .separator,
    #XfceNotifyWindow.toolbar .separator {
      color: rgba(14, 14, 14, 0.8); }
  .osd.trough,
  #XfceNotifyWindow.trough {
    background-color: rgba(12, 12, 12, 0.8); }
  .osd.progressbar,
  #XfceNotifyWindow.progressbar {
    background-color: #a5a5a5; }
  .osd .scale.slider,
  #XfceNotifyWindow .scale.slider {
    background-color: rgba(16, 16, 16, 0.8);
    background-image: none;
    border-color: rgba(12, 12, 12, 0.8); }
    .osd .scale.slider:focus, .osd .scale.slider:hover,
    #XfceNotifyWindow .scale.slider:focus,
    #XfceNotifyWindow .scale.slider:hover {
      border-color: rgba(11, 11, 11, 0.8); }
    .osd .scale.slider:active, .osd .scale.slider:active:hover, .osd .scale.slider:active:focus, .osd .scale.slider:active:hover:focus, .osd .scale.slider:checked, .osd .scale.slider:checked:hover, .osd .scale.slider:checked:focus, .osd .scale.slider:checked:hover:focus,
    #XfceNotifyWindow .scale.slider:active,
    #XfceNotifyWindow .scale.slider:active:hover,
    #XfceNotifyWindow .scale.slider:active:focus,
    #XfceNotifyWindow .scale.slider:active:hover:focus,
    #XfceNotifyWindow .scale.slider:checked,
    #XfceNotifyWindow .scale.slider:checked:hover,
    #XfceNotifyWindow .scale.slider:checked:focus,
    #XfceNotifyWindow .scale.slider:checked:hover:focus {
      border-color: rgba(11, 11, 11, 0.8); }
    .osd .scale.slider:insensitive,
    #XfceNotifyWindow .scale.slider:insensitive {
      border-color: rgba(13, 13, 13, 0.8); }
    .osd .scale.slider:active:insensitive, .osd .scale.slider:checked:insensitive,
    #XfceNotifyWindow .scale.slider:active:insensitive,
    #XfceNotifyWindow .scale.slider:checked:insensitive {
      border-color: rgba(12, 12, 12, 0.8); }
    .osd .scale.slider:insensitive,
    #XfceNotifyWindow .scale.slider:insensitive {
      background-color: rgba(14, 14, 14, 0.8);
      background-image: none; }
  .osd .scale.trough,
  #XfceNotifyWindow .scale.trough {
    border-color: rgba(12, 12, 12, 0.8);
    background-color: rgba(16, 16, 16, 0.8);
    background-image: none; }
    .osd .scale.trough.highlight,
    #XfceNotifyWindow .scale.trough.highlight {
      border-color: #B36A87;
      background-color: #B36A87;
      background-image: none; }
    .osd .scale.trough:insensitive, .osd .scale.trough.highlight:insensitive,
    #XfceNotifyWindow .scale.trough:insensitive,
    #XfceNotifyWindow .scale.trough.highlight:insensitive {
      border-color: rgba(13, 13, 13, 0.8);
      background-color: rgba(14, 14, 14, 0.8);
      background-image: none; }
  .osd.view, GtkHTML.osd, .osd .view, .osd GtkHTML,
  #XfceNotifyWindow.view,
  GtkHTML#XfceNotifyWindow,
  #XfceNotifyWindow .view,
  #XfceNotifyWindow GtkHTML {
    background-color: rgba(15, 15, 15, 0.8); }
  .osd .scrollbar .trough,
  #XfceNotifyWindow .scrollbar .trough {
    background-color: rgba(15, 15, 15, 0.8); }
  .osd .scrollbar .slider,
  #XfceNotifyWindow .scrollbar .slider {
    border: 1px solid mix(rgba(13, 13, 13, 0.8),#a5a5a5,0.21);
    border-radius: 0;
    background-color: mix(rgba(15, 15, 15, 0.8),#a5a5a5,0.21); }
    .osd .scrollbar .slider:hover,
    #XfceNotifyWindow .scrollbar .slider:hover {
      border-color: mix(rgba(13, 13, 13, 0.8),#a5a5a5,0.31);
      background-color: mix(rgba(15, 15, 15, 0.8),#a5a5a5,0.31); }
    .osd .scrollbar .slider:active,
    #XfceNotifyWindow .scrollbar .slider:active {
      border-color: #a95778;
      background-color: #B36A87; }
  .osd GtkIconView.cell:selected, .osd GtkIconView.cell:selected:focus,
  #XfceNotifyWindow GtkIconView.cell:selected,
  #XfceNotifyWindow GtkIconView.cell:selected:focus {
    background-color: transparent;
    border: 3px solid mix(rgba(13, 13, 13, 0.8),#a5a5a5,0.21);
    border-radius: 3px;
    outline-color: transparent; }
  .osd .page-thumbnail,
  #XfceNotifyWindow .page-thumbnail {
    border: 1px solid rgba(14, 14, 14, 0.8);
    /* when there's no pixbuf yet */
    background-color: rgba(15, 15, 15, 0.8); }

.osd GtkProgressBar, GtkProgressBar.osd {
  -GtkProgressBar-xspacing: 0;
  -GtkProgressBar-yspacing: 2px;
  -GtkProgressBar-min-horizontal-bar-height: 2px;
  padding: 0; }
  .osd GtkProgressBar.trough, GtkProgressBar.osd.trough {
    padding: 0;
    border-style: none;
    border-radius: 0;
    background-image: none;
    background-color: transparent; }
  .osd GtkProgressBar.progressbar, GtkProgressBar.osd.progressbar {
    border-style: none;
    border-radius: 0;
    background-color: #B36A87;
    background-image: none; }

.overshoot.top {
  background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25))), -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(179, 106, 135, 0.2)), to(rgba(179, 106, 135, 0)));
  background-size: 100% 5%, 100% 100%;
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: 0;
  box-shadow: none; }
  .overshoot.top:backdrop {
    background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25)));
    background-size: 100% 5%;
    background-repeat: no-repeat;
    background-position: center top;
    background-color: transparent;
    border: 0;
    box-shadow: none; }

.overshoot.bottom {
  background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25))), -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(179, 106, 135, 0.2)), to(rgba(179, 106, 135, 0)));
  background-size: 100% 5%, 100% 100%;
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: 0;
  box-shadow: none; }
  .overshoot.bottom:backdrop {
    background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25)));
    background-size: 100% 5%;
    background-repeat: no-repeat;
    background-position: center bottom;
    background-color: transparent;
    border: 0;
    box-shadow: none; }

.overshoot.left {
  background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25))), -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(179, 106, 135, 0.2)), to(rgba(179, 106, 135, 0)));
  background-size: 5% 100%, 100% 100%;
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: 0;
  box-shadow: none; }
  .overshoot.left:backdrop {
    background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25)));
    background-size: 5% 100%;
    background-repeat: no-repeat;
    background-position: left center;
    background-color: transparent;
    border: 0;
    box-shadow: none; }

.overshoot.right {
  background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25))), -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(179, 106, 135, 0.2)), to(rgba(179, 106, 135, 0)));
  background-size: 5% 100%, 100% 100%;
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: 0;
  box-shadow: none; }
  .overshoot.right:backdrop {
    background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(rgba(179, 106, 135, 0.35)), to(rgba(179, 106, 135, 0.25)));
    background-size: 5% 100%;
    background-repeat: no-repeat;
    background-position: right center;
    background-color: transparent;
    border: 0;
    box-shadow: none; }

.undershoot.top {
  background-color: transparent;
  /*background-image: linear-gradient(to $_gradient_dir, // this is the dashed line
                                         $_undershoot_color_light 50%,
                                         $_undershoot_color_dark 50%);*/
  padding-top: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center top; }

.undershoot.bottom {
  background-color: transparent;
  /*background-image: linear-gradient(to $_gradient_dir, // this is the dashed line
                                         $_undershoot_color_light 50%,
                                         $_undershoot_color_dark 50%);*/
  padding-bottom: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center bottom; }

.undershoot.left {
  background-color: transparent;
  /*background-image: linear-gradient(to $_gradient_dir, // this is the dashed line
                                         $_undershoot_color_light 50%,
                                         $_undershoot_color_dark 50%);*/
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center; }

.undershoot.right {
  background-color: transparent;
  /*background-image: linear-gradient(to $_gradient_dir, // this is the dashed line
                                         $_undershoot_color_light 50%,
                                         $_undershoot_color_dark 50%);*/
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center; }

/*****************
 ! Progress bars *
******************/
GtkProgressBar {
  padding: 0;
  border-radius: 3px;
  font-size: smaller;
  color: rgba(0, 0, 0, 0.6);
  -GtkProgressBar-min-horizontal-bar-height: 6;
  -GtkProgressBar-min-vertical-bar-width: 6; }
  GtkProgressBar.osd {
    -GtkProgressBar-xspacing: 0;
    -GtkProgressBar-yspacing: 0;
    -GtkProgressBar-min-horizontal-bar-height: 3; }
  GtkProgressBar.trough {
    border: 1px solid rgba(132, 132, 132, 0.5);
    background-color: #b2b2b2;
    background-image: none; }

.progressbar {
  background-color: #B36A87;
  background-image: none;
  border-radius: 0;
  box-shadow: none; }
  .progressbar.left {
    border-top-left-radius: 3px;
    border-bottom-left-radius: 3px; }
  .progressbar.right {
    border-top-right-radius: 3px;
    border-bottom-right-radius: 3px; }
  .progressbar.left.right {
    box-shadow: none; }
  .progressbar.vertical {
    background-color: #B36A87;
    background-image: none; }
    .progressbar.vertical.bottom {
      border-bottom-left-radius: 3px;
      border-bottom-right-radius: 3px; }
    .progressbar.vertical.top {
      border-top-left-radius: 3px;
      border-top-right-radius: 3px; }

GtkLevelBar {
  -GtkLevelBar-min-block-width: 34;
  -GtkLevelBar-min-block-height: 3; }
  GtkLevelBar.vertical {
    -GtkLevelBar-min-block-width: 3;
    -GtkLevelBar-min-block-height: 34; }

.level-bar.trough {
  background-color: #b2b2b2;
  background-image: none;
  border: 1px solid rgba(132, 132, 132, 0.5);
  border-radius: 3px; }

.level-bar.fill-block {
  background-color: #B36A87;
  background-image: none;
  border-color: transparent;
  border-radius: 0; }
  .level-bar.fill-block.indicator-discrete.horizontal {
    margin-right: 1px; }
  .level-bar.fill-block.indicator-discrete.vertical {
    margin-bottom: 1px; }
  .level-bar.fill-block.level-high {
    background-color: #4caf50;
    border-color: transparent; }
  .level-bar.fill-block.level-low {
    background-color: #ef6c00;
    border-color: transparent; }
  .level-bar.fill-block.empty-fill-block {
    background-color: transparent;
    border-color: transparent;
    box-shadow: none; }

.scale {
  -GtkRange-slider-width: 16;
  -GtkRange-trough-border: 1;
  -GtkScale-slider-length: 16;
  padding: 0;
  border-width: 1px;
  border-radius: 3px;
  outline-offset: -1px; }
  .scale.slider {
    background-color: #b2b2b2;
    background-image: none;
    border-color: #848484;
    border-radius: 8px;
    border-width: 1px;
    border-style: solid;
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.3); }
    .scale.slider:focus, .scale.slider:hover {
      border-color: #7c7c7c; }
    .scale.slider:active, .scale.slider:active:hover, .scale.slider:active:focus, .scale.slider:active:hover:focus, .scale.slider:checked, .scale.slider:checked:hover, .scale.slider:checked:focus, .scale.slider:checked:hover:focus {
      border-color: #747474; }
    .scale.slider:insensitive {
      border-color: #8c8c8c; }
    .scale.slider:active:insensitive, .scale.slider:checked:insensitive {
      border-color: #848484; }
    .scale.slider:insensitive {
      background-color: #959595;
      background-image: none; }
  .scale.fine-tune:active, .scale.fine-tune:active:hover, .scale.fine-tune.horizontal:active, .scale.fine-tune.horizontal:active:hover {
    background-size: 50%;
    background-repeat: no-repeat;
    background-position: center; }
  .scale.mark {
    border-color: rgba(132, 132, 132, 0.5); }
  .scale.trough {
    background-color: #b2b2b2;
    background-image: none;
    margin: 7px 0;
    border: 1px solid rgba(132, 132, 132, 0.5);
    border-radius: 3px; }
    .scale.trough:insensitive {
      background-color: #959595;
      background-image: none; }
    .scale.trough.vertical {
      margin: 0 7px; }
  .scale.highlight.left, .memuitem .scale.highlight.left {
    background-color: #B36A87;
    background-image: none;
    border-color: #B36A87; }
    .scale.highlight.left:hover, .memuitem .scale.highlight.left:hover {
      border-color: #974d6a;
      background-color: #974d6a; }
    .scale.highlight.left:insensitive, .memuitem .scale.highlight.left:insensitive {
      background-color: #959595;
      background-image: none;
      border-color: #8c8c8c; }
  .scale.highlight.bottom {
    background-color: #B36A87;
    background-image: none;
    border-color: #B36A87; }

/***********
 ! Scrollbar
************/
* {
  -GtkRange-slider-width: 8;
  -GtkRange-stepper-spacing: 0;
  -GtkRange-trough-border: 2;
  -GtkRange-trough-under-steppers: 1;
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
  -GtkScrollbar-min-slider-length: 80;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkScrolledWindow-scrollbars-within-bevel: 1; }

.scrollbar {
  border: 0;
  padding: 0; }
  .scrollbar.button, .scrollbar.button:active, .scrollbar.button:active:hover {
    border-width: 0;
    border-radius: 0;
    background-color: transparent;
    background-image: none;
    color: rgba(0, 0, 0, 0.5); }
  .scrollbar.slider, .scrollbar.slider.vertical {
    border: 0;
    border-radius: 3px;
    background-color: mix(#a5a5a5,#000000,0.21); }
    .scrollbar.slider:hover, .scrollbar.slider.vertical:hover {
      background-color: mix(#a5a5a5,#000000,0.31); }
    .scrollbar.slider:active, .scrollbar.slider.vertical:active {
      background-color: #B36A87; }
    .scrollbar.slider.fine-tune:hover:active, .scrollbar.slider.vertical.fine-tune:hover:active {
      border: 2px solid transparent; }
  .scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
    opacity: .5;
    -GtkRange-slider-width: 4px; }
    .scrollbar.overlay-indicator:not(.dragging):not(.hovering) .slider {
      margin: 0;
      background-color: #000000;
      background-clip: padding-box; }
    .scrollbar.overlay-indicator:not(.dragging):not(.hovering) .trough {
      border-style: none;
      background-color: transparent; }
  .scrollbar.overlay-indicator.dragging, .scrollbar.overlay-indicator.hovering {
    opacity: .7; }

.scrollbars-junction,
.scrollbars-junction.frame,
.scrollbar.trough {
  border: 0;
  border-radius: 0;
  background-color: #a5a5a5;
  background-image: none; }

OsThumb, OsScrollbar {
  color: #747474; }
  OsThumb:selected, OsScrollbar:selected {
    background-color: #B36A87; }
  OsThumb:active, OsScrollbar:active {
    background-color: #B36A87; }
  OsThumb:insensitive, OsScrollbar:insensitive {
    background-color: #959595; }

/*********
 ! Sidebar
**********/
.sidebar, .sidebar.view, GtkHTML.sidebar, .sidebar .view, .sidebar GtkHTML, .sidebar GtkScrolledWindow {
  background-color: #a5a5a5;
  color: mix(#000000,#a5a5a5,0.1); }
  .sidebar.separator, .sidebar.separator:hover, .sidebar.separator:focus, .sidebar.view.separator, GtkHTML.sidebar.separator, .sidebar.view.separator:hover, GtkHTML.sidebar.separator:hover, .sidebar.view.separator:focus, GtkHTML.sidebar.separator:focus, .sidebar .view.separator, .sidebar GtkHTML.separator, .sidebar .view.separator:hover, .sidebar GtkHTML.separator:hover, .sidebar .view.separator:focus, .sidebar GtkHTML.separator:focus, .sidebar GtkScrolledWindow.separator, .sidebar GtkScrolledWindow.separator:hover, .sidebar GtkScrolledWindow.separator:focus {
    border-width: 1px;
    border-style: solid;
    border-color: #959595;
    color: #959595; }

.sidebar row:selected, .sidebar row:selected:hover, .sidebar row:selected:focus, .sidebar .view row:selected, .sidebar GtkHTML row:selected, .sidebar .view row:selected:hover, .sidebar GtkHTML row:selected:hover, .sidebar .view row:selected:focus, .sidebar GtkHTML row:selected:focus {
  border: 0;
  background-image: none;
  background-color: #B36A87;
  color: #000000; }

.sidebar row:selected:hover, .sidebar .view row:selected:hover, .sidebar GtkHTML row:selected:hover {
  border: 0;
  background-image: none;
  background-color: #b8738f;
  color: #000000; }

.sidebar row:hover, .sidebar .view row:hover, .sidebar GtkHTML row:hover {
  border: 0;
  background-image: none;
  background-color: #adadad; }

.sidebar .frame {
  border-width: 0; }

.sidebar .sidebar-row {
  padding: 1px; }

.sidebar .sidebar-icon {
  padding-left: 6px;
  padding-right: 6px; }

GtkAssistant .sidebar {
  padding: 3px;
  border-width: 0 1px 0 0;
  border-style: solid;
  border-right-color: #848484;
  border-radius: 0;
  background-color: #a5a5a5;
  color: mix(#000000,#a5a5a5,0.1); }
  GtkAssistant .sidebar:dir(ltr) {
    border-width: 0 1px 0 0; }
  GtkAssistant .sidebar:dir(rtl) {
    border-width: 0 0 0 1px; }
  GtkAssistant .sidebar .label {
    padding: 3px 6px; }
    GtkAssistant .sidebar .label.highlight {
      background-color: mix(#a5a5a5,#000000,0.8); }
  GtkAssistant .sidebar.csd .sidebar {
    border-top-style: none; }
  GtkAssistant .sidebar .highlight {
    font: bold; }

/******
! Paned
*******/
GtkPaned {
  -GtkPaned-handle-size: 1;
  -gtk-icon-source: none;
  margin: 0 3px; }
  GtkPaned:dir(rtl) {
    margin-right: 0;
    margin-left: 3px; }
  GtkPaned .pane-separator {
    background-color: #959595; }
  GtkPaned.wide {
    -GtkPaned-handle-size: 4;
    margin: 0; }
    GtkPaned.wide .pane-separator {
      background-color: transparent;
      border-style: none solid;
      border-color: #959595;
      border-width: 1px; }
    GtkPaned.wide.vertical .pane-separator {
      border-style: solid none; }

/*******************
 ! Spinner animation
********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn); } }

.spinner {
  background-image: none;
  background-color: #B36A87;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
  .spinner:active {
    opacity: 1;
    animation: spin 1s linear infinite; }
    .spinner:active:insensitive {
      opacity: .5; }

/***********************
 ! Check and Radio items
************************/
* {
  -GtkCheckButton-indicator-size: 16;
  -GtkCheckMenuItem-indicator-size: 16; }

.radio {
  background-image: none;
  -gtk-icon-source: url("../assets/radio-unchecked.svg"); }
  .radio:insensitive {
    -gtk-icon-source: url("../assets/radio-unchecked-insensitive.svg"); }
  .radio:checked, .radio:active {
    -gtk-icon-source: url("../assets/radio-checked.svg"); }
    .radio:checked:insensitive, .radio:active:insensitive {
      -gtk-icon-source: url("../assets/radio-checked-insensitive.svg"); }
  .radio:inconsistent {
    -gtk-icon-source: url("../assets/radio-mixed.svg"); }
    .radio:inconsistent:insensitive {
      -gtk-icon-source: url("../assets/radio-mixed-insensitive.svg"); }
  .radio.menuitem {
    -gtk-icon-source: url("../assets/menuitem-radio-unchecked.svg"); }
    .radio.menuitem:insensitive {
      -gtk-icon-source: url("../assets/menuitem-radio-checked-insensitive.svg"); }
    .radio.menuitem:checked, .radio.menuitem:active {
      -gtk-icon-source: url("../assets/menuitem-radio-checked.svg"); }
      .radio.menuitem:checked:hover, .radio.menuitem:active:hover {
        -gtk-icon-source: url("../assets/menuitem-radio-checked-hover.svg"); }
      .radio.menuitem:checked:insensitive, .radio.menuitem:active:insensitive {
        -gtk-icon-source: url("../assets/menuitem-radio-checked-insensitive.svg"); }
    .radio.menuitem:inconsistent {
      -gtk-icon-source: url("../assets/menuitem-radio-mixed.svg"); }
      .radio.menuitem:inconsistent:hover {
        -gtk-icon-source: url("../assets/menuitem-radio-mixed-hover.svg"); }
      .radio.menuitem:inconsistent:insensitive {
        -gtk-icon-source: url("../assets/menuitem-radio-mixed-insensitive.svg"); }

.check {
  background-image: none;
  -gtk-icon-source: url("../assets/checkbox-unchecked.svg"); }
  .check:insensitive {
    -gtk-icon-source: url("../assets/checkbox-unchecked-insensitive.svg"); }
  .check:checked, .check:active {
    -gtk-icon-source: url("../assets/checkbox-checked.svg"); }
    .check:checked:insensitive, .check:active:insensitive {
      -gtk-icon-source: url("../assets/checkbox-checked-insensitive.svg"); }
  .check:inconsistent {
    -gtk-icon-source: url("../assets/checkbox-mixed.svg"); }
    .check:inconsistent:insensitive {
      -gtk-icon-source: url("../assets/checkbox-mixed-insensitive.svg"); }
  .check.menuitem {
    -gtk-icon-source: url("../assets/menuitem-checkbox-unchecked.svg"); }
    .check.menuitem:insensitive {
      -gtk-icon-source: url("../assets/menuitem-checkbox-checked-insensitive.svg"); }
    .check.menuitem:checked, .check.menuitem:active {
      -gtk-icon-source: url("../assets/menuitem-checkbox-checked.svg"); }
      .check.menuitem:checked:hover, .check.menuitem:active:hover {
        -gtk-icon-source: url("../assets/menuitem-checkbox-checked-hover.svg"); }
      .check.menuitem:checked:insensitive, .check.menuitem:active:insensitive {
        -gtk-icon-source: url("../assets/menuitem-checkbox-checked-insensitive.svg"); }
    .check.menuitem:inconsistent {
      -gtk-icon-source: url("../assets/menuitem-checkbox-mixed.svg"); }
      .check.menuitem:inconsistent:hover {
        -gtk-icon-source: url("../assets/menuitem-checkbox-mixed-hover.svg"); }
      .check.menuitem:inconsistent:insensitive {
        -gtk-icon-source: url("../assets/menuitem-checkbox-mixed-insensitive.svg"); }

.view.content-view.check:not(list), GtkHTML.content-view.check:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-unchecked.svg");
  background-color: transparent; }

.view.content-view.check:hover:not(list), GtkHTML.content-view.check:hover:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-unchecked.svg");
  background-color: transparent; }

.view.content-view.check:active:not(list), GtkHTML.content-view.check:active:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-checked.svg");
  background-color: transparent; }

.view.content-view.check:backdrop:not(list), GtkHTML.content-view.check:backdrop:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-unchecked.svg");
  background-color: transparent; }

.view.content-view.check:checked:not(list), GtkHTML.content-view.check:checked:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-checked.svg");
  background-color: transparent; }

.view.content-view.check:checked:hover:not(list), GtkHTML.content-view.check:checked:hover:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-checked.svg");
  background-color: transparent; }

.view.content-view.check:checked:active:not(list), GtkHTML.content-view.check:checked:active:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-checked.svg");
  background-color: transparent; }

.view.content-view.check:backdrop:checked:not(list), GtkHTML.content-view.check:backdrop:checked:not(list) {
  icon-shadow: none;
  -gtk-icon-source: url("../assets/grid-selection-checked.svg");
  background-color: transparent; }

/********
 ! Switch
*********/
GtkSwitch {
  padding: 0;
  border-radius: 3px;
  font: bold condensed;
  outline-offset: -4px; }
  GtkSwitch.slider {
    background-color: #c6c6c6;
    background-image: none;
    border: 1px solid rgba(0, 0, 0, 0.2);
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.12); }
    GtkSwitch.slider:insensitive {
      border-color: rgba(0, 0, 0, 0.1);
      background-color: #959595;
      box-shadow: none; }
  GtkSwitch.trough {
    background-color: #9d9d9d;
    background-image: none;
    border: 1px solid #848484;
    color: #000000;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.07), inset 0 1px rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.07), inset 0 -1px rgba(0, 0, 0, 0.05); }
    GtkSwitch.trough:active {
      background-color: #B36A87;
      background-image: none;
      border-color: #a95778;
      color: #000000; }
    GtkSwitch.trough:insensitive {
      background-color: #959595;
      background-image: none;
      border-color: #8c8c8c;
      color: mix(#000000,#a5a5a5,0.5); }

/*********
 ! Buttons
**********/
/******************
! ComboBoxes *
*******************/
/*********
 ! Toolbar
**********/
/***************
 ! Generic views
****************/
* {
  -GtkTextView-error-underline-color: #f44336; }

.view, GtkHTML {
  color: #000000;
  background-color: #d0d0d0; }
  .view:insensitive, GtkHTML:insensitive, .view:insensitive:insensitive, GtkHTML:insensitive:insensitive {
    background-color: #bbbbbb;
    color: mix(#000000,#d0d0d0,0.5); }

.cell {
  border-width: 0;
  border-radius: 0; }
  .cell:selected, .cell:selected:focus {
    background-color: #B36A87;
    color: #000000; }

row:selected, row:selected:hover, row:selected:focus {
  -GtkWidget-focus-padding: 1;
  -GtkWidget-focus-line-width: 0;
  border: 0;
  background-color: #B36A87;
  background-image: none;
  color: #000000; }

.content-view.view, GtkHTML.content-view {
  background-color: #d0d0d0; }
  .content-view.view:hover, GtkHTML.content-view:hover {
    background-color: rgba(179, 106, 135, 0.6); }
  .content-view.view:selected, GtkHTML.content-view:selected, .content-view.view:active, GtkHTML.content-view:active {
    background-color: #B36A87; }
  .content-view.view:insensitive, GtkHTML.content-view:insensitive {
    background-color: #bbbbbb; }
  .content-view.view.check, GtkHTML.content-view.check, .content-view.view.check:active, GtkHTML.content-view.check:active, .content-view.view.check:hover, GtkHTML.content-view.check:hover, .content-view.view.check:insensitive, GtkHTML.content-view.check:insensitive, .content-view.view.check:selected, GtkHTML.content-view.check:selected {
    background-color: transparent; }

.content-view .subtitle {
  font: smaller;
  padding: 0 12px; }

GtkIconView.view.cell:selected, GtkIconView.view.cell:selected:focus {
  border: 0;
  border-radius: 2px;
  background-image: none;
  background-color: #B36A87;
  color: #000000; }

.dim-label, GtkLabel.separator, .dim-label.view, GtkLabel.view.separator, GtkHTML.dim-label {
  color: alpha(currentColor,0.5); }

.dnd {
  border: 1px solid #B36A87; }

.grip {
  background-color: transparent; }

.arrow {
  color: alpha(currentColor,0.7); }

.rubberband, .rubberband.view, GtkHTML.rubberband, .rubberband.content-view.view, GtkHTML.rubberband.content-view {
  border: 1px solid #B36A87;
  border-radius: 0;
  background-color: rgba(179, 106, 135, 0.3); }

GdMainIconView.content-view {
  -GdMainIconView-icon-size: 40; }

/* this will get overridden by .view, needed by gedit line numbers */
GtkTextView {
  background-color: mix(#a5a5a5,#d0d0d0,0.5); }

GtkHTML:insensitive {
  background-color: #bbbbbb; }

GtkDrawingArea {
  background-color: transparent; }

/************
 ! Treeview *
*************/
GtkTreeView {
  -GtkTreeView-expander-size: 8;
  -GtkTreeView-vertical-separator: 0;
  outline-offset: -1px;
  border-top-color: #0e0e0e; }
  GtkTreeView:hover, GtkTreeView:selected, GtkTreeView:selected:focus, GtkTreeView:backdrop:selected, GtkTreeView:backdrop:selected:focus {
    border-top-color: #B36A87; }
  GtkTreeView.dnd {
    border: 1px solid #B36A87; }
  GtkTreeView .entry {
    border-radius: 0;
    background-color: #d0d0d0;
    background-image: none; }
  GtkTreeView .progressbar {
    background-color: #B36A87;
    background-image: none;
    border: 1px solid #974d6a; }
    GtkTreeView .progressbar:selected:focus, GtkTreeView .progressbar:selected {
      background-color: #B36A87;
      background-image: none;
      border: 1px solid #8e4864;
      color: #000000; }
    GtkTreeView .progressbar:insensitive:insensitive {
      background-color: #a5a5a5;
      background-image: none;
      border-color: #8c8c8c; }
  GtkTreeView .trough {
    background-color: mix(#a5a5a5,#d0d0d0,0.5);
    border: 1px solid #a6a6a6; }
    GtkTreeView .trough:selected:focus, GtkTreeView .trough:selected {
      background-color: #d0d0d0;
      border: 1px solid #7c7c7c;
      color: #000000; }
    GtkTreeView .trough:insensitive:insensitive {
      background-color: #d0d0d0; }

/***********
 ! Separator
************/
.view.separator, GtkHTML.separator, .separator {
  color: #959595;
  border: 1px solid currentColor; }

/*********************
 ! Column view headers
**********************/
column-header .button, column-header .button:active {
  border-width: 0 1px 1px 0;
  border-radius: 0; }

column-header .button, column-header .button:active, column-header .button:focus, column-header .button:active:focus {
  border-color: #bbbbbb;
  border-bottom-color: #a6a6a6;
  background-color: #cacaca;
  background-image: none; }

column-header .button:hover, column-header .button:active:hover, column-header .button:hover:focus, column-header .button:active:hover:focus {
  border-color: #bbbbbb;
  border-bottom-color: #a6a6a6;
  background-color: #cecece;
  background-image: none; }

column-header .button:last-child .button {
  border-width: 0 0 1px; }

/**********
 ! Frames *
***********/
.frame {
  border: 1px solid #848484; }
  .frame.flat {
    border: 0; }

/* avoid double borders when a viewport is packed into a GtkScrolledWindow */
GtkScrolledWindow GtkViewport.frame {
  border: 0; }

/**************
 ! Window frame
***************/
.window-frame, .window-frame.csd.popup, .window-frame.csd.message-dialog {
  box-shadow: 0 19px 38px rgba(0, 0, 0, 0.3), 0 15px 12px rgba(0, 0, 0, 0.22), 0 0 0 1px #B36A87; }
  .window-frame:backdrop, .window-frame.csd.popup:backdrop, .window-frame.csd.message-dialog:backdrop {
    box-shadow: 0 10px 20px rgba(0, 0, 0, 0.19), 0 6px 6px rgba(0, 0, 0, 0.23), 0 0 0 1px #0f0f0f; }

.window-frame {
  border: 0;
  border-radius: 3px 3px 0 0;
  background-color: mix(#0b0b0b,#a5a5a5,0.21);
  /* this is used for the resize cursor area */
  margin: 9px; }
  .window-frame.tiled {
    border-radius: 0; }
  .window-frame.solid-csd {
    border-radius: 3px 3px 0 0;
    margin: 1px;
    background-color: mix(#0b0b0b,#a5a5a5,0.21);
    box-shadow: none; }
  .window-frame.csd.popup {
    border-radius: 0; }
  .window-frame.csd.tooltip {
    border-radius: 3px;
    box-shadow: none; }
  .window-frame.csd.message-dialog {
    border-radius: 3px; }
  .window-frame.ssd {
    box-shadow: 0 0 0 1px #B36A87; }
    .window-frame.ssd.maximized {
      border-radius: 0; }

/***********************
 ! Unity Greeter *
 ***********************/
.lightdm.menu {
  background-image: none;
  background-color: rgba(0, 0, 0, 0.6);
  border-color: rgba(255, 255, 255, 0.2);
  border-radius: 4px;
  padding: 1px;
  color: #fff; }

.lightdm-combo .menu {
  background-color: #101010;
  border-radius: 0;
  padding: 0;
  color: #fff; }

.lightdm.menu .menuitem *,
.lightdm.menu .menuitem.check:active,
.lightdm.menu .menuitem.radio:active {
  color: #fff; }

.lightdm.menubar *,
.lightdm.menubar .menuitem {
  padding: 2px; }

.lightdm-combo.combobox-entry .button,
.lightdm-combo .cell,
.lightdm-combo .button,
.lightdm-combo .entry,
.lightdm.button {
  background-image: none;
  background-color: rgba(0, 0, 0, 0.3);
  border-color: rgba(255, 255, 255, 0.9);
  border-radius: 5px;
  padding: 5px;
  color: #fff; }

.lightdm.button:hover {
  background-image: none;
  background-color: rgba(255, 255, 255, 0.3);
  border-color: rgba(255, 255, 255, 0.6);
  border-radius: 5px;
  padding: 5px;
  color: #fff;
  text-shadow: none; }

.lightdm.button:active,
.lightdm.button:active:focus,
.lightdm.button:focus,
.lightdm.entry {
  background-image: none;
  background-color: rgba(0, 0, 0, 0.3);
  border-color: rgba(255, 255, 255, 0.6);
  border-radius: 5px;
  padding: 6px;
  color: #fff;
  text-shadow: none; }

.lightdm.entry:hover,
.lightdm.entry:active,
.lightdm.entry:active:focus {
  background-image: none;
  border-image: none; }

.lightdm.entry:focus {
  border-color: rgba(255, 255, 255, 0.6);
  border-width: 1px;
  border-style: solid;
  color: #fff; }

.lightdm.entry:selected {
  background-color: rgba(255, 255, 255, 0.2); }

@keyframes dashentry_spinner {
  to {
    -gtk-icon-transform: rotate(1turn); } }

.lightdm.entry:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: dashentry_spinner 1s infinite linear; }

.lightdm.option-button {
  background: none;
  border-width: 0; }

.lightdm.option-button:insensitive:insensitive {
  background: none; }

.lightdm.toggle-button {
  background: none;
  border-width: 0; }

.lightdm.toggle-button.selected:hover {
  background-color: rgba(255, 255, 255, 0.3);
  border-color: rgba(255, 255, 255, 0.3);
  border-width: 1px; }

.lightdm.toggle-button.selected {
  background-color: rgba(0, 0, 0, 0.3);
  border-color: rgba(255, 255, 255, 0.3);
  border-width: 1px; }

/*********
 ! Gedit *
**********/
GeditWindow .pane-separator {
  border-width: 0 1px 0 0;
  border-style: solid; }
  GeditWindow .pane-separator, GeditWindow .pane-separator:hover {
    border-color: #959595;
    background-color: #a5a5a5; }

.gedit-document-panel {
  background-color: #a5a5a5;
  color: mix(#000000,#a5a5a5,0.1); }
  .gedit-document-panel .list-row {
    padding: 3px; }
    .gedit-document-panel .list-row .button {
      padding: 1px;
      border-radius: 3px;
      border-style: solid;
      border-color: transparent;
      border-width: 1px;
      background-color: transparent;
      background-image: none;
      color: transparent;
      icon-shadow: none; }
  .gedit-document-panel .prelight-row .button {
    border-color: rgba(0, 0, 0, 0.1);
    color: rgba(255, 255, 255, 0.8); }
    .gedit-document-panel .prelight-row .button:active {
      border-color: rgba(0, 0, 0, 0.2);
      background-color: rgba(0, 0, 0, 0.08);
      color: #fff; }
  .gedit-document-panel list-row .button:hover, .gedit-document-panel .prelight-row .button:hover {
    border-color: rgba(0, 0, 0, 0.1);
    color: #fff; }

.gedit-document-panel-group-row, .gedit-document-panel-group-row:hover {
  border-top: 1px solid #959595;
  background-color: #a5a5a5; }

.gedit-document-panel-document-row:hover {
  background-color: #adadad; }

.gedit-document-panel-dragged-row {
  border: 1px solid rgba(0, 0, 0, 0.1);
  background-color: rgba(0, 0, 0, 0.5);
  color: #fff; }

.gedit-document-panel-placeholder-row {
  border: 0;
  background-color: rgba(0, 0, 0, 0.08);
  transition: all 200ms ease-in; }

GeditStatusbar {
  border-top: 1px solid #848484; }

GeditStatusbar GeditSmallButton, GeditStatusMenuButton {
  text-shadow: none; }
  GeditStatusbar GeditSmallButton .button, GeditStatusMenuButton .button {
    border-style: solid;
    border-width: 0 1px;
    border-color: transparent;
    border-radius: 0;
    padding: 1px 6px 2px 4px; }
    GeditStatusbar GeditSmallButton .button:hover, GeditStatusbar GeditSmallButton .button:active, GeditStatusbar GeditSmallButton .button:active:hover, GeditStatusMenuButton .button:hover, GeditStatusMenuButton .button:active, GeditStatusMenuButton .button:active:hover {
      border-color: #848484; }
    GeditStatusbar GeditSmallButton .button:active, GeditStatusMenuButton .button:active {
      background-color: #9d9d9d;
      color: #000000; }

GeditViewFrame .gedit-search-slider {
  padding: 3px;
  border-radius: 0 0 3px 3px;
  border-width: 0 1px 1px;
  border-style: solid;
  border-color: #a6a6a6;
  background-color: #d0d0d0; }
  GeditViewFrame .gedit-search-slider .not-found {
    background-color: #f44336;
    background-image: none;
    color: #fff; }

GeditFileBrowserWidget .toolbar {
  padding: 1.5px;
  border-top: 0;
  background-color: #a5a5a5;
  background-image: none; }

.gedit-search-entry-occurrences-tag {
  margin: 1.5px;
  padding: 1.5px;
  color: mix(#000000,#d0d0d0,0.5); }

/************
 ! Nautilus *
*************/
.nautilus-desktop.nautilus-canvas-item {
  color: #fff;
  text-shadow: 1px 1px #000; }
  .nautilus-desktop.nautilus-canvas-item:active {
    color: #000000; }
  .nautilus-desktop.nautilus-canvas-item:selected {
    color: #000000; }
  .nautilus-desktop.nautilus-canvas-item:active, .nautilus-desktop.nautilus-canvas-item:hover, .nautilus-desktop.nautilus-canvas-item:selected {
    text-shadow: none; }

NautilusWindow .toolbar {
  border-width: 0 0 1px;
  border-style: solid;
  border-color: #848484; }

NautilusWindow .sidebar .frame {
  border: 0; }

NautilusWindow GtkPaned {
  border-width: 0 1px 0 0;
  border-style: solid; }
  NautilusWindow GtkPaned, NautilusWindow GtkPaned:hover {
    border-color: #959595;
    background-color: #a5a5a5; }

NautilusNotebook.notebook {
  border-right-width: 0;
  border-left-width: 0;
  border-bottom-width: 0; }

NautilusNotebook .frame {
  border: 0; }

NautilusQueryEditor .toolbar {
  padding-top: 2px;
  padding-bottom: 1px;
  border-width: 1px 0 0;
  border-style: solid;
  border-color: #a5a5a5;
  background-color: #959595; }
  NautilusQueryEditor .toolbar:nth-child(2) {
    border-color: #848484; }
  NautilusQueryEditor .toolbar.search-bar {
    border-top-width: 0;
    border-bottom-width: 0; }
  NautilusQueryEditor .toolbar:last-child, NautilusQueryEditor .toolbar:only-child, NautilusQueryEditor .toolbar.search-bar:last-child, NautilusQueryEditor .toolbar.search-bar:only-child {
    border-bottom-width: 1px;
    border-bottom-color: #848484; }

/********
 ! Nemo *
*********/
.nemo-desktop.nemo-canvas-item {
  color: #fff;
  text-shadow: 1px 1px #000; }
  .nemo-desktop.nemo-canvas-item:active {
    color: #000000; }
  .nemo-desktop.nemo-canvas-item:selected {
    color: #000000; }
  .nemo-desktop.nemo-canvas-item:active, .nemo-desktop.nemo-canvas-item:hover, .nemo-desktop.nemo-canvas-item:selected {
    text-shadow: none; }

NemoPathbarButton {
  /*$button_bg: if(hue($bg) == 0deg, shade($bg, 1.2), $bg);*/
  background-color: #a5a5a5;
  background-image: none;
  border-color: rgba(0, 0, 0, 0.12);
  color: #000000;
  box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.12);
  -NemoPathbarButton-border-radius: 3px; }
  NemoPathbarButton:focus, NemoPathbarButton:hover {
    border-color: rgba(0, 0, 0, 0.12); }
  NemoPathbarButton:active, NemoPathbarButton:active:hover, NemoPathbarButton:active:focus, NemoPathbarButton:active:hover:focus, NemoPathbarButton:checked, NemoPathbarButton:checked:hover, NemoPathbarButton:checked:focus, NemoPathbarButton:checked:hover:focus {
    border-color: rgba(0, 0, 0, 0.12); }
  NemoPathbarButton:insensitive {
    border-color: rgba(0, 0, 0, 0.12); }
  NemoPathbarButton:active:insensitive, NemoPathbarButton:checked:insensitive {
    border-color: rgba(0, 0, 0, 0.12); }
  NemoPathbarButton.flat {
    border-color: rgba(165, 165, 165, 0);
    background-color: rgba(165, 165, 165, 0);
    background-image: none;
    box-shadow: none; }
  NemoPathbarButton:focus, NemoPathbarButton:hover, NemoPathbarButton.flat:focus, NemoPathbarButton.flat:hover {
    background-color: #c6c6c6;
    background-image: none;
    border-color: rgba(0, 0, 0, 0.2);
    box-shadow: 0 1px 2px -1px rgba(0, 0, 0, 0.32); }
    NemoPathbarButton:focus:focus, NemoPathbarButton:focus:hover, NemoPathbarButton:hover:focus, NemoPathbarButton:hover:hover, NemoPathbarButton.flat:focus:focus, NemoPathbarButton.flat:focus:hover, NemoPathbarButton.flat:hover:focus, NemoPathbarButton.flat:hover:hover {
      border-color: rgba(0, 0, 0, 0.2); }
    NemoPathbarButton:focus:active, NemoPathbarButton:focus:active:hover, NemoPathbarButton:focus:active:focus, NemoPathbarButton:focus:active:hover:focus, NemoPathbarButton:focus:checked, NemoPathbarButton:focus:checked:hover, NemoPathbarButton:focus:checked:focus, NemoPathbarButton:focus:checked:hover:focus, NemoPathbarButton:hover:active, NemoPathbarButton:hover:active:hover, NemoPathbarButton:hover:active:focus, NemoPathbarButton:hover:active:hover:focus, NemoPathbarButton:hover:checked, NemoPathbarButton:hover:checked:hover, NemoPathbarButton:hover:checked:focus, NemoPathbarButton:hover:checked:hover:focus, NemoPathbarButton.flat:focus:active, NemoPathbarButton.flat:focus:active:hover, NemoPathbarButton.flat:focus:active:focus, NemoPathbarButton.flat:focus:active:hover:focus, NemoPathbarButton.flat:focus:checked, NemoPathbarButton.flat:focus:checked:hover, NemoPathbarButton.flat:focus:checked:focus, NemoPathbarButton.flat:focus:checked:hover:focus, NemoPathbarButton.flat:hover:active, NemoPathbarButton.flat:hover:active:hover, NemoPathbarButton.flat:hover:active:focus, NemoPathbarButton.flat:hover:active:hover:focus, NemoPathbarButton.flat:hover:checked, NemoPathbarButton.flat:hover:checked:hover, NemoPathbarButton.flat:hover:checked:focus, NemoPathbarButton.flat:hover:checked:hover:focus {
      border-color: rgba(0, 0, 0, 0.2); }
    NemoPathbarButton:focus:insensitive, NemoPathbarButton:hover:insensitive, NemoPathbarButton.flat:focus:insensitive, NemoPathbarButton.flat:hover:insensitive {
      border-color: rgba(0, 0, 0, 0.2); }
    NemoPathbarButton:focus:active:insensitive, NemoPathbarButton:focus:checked:insensitive, NemoPathbarButton:hover:active:insensitive, NemoPathbarButton:hover:checked:insensitive, NemoPathbarButton.flat:focus:active:insensitive, NemoPathbarButton.flat:focus:checked:insensitive, NemoPathbarButton.flat:hover:active:insensitive, NemoPathbarButton.flat:hover:checked:insensitive {
      border-color: rgba(0, 0, 0, 0.2); }
  NemoPathbarButton:active, NemoPathbarButton:checked, NemoPathbarButton.flat:active, NemoPathbarButton.flat:checked {
    background-color: #747474;
    background-image: none;
    color: #000000;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.06), inset 0 1px rgba(0, 0, 0, 0.07), inset -1px 0 rgba(0, 0, 0, 0.06), inset 0 -1px rgba(0, 0, 0, 0.05); }
    NemoPathbarButton:active:focus, NemoPathbarButton:active:hover, NemoPathbarButton:checked:focus, NemoPathbarButton:checked:hover, NemoPathbarButton.flat:active:focus, NemoPathbarButton.flat:active:hover, NemoPathbarButton.flat:checked:focus, NemoPathbarButton.flat:checked:hover {
      background-color: #6b6b6b;
      background-image: none;
      color: #000000; }
  NemoPathbarButton:focus, NemoPathbarButton:hover, NemoPathbarButton.flat:focus, NemoPathbarButton.flat:hover {
    color: #000000; }
  NemoPathbarButton:active:insensitive, NemoPathbarButton:checked:insensitive, NemoPathbarButton.flat:active:insensitive, NemoPathbarButton.flat:checked:insensitive {
    background-color: #959595;
    background-image: none;
    color: #000000;
    box-shadow: none; }
  NemoPathbarButton:insensitive:insensitive, NemoPathbarButton.flat:insensitive:insensitive {
    background-color: #9d9d9d;
    background-image: none;
    color: mix(#a5a5a5,#000000,0.5);
    box-shadow: none; }
  NemoPathbarButton:active {
    color: #000000; }
  NemoPathbarButton.flat:insensitive:insensitive {
    background-color: transparent;
    background-image: none;
    color: mix(#a5a5a5,#000000,0.5);
    box-shadow: none; }
  NemoPathbarButton.separator, NemoPathbarButton .separator {
    border: 1px solid currentColor;
    color: #959595; }
    NemoPathbarButton.separator:insensitive, NemoPathbarButton .separator:insensitive {
      color: #8c8c8c; }

NemoPlacesTreeView {
  -NemoPlacesTreeView-disk-full-bg-color: #848484;
  -NemoPlacesTreeView-disk-full-fg-color: #B36A87;
  -NemoPlacesTreeView-disk-full-bar-width: 1px;
  -NemoPlacesTreeView-disk-full-bar-radius: 1px;
  -NemoPlacesTreeView-disk-full-bottom-padding: 2px;
  -NemoPlacesTreeView-disk-full-max-length: 70px; }
  NemoPlacesTreeView:selected {
    -NemoPlacesTreeView-disk-full-bg-color: #000000;
    -NemoPlacesTreeView-disk-full-fg-color: #c690a5; }

/***********************
 ! Fallback mode panel *
************************/
PanelWidget, PanelApplet, PanelToplevel, PanelSeparator, PanelApplet > GtkMenuBar.menubar.menuitem, PanelMenuBar.menubar.menuitem, .gnome-panel-menu-bar.menuitem, PanelAppletFrame, WnckPager, WnckTasklist, .xfce4-panel, UnityPanelWidget, .unity-panel {
  background-color: #0f0f0f;
  background-image: none;
  color: #a5a5a5; }

PanelApplet .button, .xfce4-panel .button {
  border-width: 0 1px;
  border-radius: 0;
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  color: #a5a5a5; }
  PanelApplet .button:hover, .xfce4-panel .button:hover, PanelApplet .button:hover, .xfce4-panel .button:hover {
    background-color: mix(#0f0f0f,#a5a5a5,0.11);
    background-image: none;
    border-color: mix(#0f0f0f,#a5a5a5,0.11);
    color: #b2b2b2; }
  PanelApplet .button:active, .xfce4-panel .button:active, PanelApplet .button:checked, .xfce4-panel .button:checked {
    background-color: mix(#0f0f0f,#a5a5a5,0.21);
    background-image: none;
    border-color: mix(#0f0f0f,#a5a5a5,0.21);
    color: #b2b2b2; }
    PanelApplet .button:active:hover, .xfce4-panel .button:active:hover, PanelApplet .button:checked:hover, .xfce4-panel .button:checked:hover {
      background-color: mix(#0f0f0f,#a5a5a5,0.31);
      background-image: none;
      border-color: mix(#0f0f0f,#a5a5a5,0.31); }

PanelWidget, PanelApplet, PanelToplevel {
  padding: 0; }

PanelApplet {
  border: 0; }
  PanelApplet .button {
    -GtkButton-inner-border: 2; }

PanelSeparator {
  border: 0; }

PanelApplet > GtkMenuBar.menubar.menuitem, PanelMenuBar.menubar.menuitem, .gnome-panel-menu-bar.menuitem {
  border: 0;
  -PanelMenuBar-icon-visible: true; }

PanelAppletFrame {
  border: 0; }

/************
 ! Synaptic *
*************/
GtkWindow > GtkVBox > .dock, GtkWindow > GtkVBox > .dock > GtkHBox > GtkToolbar {
  background-color: #a5a5a5;
  background-image: none;
  padding: 3px;
  border: 0;
  color: #000000; }

/***********************
 ! Fallback mode panel *
************************/
/***************
 ! Xfce styles *
****************/
XfceHeading {
  margin: 0;
  padding: 0;
  border: 0;
  background-image: none;
  background-color: #d0d0d0;
  color: #000000; }

.xfce4-panel {
  font: normal; }
  .xfce4-panel .menu {
    -gtk-image-effect: none; }

/***********************
 ! Fallback mode panel *
************************/
/****************
 ! Unity styles *
*****************/
UnityDecoration {
  -UnityDecoration-extents: 28px 1px 1px 1px;
  -UnityDecoration-input-extents: 10px;
  -UnityDecoration-shadow-offset-x: 1px;
  -UnityDecoration-shadow-offset-y: 1px;
  -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.7);
  -UnityDecoration-active-shadow-radius: 8px;
  -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.5);
  -UnityDecoration-inactive-shadow-radius: 5px;
  -UnityDecoration-glow-size: 10px;
  -UnityDecoration-glow-color: #B36A87;
  -UnityDecoration-title-indent: 10px;
  -UnityDecoration-title-fade: 35px;
  -UnityDecoration-title-alignment: 0; }
  UnityDecoration.top {
    border: 1px solid mix(#0b0b0b,#a5a5a5,0.21);
    border-bottom: 0;
    border-radius: 2px 2px 0 0;
    padding: 1px 8px 0 8px;
    background-color: #0f0f0f;
    color: mix(#a5a5a5,#0f0f0f,0.1);
    text-shadow: none; }
    UnityDecoration.top:backdrop {
      border: 1px solid mix(#0b0b0b,#a5a5a5,0.12);
      border-bottom: 0;
      background-color: #0f0f0f;
      color: mix(#a5a5a5,#0f0f0f,0.4); }
  UnityDecoration.left, UnityDecoration.right, UnityDecoration.bottom {
    background-color: mix(#0b0b0b,#a5a5a5,0.21); }
    UnityDecoration.left:backdrop, UnityDecoration.right:backdrop, UnityDecoration.bottom:backdrop {
      background-color: mix(#0b0b0b,#a5a5a5,0.12); }

UnityPanelWidget, .unity-panel {
  border: 0; }

.unity-panel.menuitem, .unity-panel .menuitem {
  border-width: 0 1px;
  color: #a5a5a5; }
  .unity-panel.menuitem:hover, .unity-panel.menuitem *:hover, .unity-panel .menuitem:hover, .unity-panel .menuitem *:hover {
    border-color: mix(#0f0f0f,#a5a5a5,0.21);
    background-color: mix(#0f0f0f,#a5a5a5,0.21);
    background-image: none;
    color: #b2b2b2; }

SheetStyleDialog.unity-force-quit {
  background-color: #a5a5a5; }

/***********************
 ! LightDM GTK Greeter *
 ***********************/
#panel_window {
  background-color: transparent;
  background-image: none;
  color: #fff;
  font: bold;
  text-shadow: 0 1px rgba(0, 0, 0, 0.5);
  icon-shadow: 0 1px rgba(0, 0, 0, 0.5); }
  #panel_window .menubar, #panel_window .menubar > .menuitem {
    background-color: transparent;
    background-image: none;
    color: #fff;
    font: bold;
    text-shadow: 0 1px rgba(0, 0, 0, 0.5);
    icon-shadow: 0 1px rgba(0, 0, 0, 0.5); }
    #panel_window .menubar *:hover, #panel_window .menubar > .menuitem *:hover {
      color: #fff; }
    #panel_window .menubar:hover, #panel_window .menubar > .menuitem:hover {
      border-style: none;
      background-color: rgba(255, 255, 255, 0.2);
      background-image: none;
      color: #fff; }
    #panel_window .menubar:insensitive, #panel_window .menubar > .menuitem:insensitive {
      color: rgba(255, 255, 255, 0.7); }
    #panel_window .menubar .menu, #panel_window .menubar > .menuitem .menu {
      border-radius: 1px; }
      #panel_window .menubar .menu .menuitem, #panel_window .menubar > .menuitem .menu .menuitem {
        font: normal;
        text-shadow: none; }

#content_frame {
  padding-bottom: 14px; }

#login_window, #shutdown_dialog, #restart_dialog {
  border-style: none;
  border-radius: 3px;
  background-color: #0f0f0f;
  color: #a5a5a5;
  /* draw border using box-shadow */
  box-shadow: inset 1px 0 mix(#0b0b0b,#a5a5a5,0.21), inset -1px 0 mix(#0b0b0b,#a5a5a5,0.21), inset 0 1px mix(#0b0b0b,#a5a5a5,0.21), inset 0 -1px mix(#0b0b0b,#a5a5a5,0.21); }
  #login_window .button, #shutdown_dialog .button, #restart_dialog .button {
    padding: 3px 15px;
    border-width: 1px;
    border-radius: 3px;
    border-style: solid;
    border-color: #0c0c0c;
    background-color: #101010;
    background-image: none;
    color: #a5a5a5;
    transition: all 150ms ease-out; }
    #login_window .button.default, #login_window .button:focus, #login_window .button:active:focus, #shutdown_dialog .button.default, #shutdown_dialog .button:focus, #shutdown_dialog .button:active:focus, #restart_dialog .button.default, #restart_dialog .button:focus, #restart_dialog .button:active:focus {
      border-color: #974d6a;
      background-color: #bb7993;
      background-image: none;
      color: #000000; }
      #login_window .button.default:hover, #login_window .button:focus:hover, #login_window .button:active:focus:hover, #shutdown_dialog .button.default:hover, #shutdown_dialog .button:focus:hover, #shutdown_dialog .button:active:focus:hover, #restart_dialog .button.default:hover, #restart_dialog .button:focus:hover, #restart_dialog .button:active:focus:hover {
        border-color: #84435d;
        background-color: #B36A87; }

#login_window .menu {
  border-radius: 1px; }

#login_window GtkComboBox .button, #login_window GtkComboBox .button:hover, #login_window GtkComboBox .button:active, #login_window GtkComboBox .button:active:hover, #login_window GtkComboBox .button:focus, #login_window GtkComboBox .button:hover:focus, #login_window GtkComboBox .button:active:focus, #login_window GtkComboBox .button:active:hover:focus {
  padding: 0;
  background: none;
  border-style: none;
  box-shadow: none; }

#login_window .entry {
  padding: 3px 5px;
  border-width: 1px;
  border-style: solid;
  border-color: #0c0c0c;
  border-radius: 3px;
  background-color: #0e0e0e;
  background-image: none;
  color: #a5a5a5;
  box-shadow: none;
  transition: all 150ms ease-out; }
  #login_window .entry:focus, #login_window .entry:hover {
    border-color: #0b0b0b;
    box-shadow: inset 1px 0 rgba(0, 0, 0, 0.1), inset 0 1px rgba(0, 0, 0, 0.12), inset -1px 0 rgba(0, 0, 0, 0.1), inset 0 -1px rgba(0, 0, 0, 0.05); }

#user_combobox {
  color: #a5a5a5;
  font: 18px; }
  #user_combobox .menu {
    font: normal; }
  #user_combobox .arrow {
    color: mix(#a5a5a5,#0f0f0f,0.5); }

#user_image {
  padding: 3px;
  border-radius: 3px;
  /* draw border using box-shadow */
  box-shadow: inset 1px 0 #0b0b0b, inset -1px 0 #0b0b0b, inset 0 1px #0b0b0b, inset 0 -1px #0b0b0b; }

#user_image_border {
  border-radius: 3px;
  background-color: #0e0e0e;
  background-image: none;
  box-shadow: inset 1px 0 rgba(0, 0, 0, 0.07), inset 0 1px rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.07), inset 0 -1px rgba(0, 0, 0, 0.05); }

#buttonbox_frame {
  padding-top: 10px;
  padding-bottom: 0;
  border-style: none;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  background-color: transparent;
  background-image: none;
  box-shadow: none; }

/* shutdown button */
#shutdown_button {
  border-color: #e21b0c;
  background-color: #f5584d;
  background-image: none;
  color: #fff; }
  #shutdown_button:hover, #shutdown_button:active, #shutdown_button:active:hover {
    border-color: #c6180b;
    background-color: #f44336; }

/* restart button */
#restart_button {
  border-color: #bf5600;
  background-color: #ff7503;
  background-image: none;
  color: #fff; }
  #restart_button:hover, #restart_button:active, #restart_button:active:hover {
    border-color: #a74c00;
    background-color: #ef6c00; }

/* password warning */
#greeter_infobar {
  font: bold; }

/**********************
 ! Genome Terminal *
***********************/
VteTerminal {
  background-color: #0f0f0f;
  color: #a5a5a5; }

TerminalWindow .scrollbars-junction {
  background-color: #0f0f0f; }

TerminalWindow .scrollbar.trough {
  background-color: #0f0f0f; }

TerminalWindow .scrollbar.button {
  color: #090909; }
  TerminalWindow .scrollbar.button:active {
    color: #090909; }
    TerminalWindow .scrollbar.button:active:hover {
      color: #090909; }

TerminalWindow .scrollbar.slider {
  border-color: mix(#0d0d0d,#a5a5a5,0.21);
  background-color: mix(#0f0f0f,#a5a5a5,0.21); }
  TerminalWindow .scrollbar.slider:hover {
    border-color: mix(#0d0d0d,#a5a5a5,0.31);
    background-color: mix(#0f0f0f,#a5a5a5,0.31); }
  TerminalWindow .scrollbar.slider.vertical:hover {
    border-color: mix(#0d0d0d,#a5a5a5,0.31);
    background-color: mix(#0f0f0f,#a5a5a5,0.31); }
  TerminalWindow .scrollbar.slider.vertical:active {
    border-color: #a95778;
    background-color: #B36A87; }
  TerminalWindow .scrollbar.slider:active {
    border-color: #a95778;
    background-color: #B36A87; }

TerminalWindow GtkNotebook.notebook {
  border-right-width: 0;
  border-bottom-width: 0;
  border-left-width: 0; }

TerminalNotebook.notebook {
  padding: 0;
  border-width: 1px 0 0;
  border-style: solid;
  border-color: #0b0b0b;
  border-radius: 0;
  background-color: #0f0f0f;
  background-image: none;
  background-clip: border-box;
  color: #a5a5a5;
  -GtkNotebook-initial-gap: 0;
  -GtkNotebook-arrow-spacing: 5;
  -GtkNotebook-tab-curvature: 0;
  -GtkNotebook-tab-overlap: 1;
  -GtkNotebook-has-tab-gap: false; }
  TerminalNotebook.notebook.frame {
    border-width: 1px; }
  TerminalNotebook.notebook.header {
    border-width: 0;
    background-color: #0d0d0d; }
    TerminalNotebook.notebook.header.frame {
      border-color: #0b0b0b; }
      TerminalNotebook.notebook.header.frame.top {
        border-width: 1px 1px 0 1px; }
      TerminalNotebook.notebook.header.frame.right {
        border-width: 1px 1px 1px 0; }
      TerminalNotebook.notebook.header.frame.bottom {
        border-width: 0 1px 1px 1px; }
      TerminalNotebook.notebook.header.frame.left {
        border-width: 1px 0 1px 1px; }
  TerminalNotebook.notebook GtkViewport {
    border-width: 0;
    background-color: #0f0f0f;
    color: #a5a5a5; }
  TerminalNotebook.notebook tab {
    padding: 4px 6px;
    border: 1px solid transparent;
    background-color: transparent;
    background-image: none;
    /* close button styling */ }
    TerminalNotebook.notebook tab:active {
      background-color: transparent;
      background-image: none; }
    TerminalNotebook.notebook tab.top {
      border-bottom-width: 2px;
      border-bottom-right-radius: 0;
      border-bottom-left-radius: 0; }
      TerminalNotebook.notebook tab.top:hover {
        border-bottom-color: rgba(179, 106, 135, 0.3); }
      TerminalNotebook.notebook tab.top:active {
        border-bottom-color: #B36A87; }
    TerminalNotebook.notebook tab.right {
      border-left-width: 2px;
      border-bottom-left-radius: 0;
      border-top-left-radius: 0; }
      TerminalNotebook.notebook tab.right:hover {
        border-left-color: rgba(179, 106, 135, 0.3); }
      TerminalNotebook.notebook tab.right:active {
        border-left-color: #B36A87; }
    TerminalNotebook.notebook tab.bottom {
      border-top-width: 2px;
      border-top-right-radius: 0;
      border-top-left-radius: 0; }
      TerminalNotebook.notebook tab.bottom:hover {
        border-top-color: rgba(179, 106, 135, 0.3); }
      TerminalNotebook.notebook tab.bottom:active {
        border-top-color: #B36A87; }
    TerminalNotebook.notebook tab.left {
      border-right-width: 2px;
      border-top-right-radius: 0;
      border-bottom-right-radius: 0; }
      TerminalNotebook.notebook tab.left:hover {
        border-right-color: rgba(179, 106, 135, 0.3); }
      TerminalNotebook.notebook tab.left:active {
        border-right-color: #B36A87; }
    TerminalNotebook.notebook tab GtkLabel {
      color: mix(#a5a5a5,#0f0f0f,0.3); }
    TerminalNotebook.notebook tab.reorderable-page:hover {
      background-color: #0d0d0d;
      border-left: 0;
      border-right: 0;
      /* using box shadows instead of borders due to slanted edges */
      box-shadow: inset 0 3px rgba(0, 0, 0, 0.03), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.03), inset 1px 0 #0b0b0b, inset -1px 0 #0b0b0b; }
    TerminalNotebook.notebook tab.reorderable-page:active {
      background-color: #0e0e0e;
      border-left: 0;
      border-right: 0;
      box-shadow: inset 0 3px rgba(0, 0, 0, 0.03), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.03), inset 1px 0 #0b0b0b, inset -1px 0 #0b0b0b; }
    TerminalNotebook.notebook tab .button, TerminalNotebook.notebook tab .button:active, TerminalNotebook.notebook tab .button:checked, TerminalNotebook.notebook tab .button:hover {
      padding: 1px;
      border-width: 1px;
      border-radius: 2px;
      border-style: solid;
      border-color: transparent;
      background-image: none;
      background-color: transparent;
      color: mix(#a5a5a5,#0f0f0f,0.5); }
    TerminalNotebook.notebook tab .button:hover {
      color: #a5a5a5;
      border-color: #0c0c0c; }
    TerminalNotebook.notebook tab .button:active, TerminalNotebook.notebook tab .button:checked, TerminalNotebook.notebook tab .button:active:hover, TerminalNotebook.notebook tab .button:checked:hover {
      border-color: #0b0b0b;
      background-color: #0e0e0e; }
  TerminalNotebook.notebook .prelight-page, TerminalNotebook.notebook .prelight-page GtkLabel {
    color: mix(#a5a5a5,#0f0f0f,0.15); }
  TerminalNotebook.notebook .active-page, TerminalNotebook.notebook .active-page GtkLabel {
    color: #a5a5a5; }
